! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Mon Nov 27 13:27:13 2017
! Working directory    : /n/home05/msulprizio/GC/Code.Dev/KPP/SOA_SVPOA
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(60) = X(60)-JVS(396)*X(53)
  X(61) = X(61)-JVS(401)*X(46)
  X(64) = X(64)-JVS(416)*X(47)
  X(74) = X(74)-JVS(462)*X(73)
  X(76) = X(76)-JVS(472)*X(41)-JVS(473)*X(44)-JVS(474)*X(50)
  X(84) = X(84)-JVS(504)*X(72)
  X(103) = X(103)-JVS(604)*X(96)
  X(107) = X(107)-JVS(622)*X(84)
  X(110) = X(110)-JVS(643)*X(104)
  X(127) = X(127)-JVS(738)*X(109)
  X(130) = X(130)-JVS(757)*X(68)
  X(134) = X(134)-JVS(782)*X(59)-JVS(783)*X(73)-JVS(784)*X(125)
  X(136) = X(136)-JVS(800)*X(121)-JVS(801)*X(129)
  X(137) = X(137)-JVS(810)*X(51)
  X(143) = X(143)-JVS(866)*X(122)-JVS(867)*X(126)-JVS(868)*X(131)-JVS(869)*X(132)-JVS(870)*X(133)-JVS(871)*X(135)&
             &-JVS(872)*X(139)-JVS(873)*X(142)
  X(144) = X(144)-JVS(890)*X(58)-JVS(891)*X(62)-JVS(892)*X(63)-JVS(893)*X(105)-JVS(894)*X(112)-JVS(895)*X(113)-JVS(896)&
             &*X(141)
  X(145) = X(145)-JVS(904)*X(72)-JVS(905)*X(83)-JVS(906)*X(85)-JVS(907)*X(98)-JVS(908)*X(107)
  X(146) = X(146)-JVS(922)*X(141)
  X(147) = X(147)-JVS(932)*X(100)-JVS(933)*X(115)-JVS(934)*X(116)-JVS(935)*X(124)
  X(148) = X(148)-JVS(946)*X(46)-JVS(947)*X(49)-JVS(948)*X(53)-JVS(949)*X(80)-JVS(950)*X(96)-JVS(951)*X(97)-JVS(952)&
             &*X(103)-JVS(953)*X(121)-JVS(954)*X(128)-JVS(955)*X(129)-JVS(956)*X(144)
  X(149) = X(149)-JVS(970)*X(89)
  X(152) = X(152)-JVS(998)*X(78)-JVS(999)*X(99)
  X(153) = X(153)-JVS(1010)*X(89)-JVS(1011)*X(121)-JVS(1012)*X(129)-JVS(1013)*X(141)-JVS(1014)*X(149)
  X(156) = X(156)-JVS(1044)*X(131)-JVS(1045)*X(137)-JVS(1046)*X(141)-JVS(1047)*X(142)-JVS(1048)*X(144)-JVS(1049)*X(146)
  X(158) = X(158)-JVS(1077)*X(88)
  X(159) = X(159)-JVS(1087)*X(93)
  X(160) = X(160)-JVS(1098)*X(79)-JVS(1099)*X(99)
  X(161) = X(161)-JVS(1110)*X(114)
  X(162) = X(162)-JVS(1117)*X(114)-JVS(1118)*X(161)
  X(163) = X(163)-JVS(1128)*X(117)-JVS(1129)*X(154)
  X(164) = X(164)-JVS(1139)*X(1)-JVS(1140)*X(2)-JVS(1141)*X(3)-JVS(1142)*X(44)-JVS(1143)*X(48)-JVS(1144)*X(56)-JVS(1145)&
             &*X(57)-JVS(1146)*X(59)-JVS(1147)*X(67)-JVS(1148)*X(73)-JVS(1149)*X(76)-JVS(1150)*X(95)-JVS(1151)*X(125)&
             &-JVS(1152)*X(134)
  X(165) = X(165)-JVS(1163)*X(115)-JVS(1164)*X(116)-JVS(1165)*X(147)
  X(166) = X(166)-JVS(1177)*X(141)-JVS(1178)*X(161)
  X(167) = X(167)-JVS(1188)*X(44)-JVS(1189)*X(50)-JVS(1190)*X(76)-JVS(1191)*X(95)-JVS(1192)*X(125)-JVS(1193)*X(134)&
             &-JVS(1194)*X(164)
  X(168) = X(168)-JVS(1204)*X(45)-JVS(1205)*X(64)-JVS(1206)*X(81)-JVS(1207)*X(90)-JVS(1208)*X(98)-JVS(1209)*X(111)&
             &-JVS(1210)*X(115)-JVS(1211)*X(116)-JVS(1212)*X(120)-JVS(1213)*X(124)-JVS(1214)*X(125)-JVS(1215)*X(127)&
             &-JVS(1216)*X(128)-JVS(1217)*X(134)-JVS(1218)*X(140)-JVS(1219)*X(141)-JVS(1220)*X(146)-JVS(1221)*X(147)&
             &-JVS(1222)*X(148)-JVS(1223)*X(150)-JVS(1224)*X(161)-JVS(1225)*X(163)-JVS(1226)*X(164)-JVS(1227)*X(165)&
             &-JVS(1228)*X(166)-JVS(1229)*X(167)
  X(169) = X(169)-JVS(1265)*X(124)-JVS(1266)*X(164)-JVS(1267)*X(167)
  X(170) = X(170)-JVS(1278)*X(122)-JVS(1279)*X(131)
  X(171) = X(171)-JVS(1289)*X(122)-JVS(1290)*X(131)-JVS(1291)*X(170)
  X(172) = X(172)-JVS(1300)*X(131)
  X(173) = X(173)-JVS(1309)*X(52)-JVS(1310)*X(87)-JVS(1311)*X(155)
  X(174) = X(174)-JVS(1324)*X(122)
  X(175) = X(175)-JVS(1333)*X(133)-JVS(1334)*X(137)-JVS(1335)*X(149)-JVS(1336)*X(152)-JVS(1337)*X(154)-JVS(1338)*X(158)&
             &-JVS(1339)*X(159)-JVS(1340)*X(160)-JVS(1341)*X(162)-JVS(1342)*X(163)-JVS(1343)*X(166)
  X(176) = X(176)-JVS(1373)*X(114)-JVS(1374)*X(141)-JVS(1375)*X(161)
  X(177) = X(177)-JVS(1383)*X(96)-JVS(1384)*X(104)-JVS(1385)*X(106)-JVS(1386)*X(128)-JVS(1387)*X(132)-JVS(1388)*X(144)&
             &-JVS(1389)*X(146)-JVS(1390)*X(161)-JVS(1391)*X(176)
  X(179) = X(179)-JVS(1415)*X(104)-JVS(1416)*X(112)-JVS(1417)*X(113)
  X(180) = X(180)-JVS(1426)*X(99)-JVS(1427)*X(120)-JVS(1428)*X(145)-JVS(1429)*X(147)-JVS(1430)*X(165)-JVS(1431)*X(167)&
             &-JVS(1432)*X(169)
  X(181) = X(181)-JVS(1449)*X(122)-JVS(1450)*X(131)
  X(182) = X(182)-JVS(1460)*X(106)-JVS(1461)*X(157)
  X(183) = X(183)-JVS(1472)*X(117)-JVS(1473)*X(123)-JVS(1474)*X(154)
  X(184) = X(184)-JVS(1485)*X(49)-JVS(1486)*X(53)-JVS(1487)*X(80)-JVS(1488)*X(93)-JVS(1489)*X(96)-JVS(1490)*X(97)&
             &-JVS(1491)*X(103)-JVS(1492)*X(104)-JVS(1493)*X(106)-JVS(1494)*X(108)-JVS(1495)*X(128)-JVS(1496)*X(135)&
             &-JVS(1497)*X(137)-JVS(1498)*X(139)-JVS(1499)*X(144)-JVS(1500)*X(146)-JVS(1501)*X(153)-JVS(1502)*X(154)&
             &-JVS(1503)*X(155)-JVS(1504)*X(159)-JVS(1505)*X(161)-JVS(1506)*X(166)-JVS(1507)*X(176)-JVS(1508)*X(178)&
             &-JVS(1509)*X(179)-JVS(1510)*X(181)-JVS(1511)*X(182)
  X(186) = X(186)-JVS(1544)*X(105)-JVS(1545)*X(112)-JVS(1546)*X(113)-JVS(1547)*X(141)-JVS(1548)*X(178)
  X(187) = X(187)-JVS(1559)*X(79)-JVS(1560)*X(160)-JVS(1561)*X(174)
  X(188) = X(188)-JVS(1574)*X(105)-JVS(1575)*X(112)-JVS(1576)*X(113)-JVS(1577)*X(157)
  X(189) = X(189)-JVS(1587)*X(102)-JVS(1588)*X(151)-JVS(1589)*X(157)
  X(190) = X(190)-JVS(1603)*X(77)-JVS(1604)*X(120)-JVS(1605)*X(131)-JVS(1606)*X(173)-JVS(1607)*X(185)
  X(191) = X(191)-JVS(1625)*X(136)-JVS(1626)*X(157)-JVS(1627)*X(185)
  X(192) = X(192)-JVS(1637)*X(88)-JVS(1638)*X(96)-JVS(1639)*X(102)-JVS(1640)*X(104)-JVS(1641)*X(110)-JVS(1642)*X(111)&
             &-JVS(1643)*X(123)-JVS(1644)*X(128)-JVS(1645)*X(130)-JVS(1646)*X(132)-JVS(1647)*X(137)-JVS(1648)*X(140)&
             &-JVS(1649)*X(144)-JVS(1650)*X(150)-JVS(1651)*X(151)-JVS(1652)*X(155)-JVS(1653)*X(157)-JVS(1654)*X(158)&
             &-JVS(1655)*X(159)-JVS(1656)*X(161)-JVS(1657)*X(163)-JVS(1658)*X(166)-JVS(1659)*X(170)-JVS(1660)*X(171)&
             &-JVS(1661)*X(172)-JVS(1662)*X(174)-JVS(1663)*X(176)-JVS(1664)*X(178)-JVS(1665)*X(179)-JVS(1666)*X(181)&
             &-JVS(1667)*X(183)-JVS(1668)*X(185)-JVS(1669)*X(186)-JVS(1670)*X(187)-JVS(1671)*X(188)-JVS(1672)*X(189)&
             &-JVS(1673)*X(191)
  X(193) = X(193)-JVS(1692)*X(90)-JVS(1693)*X(91)-JVS(1694)*X(92)-JVS(1695)*X(127)-JVS(1696)*X(128)-JVS(1697)*X(162)&
             &-JVS(1698)*X(172)-JVS(1699)*X(174)-JVS(1700)*X(176)-JVS(1701)*X(178)-JVS(1702)*X(179)-JVS(1703)*X(186)&
             &-JVS(1704)*X(188)-JVS(1705)*X(191)
  X(194) = X(194)-JVS(1716)*X(131)-JVS(1717)*X(157)-JVS(1718)*X(172)
  X(195) = X(195)-JVS(1730)*X(136)-JVS(1731)*X(154)-JVS(1732)*X(162)-JVS(1733)*X(176)-JVS(1734)*X(178)-JVS(1735)*X(181)&
             &-JVS(1736)*X(185)-JVS(1737)*X(188)-JVS(1738)*X(191)-JVS(1739)*X(193)
  X(196) = X(196)-JVS(1751)*X(70)-JVS(1752)*X(71)-JVS(1753)*X(82)-JVS(1754)*X(90)-JVS(1755)*X(98)-JVS(1756)*X(99)&
             &-JVS(1757)*X(101)-JVS(1758)*X(118)-JVS(1759)*X(120)-JVS(1760)*X(124)-JVS(1761)*X(143)-JVS(1762)*X(145)&
             &-JVS(1763)*X(147)-JVS(1764)*X(151)-JVS(1765)*X(156)-JVS(1766)*X(157)-JVS(1767)*X(161)-JVS(1768)*X(165)&
             &-JVS(1769)*X(166)-JVS(1770)*X(167)-JVS(1771)*X(169)-JVS(1772)*X(174)-JVS(1773)*X(175)-JVS(1774)*X(176)&
             &-JVS(1775)*X(177)-JVS(1776)*X(178)-JVS(1777)*X(179)-JVS(1778)*X(180)-JVS(1779)*X(181)-JVS(1780)*X(182)&
             &-JVS(1781)*X(183)-JVS(1782)*X(185)-JVS(1783)*X(186)-JVS(1784)*X(187)-JVS(1785)*X(188)-JVS(1786)*X(189)&
             &-JVS(1787)*X(190)-JVS(1788)*X(191)-JVS(1789)*X(192)-JVS(1790)*X(193)-JVS(1791)*X(194)-JVS(1792)*X(195)
  X(197) = X(197)-JVS(1813)*X(4)-JVS(1814)*X(46)-JVS(1815)*X(53)-JVS(1816)*X(69)-JVS(1817)*X(80)-JVS(1818)*X(81)&
             &-JVS(1819)*X(88)-JVS(1820)*X(93)-JVS(1821)*X(96)-JVS(1822)*X(101)-JVS(1823)*X(102)-JVS(1824)*X(105)-JVS(1825)&
             &*X(106)-JVS(1826)*X(108)-JVS(1827)*X(112)-JVS(1828)*X(113)-JVS(1829)*X(117)-JVS(1830)*X(119)-JVS(1831)*X(121)&
             &-JVS(1832)*X(123)-JVS(1833)*X(129)-JVS(1834)*X(130)-JVS(1835)*X(131)-JVS(1836)*X(137)-JVS(1837)*X(141)&
             &-JVS(1838)*X(142)-JVS(1839)*X(144)-JVS(1840)*X(146)-JVS(1841)*X(148)-JVS(1842)*X(149)-JVS(1843)*X(151)&
             &-JVS(1844)*X(152)-JVS(1845)*X(153)-JVS(1846)*X(154)-JVS(1847)*X(155)-JVS(1848)*X(157)-JVS(1849)*X(158)&
             &-JVS(1850)*X(159)-JVS(1851)*X(160)-JVS(1852)*X(161)-JVS(1853)*X(162)-JVS(1854)*X(163)-JVS(1855)*X(166)&
             &-JVS(1856)*X(170)-JVS(1857)*X(171)-JVS(1858)*X(172)-JVS(1859)*X(173)-JVS(1860)*X(174)-JVS(1861)*X(176)&
             &-JVS(1862)*X(177)-JVS(1863)*X(178)-JVS(1864)*X(179)-JVS(1865)*X(181)-JVS(1866)*X(182)-JVS(1867)*X(183)&
             &-JVS(1868)*X(185)-JVS(1869)*X(186)-JVS(1870)*X(187)-JVS(1871)*X(188)-JVS(1872)*X(189)-JVS(1873)*X(190)&
             &-JVS(1874)*X(191)-JVS(1875)*X(192)-JVS(1876)*X(193)-JVS(1877)*X(194)-JVS(1878)*X(195)
  X(198) = X(198)-JVS(1898)*X(72)-JVS(1899)*X(84)-JVS(1900)*X(85)-JVS(1901)*X(145)-JVS(1902)*X(165)-JVS(1903)*X(167)&
             &-JVS(1904)*X(169)-JVS(1905)*X(180)-JVS(1906)*X(187)-JVS(1907)*X(190)-JVS(1908)*X(191)-JVS(1909)*X(193)&
             &-JVS(1910)*X(194)-JVS(1911)*X(195)-JVS(1912)*X(196)-JVS(1913)*X(197)
  X(199) = X(199)-JVS(1932)*X(105)-JVS(1933)*X(112)-JVS(1934)*X(113)-JVS(1935)*X(126)-JVS(1936)*X(157)-JVS(1937)*X(188)&
             &-JVS(1938)*X(191)
  X(200) = X(200)-JVS(1951)*X(91)-JVS(1952)*X(106)-JVS(1953)*X(109)-JVS(1954)*X(110)-JVS(1955)*X(122)-JVS(1956)*X(136)&
             &-JVS(1957)*X(140)-JVS(1958)*X(163)-JVS(1959)*X(170)-JVS(1960)*X(171)-JVS(1961)*X(172)-JVS(1962)*X(174)&
             &-JVS(1963)*X(179)-JVS(1964)*X(181)-JVS(1965)*X(182)-JVS(1966)*X(183)-JVS(1967)*X(185)-JVS(1968)*X(186)&
             &-JVS(1969)*X(188)-JVS(1970)*X(189)-JVS(1971)*X(191)-JVS(1972)*X(193)-JVS(1973)*X(195)-JVS(1974)*X(199)
  X(201) = X(201)-JVS(1988)*X(77)-JVS(1989)*X(87)-JVS(1990)*X(88)-JVS(1991)*X(118)-JVS(1992)*X(133)-JVS(1993)*X(149)&
             &-JVS(1994)*X(155)-JVS(1995)*X(158)-JVS(1996)*X(162)-JVS(1997)*X(173)-JVS(1998)*X(176)-JVS(1999)*X(178)&
             &-JVS(2000)*X(181)-JVS(2001)*X(185)-JVS(2002)*X(188)-JVS(2003)*X(190)-JVS(2004)*X(191)-JVS(2005)*X(193)&
             &-JVS(2006)*X(194)-JVS(2007)*X(195)-JVS(2008)*X(199)-JVS(2009)*X(200)
  X(202) = X(202)-JVS(2025)*X(78)-JVS(2026)*X(89)-JVS(2027)*X(91)-JVS(2028)*X(92)-JVS(2029)*X(114)-JVS(2030)*X(122)&
             &-JVS(2031)*X(127)-JVS(2032)*X(128)-JVS(2033)*X(136)-JVS(2034)*X(138)-JVS(2035)*X(149)-JVS(2036)*X(150)&
             &-JVS(2037)*X(152)-JVS(2038)*X(154)-JVS(2039)*X(158)-JVS(2040)*X(160)-JVS(2041)*X(161)-JVS(2042)*X(162)&
             &-JVS(2043)*X(163)-JVS(2044)*X(170)-JVS(2045)*X(171)-JVS(2046)*X(172)-JVS(2047)*X(174)-JVS(2048)*X(176)&
             &-JVS(2049)*X(178)-JVS(2050)*X(179)-JVS(2051)*X(181)-JVS(2052)*X(182)-JVS(2053)*X(183)-JVS(2054)*X(185)&
             &-JVS(2055)*X(186)-JVS(2056)*X(188)-JVS(2057)*X(189)-JVS(2058)*X(191)-JVS(2059)*X(193)-JVS(2060)*X(194)&
             &-JVS(2061)*X(195)-JVS(2062)*X(199)-JVS(2063)*X(200)
  X(203) = X(203)-JVS(2078)*X(3)-JVS(2079)*X(42)-JVS(2080)*X(43)-JVS(2081)*X(54)-JVS(2082)*X(55)-JVS(2083)*X(57)&
             &-JVS(2084)*X(73)-JVS(2085)*X(94)-JVS(2086)*X(95)-JVS(2087)*X(99)-JVS(2088)*X(100)-JVS(2089)*X(115)-JVS(2090)&
             &*X(116)-JVS(2091)*X(120)-JVS(2092)*X(124)-JVS(2093)*X(125)-JVS(2094)*X(134)-JVS(2095)*X(145)-JVS(2096)*X(147)&
             &-JVS(2097)*X(164)-JVS(2098)*X(165)-JVS(2099)*X(167)-JVS(2100)*X(169)-JVS(2101)*X(180)-JVS(2102)*X(187)&
             &-JVS(2103)*X(193)-JVS(2104)*X(194)-JVS(2105)*X(195)-JVS(2106)*X(196)-JVS(2107)*X(197)-JVS(2108)*X(198)&
             &-JVS(2109)*X(199)-JVS(2110)*X(200)-JVS(2111)*X(201)-JVS(2112)*X(202)
  X(204) = X(204)-JVS(2126)*X(51)-JVS(2127)*X(52)-JVS(2128)*X(54)-JVS(2129)*X(68)-JVS(2130)*X(69)-JVS(2131)*X(73)&
             &-JVS(2132)*X(74)-JVS(2133)*X(75)-JVS(2134)*X(76)-JVS(2135)*X(83)-JVS(2136)*X(86)-JVS(2137)*X(89)-JVS(2138)&
             &*X(97)-JVS(2139)*X(98)-JVS(2140)*X(103)-JVS(2141)*X(111)-JVS(2142)*X(114)-JVS(2143)*X(119)-JVS(2144)*X(123)&
             &-JVS(2145)*X(124)-JVS(2146)*X(125)-JVS(2147)*X(126)-JVS(2148)*X(127)-JVS(2149)*X(128)-JVS(2150)*X(129)&
             &-JVS(2151)*X(130)-JVS(2152)*X(132)-JVS(2153)*X(133)-JVS(2154)*X(134)-JVS(2155)*X(135)-JVS(2156)*X(136)&
             &-JVS(2157)*X(137)-JVS(2158)*X(139)-JVS(2159)*X(140)-JVS(2160)*X(141)-JVS(2161)*X(142)-JVS(2162)*X(144)&
             &-JVS(2163)*X(146)-JVS(2164)*X(149)-JVS(2165)*X(150)-JVS(2166)*X(151)-JVS(2167)*X(152)-JVS(2168)*X(153)&
             &-JVS(2169)*X(154)-JVS(2170)*X(155)-JVS(2171)*X(157)-JVS(2172)*X(158)-JVS(2173)*X(159)-JVS(2174)*X(160)&
             &-JVS(2175)*X(161)-JVS(2176)*X(162)-JVS(2177)*X(163)-JVS(2178)*X(164)-JVS(2179)*X(165)-JVS(2180)*X(166)&
             &-JVS(2181)*X(167)-JVS(2182)*X(168)-JVS(2183)*X(169)-JVS(2184)*X(170)-JVS(2185)*X(171)-JVS(2186)*X(172)&
             &-JVS(2187)*X(173)-JVS(2188)*X(174)-JVS(2189)*X(176)-JVS(2190)*X(177)-JVS(2191)*X(178)-JVS(2192)*X(179)&
             &-JVS(2193)*X(180)-JVS(2194)*X(181)-JVS(2195)*X(182)-JVS(2196)*X(183)-JVS(2197)*X(184)-JVS(2198)*X(185)&
             &-JVS(2199)*X(186)-JVS(2200)*X(187)-JVS(2201)*X(188)-JVS(2202)*X(189)-JVS(2203)*X(190)-JVS(2204)*X(191)&
             &-JVS(2205)*X(192)-JVS(2206)*X(193)-JVS(2207)*X(194)-JVS(2208)*X(195)-JVS(2209)*X(196)-JVS(2210)*X(197)&
             &-JVS(2211)*X(198)-JVS(2212)*X(199)-JVS(2213)*X(200)-JVS(2214)*X(201)-JVS(2215)*X(202)-JVS(2216)*X(203)
  X(205) = X(205)-JVS(2229)*X(85)-JVS(2230)*X(109)-JVS(2231)*X(115)-JVS(2232)*X(116)-JVS(2233)*X(122)-JVS(2234)*X(123)&
             &-JVS(2235)*X(131)-JVS(2236)*X(141)-JVS(2237)*X(147)-JVS(2238)*X(150)-JVS(2239)*X(155)-JVS(2240)*X(157)&
             &-JVS(2241)*X(164)-JVS(2242)*X(165)-JVS(2243)*X(167)-JVS(2244)*X(169)-JVS(2245)*X(170)-JVS(2246)*X(171)&
             &-JVS(2247)*X(172)-JVS(2248)*X(173)-JVS(2249)*X(174)-JVS(2250)*X(178)-JVS(2251)*X(179)-JVS(2252)*X(180)&
             &-JVS(2253)*X(183)-JVS(2254)*X(185)-JVS(2255)*X(186)-JVS(2256)*X(187)-JVS(2257)*X(188)-JVS(2258)*X(191)&
             &-JVS(2259)*X(193)-JVS(2260)*X(194)-JVS(2261)*X(195)-JVS(2262)*X(196)-JVS(2263)*X(197)-JVS(2264)*X(198)&
             &-JVS(2265)*X(199)-JVS(2266)*X(200)-JVS(2267)*X(201)-JVS(2268)*X(202)-JVS(2269)*X(203)-JVS(2270)*X(204)
  X(206) = X(206)-JVS(2282)*X(59)-JVS(2283)*X(60)-JVS(2284)*X(61)-JVS(2285)*X(65)-JVS(2286)*X(74)-JVS(2287)*X(76)&
             &-JVS(2288)*X(80)-JVS(2289)*X(97)-JVS(2290)*X(103)-JVS(2291)*X(121)-JVS(2292)*X(126)-JVS(2293)*X(127)-JVS(2294)&
             &*X(128)-JVS(2295)*X(129)-JVS(2296)*X(132)-JVS(2297)*X(133)-JVS(2298)*X(135)-JVS(2299)*X(137)-JVS(2300)*X(139)&
             &-JVS(2301)*X(142)-JVS(2302)*X(144)-JVS(2303)*X(149)-JVS(2304)*X(151)-JVS(2305)*X(152)-JVS(2306)*X(154)&
             &-JVS(2307)*X(155)-JVS(2308)*X(157)-JVS(2309)*X(158)-JVS(2310)*X(159)-JVS(2311)*X(160)-JVS(2312)*X(161)&
             &-JVS(2313)*X(162)-JVS(2314)*X(163)-JVS(2315)*X(164)-JVS(2316)*X(166)-JVS(2317)*X(167)-JVS(2318)*X(169)&
             &-JVS(2319)*X(170)-JVS(2320)*X(171)-JVS(2321)*X(172)-JVS(2322)*X(173)-JVS(2323)*X(174)-JVS(2324)*X(176)&
             &-JVS(2325)*X(178)-JVS(2326)*X(179)-JVS(2327)*X(181)-JVS(2328)*X(182)-JVS(2329)*X(183)-JVS(2330)*X(185)&
             &-JVS(2331)*X(186)-JVS(2332)*X(187)-JVS(2333)*X(188)-JVS(2334)*X(189)-JVS(2335)*X(190)-JVS(2336)*X(191)&
             &-JVS(2337)*X(193)-JVS(2338)*X(194)-JVS(2339)*X(195)-JVS(2340)*X(196)-JVS(2341)*X(197)-JVS(2342)*X(198)&
             &-JVS(2343)*X(199)-JVS(2344)*X(200)-JVS(2345)*X(201)-JVS(2346)*X(202)-JVS(2347)*X(203)-JVS(2348)*X(204)&
             &-JVS(2349)*X(205)
  X(207) = X(207)-JVS(2360)*X(81)-JVS(2361)*X(126)-JVS(2362)*X(132)-JVS(2363)*X(133)-JVS(2364)*X(135)-JVS(2365)*X(139)&
             &-JVS(2366)*X(142)-JVS(2367)*X(151)-JVS(2368)*X(157)-JVS(2369)*X(186)-JVS(2370)*X(188)-JVS(2371)*X(191)&
             &-JVS(2372)*X(194)-JVS(2373)*X(199)-JVS(2374)*X(203)-JVS(2375)*X(204)-JVS(2376)*X(205)-JVS(2377)*X(206)
  X(208) = X(208)-JVS(2387)*X(66)-JVS(2388)*X(86)-JVS(2389)*X(93)-JVS(2390)*X(96)-JVS(2391)*X(106)-JVS(2392)*X(108)&
             &-JVS(2393)*X(117)-JVS(2394)*X(123)-JVS(2395)*X(130)-JVS(2396)*X(139)-JVS(2397)*X(144)-JVS(2398)*X(146)&
             &-JVS(2399)*X(149)-JVS(2400)*X(152)-JVS(2401)*X(154)-JVS(2402)*X(155)-JVS(2403)*X(157)-JVS(2404)*X(158)&
             &-JVS(2405)*X(159)-JVS(2406)*X(160)-JVS(2407)*X(161)-JVS(2408)*X(162)-JVS(2409)*X(163)-JVS(2410)*X(170)&
             &-JVS(2411)*X(171)-JVS(2412)*X(172)-JVS(2413)*X(173)-JVS(2414)*X(174)-JVS(2415)*X(176)-JVS(2416)*X(178)&
             &-JVS(2417)*X(179)-JVS(2418)*X(181)-JVS(2419)*X(182)-JVS(2420)*X(183)-JVS(2421)*X(184)-JVS(2422)*X(185)&
             &-JVS(2423)*X(186)-JVS(2424)*X(187)-JVS(2425)*X(188)-JVS(2426)*X(189)-JVS(2427)*X(190)-JVS(2428)*X(191)&
             &-JVS(2429)*X(192)-JVS(2430)*X(193)-JVS(2431)*X(194)-JVS(2432)*X(195)-JVS(2433)*X(199)-JVS(2434)*X(200)&
             &-JVS(2435)*X(201)-JVS(2436)*X(202)-JVS(2437)*X(203)-JVS(2438)*X(204)-JVS(2439)*X(205)-JVS(2440)*X(206)&
             &-JVS(2441)*X(207)
  X(209) = X(209)-JVS(2450)*X(105)-JVS(2451)*X(112)-JVS(2452)*X(113)-JVS(2453)*X(131)-JVS(2454)*X(151)-JVS(2455)*X(157)&
             &-JVS(2456)*X(172)-JVS(2457)*X(188)-JVS(2458)*X(191)-JVS(2459)*X(204)-JVS(2460)*X(205)-JVS(2461)*X(206)&
             &-JVS(2462)*X(207)-JVS(2463)*X(208)
  X(210) = X(210)-JVS(2471)*X(69)-JVS(2472)*X(75)-JVS(2473)*X(80)-JVS(2474)*X(81)-JVS(2475)*X(86)-JVS(2476)*X(90)&
             &-JVS(2477)*X(98)-JVS(2478)*X(111)-JVS(2479)*X(120)-JVS(2480)*X(122)-JVS(2481)*X(123)-JVS(2482)*X(124)&
             &-JVS(2483)*X(125)-JVS(2484)*X(126)-JVS(2485)*X(129)-JVS(2486)*X(130)-JVS(2487)*X(131)-JVS(2488)*X(132)&
             &-JVS(2489)*X(133)-JVS(2490)*X(134)-JVS(2491)*X(135)-JVS(2492)*X(137)-JVS(2493)*X(139)-JVS(2494)*X(140)&
             &-JVS(2495)*X(142)-JVS(2496)*X(146)-JVS(2497)*X(148)-JVS(2498)*X(150)-JVS(2499)*X(151)-JVS(2500)*X(155)&
             &-JVS(2501)*X(157)-JVS(2502)*X(161)-JVS(2503)*X(164)-JVS(2504)*X(165)-JVS(2505)*X(166)-JVS(2506)*X(167)&
             &-JVS(2507)*X(168)-JVS(2508)*X(169)-JVS(2509)*X(170)-JVS(2510)*X(171)-JVS(2511)*X(172)-JVS(2512)*X(174)&
             &-JVS(2513)*X(176)-JVS(2514)*X(177)-JVS(2515)*X(178)-JVS(2516)*X(179)-JVS(2517)*X(180)-JVS(2518)*X(182)&
             &-JVS(2519)*X(183)-JVS(2520)*X(184)-JVS(2521)*X(185)-JVS(2522)*X(186)-JVS(2523)*X(187)-JVS(2524)*X(188)&
             &-JVS(2525)*X(189)-JVS(2526)*X(191)-JVS(2527)*X(192)-JVS(2528)*X(193)-JVS(2529)*X(194)-JVS(2530)*X(195)&
             &-JVS(2531)*X(196)-JVS(2532)*X(197)-JVS(2533)*X(198)-JVS(2534)*X(199)-JVS(2535)*X(200)-JVS(2536)*X(201)&
             &-JVS(2537)*X(202)-JVS(2538)*X(203)-JVS(2539)*X(204)-JVS(2540)*X(205)-JVS(2541)*X(206)-JVS(2542)*X(207)&
             &-JVS(2543)*X(208)-JVS(2544)*X(209)
  X(211) = X(211)-JVS(2551)*X(70)-JVS(2552)*X(71)-JVS(2553)*X(82)-JVS(2554)*X(96)-JVS(2555)*X(97)-JVS(2556)*X(102)&
             &-JVS(2557)*X(104)-JVS(2558)*X(108)-JVS(2559)*X(110)-JVS(2560)*X(119)-JVS(2561)*X(122)-JVS(2562)*X(123)&
             &-JVS(2563)*X(126)-JVS(2564)*X(130)-JVS(2565)*X(131)-JVS(2566)*X(132)-JVS(2567)*X(133)-JVS(2568)*X(135)&
             &-JVS(2569)*X(139)-JVS(2570)*X(141)-JVS(2571)*X(144)-JVS(2572)*X(148)-JVS(2573)*X(151)-JVS(2574)*X(153)&
             &-JVS(2575)*X(154)-JVS(2576)*X(155)-JVS(2577)*X(157)-JVS(2578)*X(161)-JVS(2579)*X(166)-JVS(2580)*X(176)&
             &-JVS(2581)*X(177)-JVS(2582)*X(178)-JVS(2583)*X(179)-JVS(2584)*X(182)-JVS(2585)*X(183)-JVS(2586)*X(184)&
             &-JVS(2587)*X(185)-JVS(2588)*X(186)-JVS(2589)*X(187)-JVS(2590)*X(188)-JVS(2591)*X(189)-JVS(2592)*X(191)&
             &-JVS(2593)*X(192)-JVS(2594)*X(193)-JVS(2595)*X(194)-JVS(2596)*X(195)-JVS(2597)*X(197)-JVS(2598)*X(198)&
             &-JVS(2599)*X(199)-JVS(2600)*X(200)-JVS(2601)*X(201)-JVS(2602)*X(202)-JVS(2603)*X(203)-JVS(2604)*X(204)&
             &-JVS(2605)*X(205)-JVS(2606)*X(206)-JVS(2607)*X(207)-JVS(2608)*X(208)-JVS(2609)*X(209)-JVS(2610)*X(210)
  X(212) = X(212)-JVS(2616)*X(48)-JVS(2617)*X(55)-JVS(2618)*X(66)-JVS(2619)*X(69)-JVS(2620)*X(81)-JVS(2621)*X(82)&
             &-JVS(2622)*X(86)-JVS(2623)*X(101)-JVS(2624)*X(121)-JVS(2625)*X(129)-JVS(2626)*X(130)-JVS(2627)*X(139)&
             &-JVS(2628)*X(149)-JVS(2629)*X(152)-JVS(2630)*X(153)-JVS(2631)*X(154)-JVS(2632)*X(155)-JVS(2633)*X(157)&
             &-JVS(2634)*X(158)-JVS(2635)*X(159)-JVS(2636)*X(160)-JVS(2637)*X(161)-JVS(2638)*X(162)-JVS(2639)*X(163)&
             &-JVS(2640)*X(170)-JVS(2641)*X(171)-JVS(2642)*X(172)-JVS(2643)*X(173)-JVS(2644)*X(174)-JVS(2645)*X(175)&
             &-JVS(2646)*X(176)-JVS(2647)*X(178)-JVS(2648)*X(179)-JVS(2649)*X(181)-JVS(2650)*X(182)-JVS(2651)*X(183)&
             &-JVS(2652)*X(185)-JVS(2653)*X(186)-JVS(2654)*X(187)-JVS(2655)*X(188)-JVS(2656)*X(189)-JVS(2657)*X(190)&
             &-JVS(2658)*X(191)-JVS(2659)*X(192)-JVS(2660)*X(193)-JVS(2661)*X(194)-JVS(2662)*X(195)-JVS(2663)*X(198)&
             &-JVS(2664)*X(199)-JVS(2665)*X(200)-JVS(2666)*X(201)-JVS(2667)*X(202)-JVS(2668)*X(203)-JVS(2669)*X(204)&
             &-JVS(2670)*X(205)-JVS(2671)*X(206)-JVS(2672)*X(207)-JVS(2673)*X(208)-JVS(2674)*X(209)-JVS(2675)*X(210)&
             &-JVS(2676)*X(211)
  X(213) = X(213)-JVS(2681)*X(42)-JVS(2682)*X(43)-JVS(2683)*X(48)-JVS(2684)*X(49)-JVS(2685)*X(55)-JVS(2686)*X(56)&
             &-JVS(2687)*X(58)-JVS(2688)*X(62)-JVS(2689)*X(63)-JVS(2690)*X(66)-JVS(2691)*X(70)-JVS(2692)*X(71)-JVS(2693)&
             &*X(72)-JVS(2694)*X(74)-JVS(2695)*X(75)-JVS(2696)*X(77)-JVS(2697)*X(78)-JVS(2698)*X(79)-JVS(2699)*X(81)&
             &-JVS(2700)*X(82)-JVS(2701)*X(83)-JVS(2702)*X(85)-JVS(2703)*X(87)-JVS(2704)*X(88)-JVS(2705)*X(89)-JVS(2706)&
             &*X(90)-JVS(2707)*X(91)-JVS(2708)*X(92)-JVS(2709)*X(93)-JVS(2710)*X(95)-JVS(2711)*X(96)-JVS(2712)*X(97)&
             &-JVS(2713)*X(98)-JVS(2714)*X(99)-JVS(2715)*X(100)-JVS(2716)*X(101)-JVS(2717)*X(102)-JVS(2718)*X(103)-JVS(2719)&
             &*X(104)-JVS(2720)*X(105)-JVS(2721)*X(106)-JVS(2722)*X(107)-JVS(2723)*X(108)-JVS(2724)*X(109)-JVS(2725)*X(110)&
             &-JVS(2726)*X(111)-JVS(2727)*X(112)-JVS(2728)*X(113)-JVS(2729)*X(114)-JVS(2730)*X(115)-JVS(2731)*X(116)&
             &-JVS(2732)*X(117)-JVS(2733)*X(118)-JVS(2734)*X(119)-JVS(2735)*X(120)-JVS(2736)*X(122)-JVS(2737)*X(123)&
             &-JVS(2738)*X(124)-JVS(2739)*X(127)-JVS(2740)*X(128)-JVS(2741)*X(130)-JVS(2742)*X(131)-JVS(2743)*X(134)&
             &-JVS(2744)*X(136)-JVS(2745)*X(137)-JVS(2746)*X(138)-JVS(2747)*X(140)-JVS(2748)*X(141)-JVS(2749)*X(143)&
             &-JVS(2750)*X(144)-JVS(2751)*X(145)-JVS(2752)*X(146)-JVS(2753)*X(147)-JVS(2754)*X(148)-JVS(2755)*X(149)&
             &-JVS(2756)*X(150)-JVS(2757)*X(151)-JVS(2758)*X(152)-JVS(2759)*X(153)-JVS(2760)*X(154)-JVS(2761)*X(155)&
             &-JVS(2762)*X(156)-JVS(2763)*X(157)-JVS(2764)*X(158)-JVS(2765)*X(159)-JVS(2766)*X(160)-JVS(2767)*X(161)&
             &-JVS(2768)*X(162)-JVS(2769)*X(163)-JVS(2770)*X(164)-JVS(2771)*X(165)-JVS(2772)*X(166)-JVS(2773)*X(167)&
             &-JVS(2774)*X(168)-JVS(2775)*X(169)-JVS(2776)*X(170)-JVS(2777)*X(171)-JVS(2778)*X(172)-JVS(2779)*X(173)&
             &-JVS(2780)*X(174)-JVS(2781)*X(175)-JVS(2782)*X(176)-JVS(2783)*X(177)-JVS(2784)*X(178)-JVS(2785)*X(179)&
             &-JVS(2786)*X(180)-JVS(2787)*X(181)-JVS(2788)*X(182)-JVS(2789)*X(183)-JVS(2790)*X(184)-JVS(2791)*X(185)&
             &-JVS(2792)*X(186)-JVS(2793)*X(187)-JVS(2794)*X(188)-JVS(2795)*X(189)-JVS(2796)*X(190)-JVS(2797)*X(191)&
             &-JVS(2798)*X(192)-JVS(2799)*X(193)-JVS(2800)*X(194)-JVS(2801)*X(195)-JVS(2802)*X(196)-JVS(2803)*X(197)&
             &-JVS(2804)*X(198)-JVS(2805)*X(199)-JVS(2806)*X(200)-JVS(2807)*X(201)-JVS(2808)*X(202)-JVS(2809)*X(203)&
             &-JVS(2810)*X(204)-JVS(2811)*X(205)-JVS(2812)*X(206)-JVS(2813)*X(207)-JVS(2814)*X(208)-JVS(2815)*X(209)&
             &-JVS(2816)*X(210)-JVS(2817)*X(211)-JVS(2818)*X(212)
  X(214) = X(214)-JVS(2822)*X(55)-JVS(2823)*X(60)-JVS(2824)*X(61)-JVS(2825)*X(65)-JVS(2826)*X(69)-JVS(2827)*X(70)&
             &-JVS(2828)*X(71)-JVS(2829)*X(75)-JVS(2830)*X(77)-JVS(2831)*X(78)-JVS(2832)*X(79)-JVS(2833)*X(80)-JVS(2834)&
             &*X(82)-JVS(2835)*X(87)-JVS(2836)*X(88)-JVS(2837)*X(89)-JVS(2838)*X(91)-JVS(2839)*X(92)-JVS(2840)*X(96)&
             &-JVS(2841)*X(97)-JVS(2842)*X(101)-JVS(2843)*X(102)-JVS(2844)*X(103)-JVS(2845)*X(104)-JVS(2846)*X(105)&
             &-JVS(2847)*X(106)-JVS(2848)*X(108)-JVS(2849)*X(109)-JVS(2850)*X(110)-JVS(2851)*X(112)-JVS(2852)*X(113)&
             &-JVS(2853)*X(114)-JVS(2854)*X(118)-JVS(2855)*X(119)-JVS(2856)*X(121)-JVS(2857)*X(122)-JVS(2858)*X(127)&
             &-JVS(2859)*X(128)-JVS(2860)*X(129)-JVS(2861)*X(130)-JVS(2862)*X(131)-JVS(2863)*X(136)-JVS(2864)*X(137)&
             &-JVS(2865)*X(138)-JVS(2866)*X(141)-JVS(2867)*X(143)-JVS(2868)*X(144)-JVS(2869)*X(148)-JVS(2870)*X(149)&
             &-JVS(2871)*X(151)-JVS(2872)*X(152)-JVS(2873)*X(154)-JVS(2874)*X(155)-JVS(2875)*X(156)-JVS(2876)*X(157)&
             &-JVS(2877)*X(158)-JVS(2878)*X(159)-JVS(2879)*X(160)-JVS(2880)*X(161)-JVS(2881)*X(162)-JVS(2882)*X(163)&
             &-JVS(2883)*X(164)-JVS(2884)*X(166)-JVS(2885)*X(167)-JVS(2886)*X(169)-JVS(2887)*X(170)-JVS(2888)*X(171)&
             &-JVS(2889)*X(172)-JVS(2890)*X(173)-JVS(2891)*X(174)-JVS(2892)*X(176)-JVS(2893)*X(177)-JVS(2894)*X(178)&
             &-JVS(2895)*X(179)-JVS(2896)*X(181)-JVS(2897)*X(182)-JVS(2898)*X(183)-JVS(2899)*X(184)-JVS(2900)*X(185)&
             &-JVS(2901)*X(186)-JVS(2902)*X(187)-JVS(2903)*X(188)-JVS(2904)*X(189)-JVS(2905)*X(190)-JVS(2906)*X(191)&
             &-JVS(2907)*X(192)-JVS(2908)*X(193)-JVS(2909)*X(194)-JVS(2910)*X(195)-JVS(2911)*X(196)-JVS(2912)*X(197)&
             &-JVS(2913)*X(198)-JVS(2914)*X(199)-JVS(2915)*X(200)-JVS(2916)*X(201)-JVS(2917)*X(202)-JVS(2918)*X(203)&
             &-JVS(2919)*X(204)-JVS(2920)*X(205)-JVS(2921)*X(206)-JVS(2922)*X(207)-JVS(2923)*X(208)-JVS(2924)*X(209)&
             &-JVS(2925)*X(210)-JVS(2926)*X(211)-JVS(2927)*X(212)-JVS(2928)*X(213)
  X(215) = X(215)-JVS(2931)*X(2)-JVS(2932)*X(67)-JVS(2933)*X(70)-JVS(2934)*X(71)-JVS(2935)*X(72)-JVS(2936)*X(73)&
             &-JVS(2937)*X(82)-JVS(2938)*X(83)-JVS(2939)*X(84)-JVS(2940)*X(90)-JVS(2941)*X(94)-JVS(2942)*X(95)-JVS(2943)&
             &*X(98)-JVS(2944)*X(99)-JVS(2945)*X(101)-JVS(2946)*X(107)-JVS(2947)*X(115)-JVS(2948)*X(116)-JVS(2949)*X(118)&
             &-JVS(2950)*X(120)-JVS(2951)*X(124)-JVS(2952)*X(125)-JVS(2953)*X(134)-JVS(2954)*X(143)-JVS(2955)*X(145)&
             &-JVS(2956)*X(147)-JVS(2957)*X(151)-JVS(2958)*X(156)-JVS(2959)*X(157)-JVS(2960)*X(161)-JVS(2961)*X(164)&
             &-JVS(2962)*X(165)-JVS(2963)*X(166)-JVS(2964)*X(167)-JVS(2965)*X(169)-JVS(2966)*X(174)-JVS(2967)*X(175)&
             &-JVS(2968)*X(176)-JVS(2969)*X(177)-JVS(2970)*X(178)-JVS(2971)*X(179)-JVS(2972)*X(180)-JVS(2973)*X(181)&
             &-JVS(2974)*X(182)-JVS(2975)*X(183)-JVS(2976)*X(185)-JVS(2977)*X(186)-JVS(2978)*X(187)-JVS(2979)*X(188)&
             &-JVS(2980)*X(189)-JVS(2981)*X(190)-JVS(2982)*X(191)-JVS(2983)*X(192)-JVS(2984)*X(193)-JVS(2985)*X(194)&
             &-JVS(2986)*X(195)-JVS(2987)*X(196)-JVS(2988)*X(197)-JVS(2989)*X(198)-JVS(2990)*X(199)-JVS(2991)*X(200)&
             &-JVS(2992)*X(201)-JVS(2993)*X(202)-JVS(2994)*X(203)-JVS(2995)*X(204)-JVS(2996)*X(205)-JVS(2997)*X(206)&
             &-JVS(2998)*X(207)-JVS(2999)*X(208)-JVS(3000)*X(209)-JVS(3001)*X(210)-JVS(3002)*X(211)-JVS(3003)*X(212)&
             &-JVS(3004)*X(213)-JVS(3005)*X(214)
  X(215) = X(215)/JVS(3006)
  X(214) = (X(214)-JVS(2930)*X(215))/(JVS(2929))
  X(213) = (X(213)-JVS(2820)*X(214)-JVS(2821)*X(215))/(JVS(2819))
  X(212) = (X(212)-JVS(2678)*X(213)-JVS(2679)*X(214)-JVS(2680)*X(215))/(JVS(2677))
  X(211) = (X(211)-JVS(2612)*X(212)-JVS(2613)*X(213)-JVS(2614)*X(214)-JVS(2615)*X(215))/(JVS(2611))
  X(210) = (X(210)-JVS(2546)*X(211)-JVS(2547)*X(212)-JVS(2548)*X(213)-JVS(2549)*X(214)-JVS(2550)*X(215))/(JVS(2545))
  X(209) = (X(209)-JVS(2465)*X(210)-JVS(2466)*X(211)-JVS(2467)*X(212)-JVS(2468)*X(213)-JVS(2469)*X(214)-JVS(2470)&
             &*X(215))/(JVS(2464))
  X(208) = (X(208)-JVS(2443)*X(209)-JVS(2444)*X(210)-JVS(2445)*X(211)-JVS(2446)*X(212)-JVS(2447)*X(213)-JVS(2448)*X(214)&
             &-JVS(2449)*X(215))/(JVS(2442))
  X(207) = (X(207)-JVS(2379)*X(208)-JVS(2380)*X(209)-JVS(2381)*X(210)-JVS(2382)*X(211)-JVS(2383)*X(212)-JVS(2384)*X(213)&
             &-JVS(2385)*X(214)-JVS(2386)*X(215))/(JVS(2378))
  X(206) = (X(206)-JVS(2351)*X(207)-JVS(2352)*X(208)-JVS(2353)*X(209)-JVS(2354)*X(210)-JVS(2355)*X(211)-JVS(2356)*X(212)&
             &-JVS(2357)*X(213)-JVS(2358)*X(214)-JVS(2359)*X(215))/(JVS(2350))
  X(205) = (X(205)-JVS(2272)*X(206)-JVS(2273)*X(207)-JVS(2274)*X(208)-JVS(2275)*X(209)-JVS(2276)*X(210)-JVS(2277)*X(211)&
             &-JVS(2278)*X(212)-JVS(2279)*X(213)-JVS(2280)*X(214)-JVS(2281)*X(215))/(JVS(2271))
  X(204) = (X(204)-JVS(2218)*X(205)-JVS(2219)*X(206)-JVS(2220)*X(207)-JVS(2221)*X(208)-JVS(2222)*X(209)-JVS(2223)*X(210)&
             &-JVS(2224)*X(211)-JVS(2225)*X(212)-JVS(2226)*X(213)-JVS(2227)*X(214)-JVS(2228)*X(215))/(JVS(2217))
  X(203) = (X(203)-JVS(2114)*X(204)-JVS(2115)*X(205)-JVS(2116)*X(206)-JVS(2117)*X(207)-JVS(2118)*X(208)-JVS(2119)*X(209)&
             &-JVS(2120)*X(210)-JVS(2121)*X(211)-JVS(2122)*X(212)-JVS(2123)*X(213)-JVS(2124)*X(214)-JVS(2125)*X(215))&
             &/(JVS(2113))
  X(202) = (X(202)-JVS(2065)*X(203)-JVS(2066)*X(204)-JVS(2067)*X(205)-JVS(2068)*X(206)-JVS(2069)*X(207)-JVS(2070)*X(208)&
             &-JVS(2071)*X(209)-JVS(2072)*X(210)-JVS(2073)*X(211)-JVS(2074)*X(212)-JVS(2075)*X(213)-JVS(2076)*X(214)&
             &-JVS(2077)*X(215))/(JVS(2064))
  X(201) = (X(201)-JVS(2011)*X(202)-JVS(2012)*X(203)-JVS(2013)*X(204)-JVS(2014)*X(205)-JVS(2015)*X(206)-JVS(2016)*X(207)&
             &-JVS(2017)*X(208)-JVS(2018)*X(209)-JVS(2019)*X(210)-JVS(2020)*X(211)-JVS(2021)*X(212)-JVS(2022)*X(213)&
             &-JVS(2023)*X(214)-JVS(2024)*X(215))/(JVS(2010))
  X(200) = (X(200)-JVS(1976)*X(204)-JVS(1977)*X(205)-JVS(1978)*X(206)-JVS(1979)*X(207)-JVS(1980)*X(208)-JVS(1981)*X(209)&
             &-JVS(1982)*X(210)-JVS(1983)*X(211)-JVS(1984)*X(212)-JVS(1985)*X(213)-JVS(1986)*X(214)-JVS(1987)*X(215))&
             &/(JVS(1975))
  X(199) = (X(199)-JVS(1940)*X(204)-JVS(1941)*X(205)-JVS(1942)*X(206)-JVS(1943)*X(207)-JVS(1944)*X(208)-JVS(1945)*X(210)&
             &-JVS(1946)*X(211)-JVS(1947)*X(212)-JVS(1948)*X(213)-JVS(1949)*X(214)-JVS(1950)*X(215))/(JVS(1939))
  X(198) = (X(198)-JVS(1915)*X(199)-JVS(1916)*X(200)-JVS(1917)*X(201)-JVS(1918)*X(202)-JVS(1919)*X(203)-JVS(1920)*X(204)&
             &-JVS(1921)*X(205)-JVS(1922)*X(206)-JVS(1923)*X(207)-JVS(1924)*X(208)-JVS(1925)*X(209)-JVS(1926)*X(210)&
             &-JVS(1927)*X(211)-JVS(1928)*X(212)-JVS(1929)*X(213)-JVS(1930)*X(214)-JVS(1931)*X(215))/(JVS(1914))
  X(197) = (X(197)-JVS(1880)*X(198)-JVS(1881)*X(199)-JVS(1882)*X(200)-JVS(1883)*X(201)-JVS(1884)*X(202)-JVS(1885)*X(203)&
             &-JVS(1886)*X(204)-JVS(1887)*X(205)-JVS(1888)*X(206)-JVS(1889)*X(207)-JVS(1890)*X(208)-JVS(1891)*X(209)&
             &-JVS(1892)*X(210)-JVS(1893)*X(211)-JVS(1894)*X(212)-JVS(1895)*X(213)-JVS(1896)*X(214)-JVS(1897)*X(215))&
             &/(JVS(1879))
  X(196) = (X(196)-JVS(1794)*X(197)-JVS(1795)*X(198)-JVS(1796)*X(199)-JVS(1797)*X(200)-JVS(1798)*X(201)-JVS(1799)*X(202)&
             &-JVS(1800)*X(203)-JVS(1801)*X(204)-JVS(1802)*X(205)-JVS(1803)*X(206)-JVS(1804)*X(207)-JVS(1805)*X(208)&
             &-JVS(1806)*X(209)-JVS(1807)*X(210)-JVS(1808)*X(211)-JVS(1809)*X(212)-JVS(1810)*X(213)-JVS(1811)*X(214)&
             &-JVS(1812)*X(215))/(JVS(1793))
  X(195) = (X(195)-JVS(1741)*X(200)-JVS(1742)*X(205)-JVS(1743)*X(206)-JVS(1744)*X(208)-JVS(1745)*X(209)-JVS(1746)*X(210)&
             &-JVS(1747)*X(212)-JVS(1748)*X(213)-JVS(1749)*X(214)-JVS(1750)*X(215))/(JVS(1740))
  X(194) = (X(194)-JVS(1720)*X(199)-JVS(1721)*X(203)-JVS(1722)*X(205)-JVS(1723)*X(206)-JVS(1724)*X(208)-JVS(1725)*X(210)&
             &-JVS(1726)*X(212)-JVS(1727)*X(213)-JVS(1728)*X(214)-JVS(1729)*X(215))/(JVS(1719))
  X(193) = (X(193)-JVS(1707)*X(195)-JVS(1708)*X(205)-JVS(1709)*X(206)-JVS(1710)*X(208)-JVS(1711)*X(210)-JVS(1712)*X(212)&
             &-JVS(1713)*X(213)-JVS(1714)*X(214)-JVS(1715)*X(215))/(JVS(1706))
  X(192) = (X(192)-JVS(1675)*X(193)-JVS(1676)*X(194)-JVS(1677)*X(195)-JVS(1678)*X(200)-JVS(1679)*X(203)-JVS(1680)*X(204)&
             &-JVS(1681)*X(205)-JVS(1682)*X(206)-JVS(1683)*X(207)-JVS(1684)*X(208)-JVS(1685)*X(209)-JVS(1686)*X(210)&
             &-JVS(1687)*X(211)-JVS(1688)*X(212)-JVS(1689)*X(213)-JVS(1690)*X(214)-JVS(1691)*X(215))/(JVS(1674))
  X(191) = (X(191)-JVS(1629)*X(205)-JVS(1630)*X(206)-JVS(1631)*X(208)-JVS(1632)*X(210)-JVS(1633)*X(212)-JVS(1634)*X(213)&
             &-JVS(1635)*X(214)-JVS(1636)*X(215))/(JVS(1628))
  X(190) = (X(190)-JVS(1609)*X(191)-JVS(1610)*X(193)-JVS(1611)*X(195)-JVS(1612)*X(199)-JVS(1613)*X(200)-JVS(1614)*X(202)&
             &-JVS(1615)*X(203)-JVS(1616)*X(204)-JVS(1617)*X(205)-JVS(1618)*X(206)-JVS(1619)*X(208)-JVS(1620)*X(210)&
             &-JVS(1621)*X(212)-JVS(1622)*X(213)-JVS(1623)*X(214)-JVS(1624)*X(215))/(JVS(1608))
  X(189) = (X(189)-JVS(1591)*X(204)-JVS(1592)*X(205)-JVS(1593)*X(206)-JVS(1594)*X(207)-JVS(1595)*X(208)-JVS(1596)*X(209)&
             &-JVS(1597)*X(210)-JVS(1598)*X(211)-JVS(1599)*X(212)-JVS(1600)*X(213)-JVS(1601)*X(214)-JVS(1602)*X(215))&
             &/(JVS(1590))
  X(188) = (X(188)-JVS(1579)*X(205)-JVS(1580)*X(206)-JVS(1581)*X(208)-JVS(1582)*X(210)-JVS(1583)*X(212)-JVS(1584)*X(213)&
             &-JVS(1585)*X(214)-JVS(1586)*X(215))/(JVS(1578))
  X(187) = (X(187)-JVS(1563)*X(193)-JVS(1564)*X(195)-JVS(1565)*X(203)-JVS(1566)*X(205)-JVS(1567)*X(206)-JVS(1568)*X(208)&
             &-JVS(1569)*X(210)-JVS(1570)*X(212)-JVS(1571)*X(213)-JVS(1572)*X(214)-JVS(1573)*X(215))/(JVS(1562))
  X(186) = (X(186)-JVS(1550)*X(188)-JVS(1551)*X(191)-JVS(1552)*X(205)-JVS(1553)*X(206)-JVS(1554)*X(208)-JVS(1555)*X(210)&
             &-JVS(1556)*X(212)-JVS(1557)*X(213)-JVS(1558)*X(214))/(JVS(1549))
  X(185) = (X(185)-JVS(1537)*X(191)-JVS(1538)*X(205)-JVS(1539)*X(206)-JVS(1540)*X(208)-JVS(1541)*X(210)-JVS(1542)*X(212)&
             &-JVS(1543)*X(213))/(JVS(1536))
  X(184) = (X(184)-JVS(1513)*X(185)-JVS(1514)*X(186)-JVS(1515)*X(187)-JVS(1516)*X(188)-JVS(1517)*X(189)-JVS(1518)*X(191)&
             &-JVS(1519)*X(192)-JVS(1520)*X(194)-JVS(1521)*X(199)-JVS(1522)*X(200)-JVS(1523)*X(203)-JVS(1524)*X(204)&
             &-JVS(1525)*X(205)-JVS(1526)*X(206)-JVS(1527)*X(207)-JVS(1528)*X(208)-JVS(1529)*X(209)-JVS(1530)*X(210)&
             &-JVS(1531)*X(211)-JVS(1532)*X(212)-JVS(1533)*X(213)-JVS(1534)*X(214)-JVS(1535)*X(215))/(JVS(1512))
  X(183) = (X(183)-JVS(1476)*X(204)-JVS(1477)*X(205)-JVS(1478)*X(206)-JVS(1479)*X(208)-JVS(1480)*X(209)-JVS(1481)*X(210)&
             &-JVS(1482)*X(212)-JVS(1483)*X(213)-JVS(1484)*X(214))/(JVS(1475))
  X(182) = (X(182)-JVS(1463)*X(199)-JVS(1464)*X(205)-JVS(1465)*X(206)-JVS(1466)*X(208)-JVS(1467)*X(210)-JVS(1468)*X(212)&
             &-JVS(1469)*X(213)-JVS(1470)*X(214)-JVS(1471)*X(215))/(JVS(1462))
  X(181) = (X(181)-JVS(1452)*X(200)-JVS(1453)*X(205)-JVS(1454)*X(206)-JVS(1455)*X(208)-JVS(1456)*X(210)-JVS(1457)*X(212)&
             &-JVS(1458)*X(213)-JVS(1459)*X(214))/(JVS(1451))
  X(180) = (X(180)-JVS(1434)*X(187)-JVS(1435)*X(194)-JVS(1436)*X(196)-JVS(1437)*X(197)-JVS(1438)*X(198)-JVS(1439)*X(201)&
             &-JVS(1440)*X(203)-JVS(1441)*X(204)-JVS(1442)*X(205)-JVS(1443)*X(206)-JVS(1444)*X(210)-JVS(1445)*X(212)&
             &-JVS(1446)*X(213)-JVS(1447)*X(214)-JVS(1448)*X(215))/(JVS(1433))
  X(179) = (X(179)-JVS(1419)*X(186)-JVS(1420)*X(188)-JVS(1421)*X(206)-JVS(1422)*X(208)-JVS(1423)*X(212)-JVS(1424)*X(213)&
             &-JVS(1425)*X(214))/(JVS(1418))
  X(178) = (X(178)-JVS(1409)*X(188)-JVS(1410)*X(191)-JVS(1411)*X(205)-JVS(1412)*X(206)-JVS(1413)*X(212)-JVS(1414)&
             &*X(213))/(JVS(1408))
  X(177) = (X(177)-JVS(1393)*X(178)-JVS(1394)*X(179)-JVS(1395)*X(182)-JVS(1396)*X(185)-JVS(1397)*X(186)-JVS(1398)*X(188)&
             &-JVS(1399)*X(204)-JVS(1400)*X(205)-JVS(1401)*X(206)-JVS(1402)*X(207)-JVS(1403)*X(208)-JVS(1404)*X(211)&
             &-JVS(1405)*X(212)-JVS(1406)*X(213)-JVS(1407)*X(214))/(JVS(1392))
  X(176) = (X(176)-JVS(1377)*X(178)-JVS(1378)*X(188)-JVS(1379)*X(205)-JVS(1380)*X(206)-JVS(1381)*X(213)-JVS(1382)&
             &*X(214))/(JVS(1376))
  X(175) = (X(175)-JVS(1345)*X(176)-JVS(1346)*X(178)-JVS(1347)*X(179)-JVS(1348)*X(181)-JVS(1349)*X(182)-JVS(1350)*X(183)&
             &-JVS(1351)*X(187)-JVS(1352)*X(188)-JVS(1353)*X(189)-JVS(1354)*X(190)-JVS(1355)*X(191)-JVS(1356)*X(192)&
             &-JVS(1357)*X(193)-JVS(1358)*X(194)-JVS(1359)*X(195)-JVS(1360)*X(203)-JVS(1361)*X(204)-JVS(1362)*X(205)&
             &-JVS(1363)*X(206)-JVS(1364)*X(207)-JVS(1365)*X(208)-JVS(1366)*X(209)-JVS(1367)*X(210)-JVS(1368)*X(211)&
             &-JVS(1369)*X(212)-JVS(1370)*X(213)-JVS(1371)*X(214)-JVS(1372)*X(215))/(JVS(1344))
  X(174) = (X(174)-JVS(1326)*X(205)-JVS(1327)*X(206)-JVS(1328)*X(208)-JVS(1329)*X(210)-JVS(1330)*X(212)-JVS(1331)*X(213)&
             &-JVS(1332)*X(214))/(JVS(1325))
  X(173) = (X(173)-JVS(1313)*X(185)-JVS(1314)*X(199)-JVS(1315)*X(200)-JVS(1316)*X(202)-JVS(1317)*X(204)-JVS(1318)*X(206)&
             &-JVS(1319)*X(208)-JVS(1320)*X(210)-JVS(1321)*X(212)-JVS(1322)*X(213)-JVS(1323)*X(214))/(JVS(1312))
  X(172) = (X(172)-JVS(1302)*X(205)-JVS(1303)*X(206)-JVS(1304)*X(208)-JVS(1305)*X(210)-JVS(1306)*X(212)-JVS(1307)*X(213)&
             &-JVS(1308)*X(214))/(JVS(1301))
  X(171) = (X(171)-JVS(1293)*X(205)-JVS(1294)*X(206)-JVS(1295)*X(208)-JVS(1296)*X(210)-JVS(1297)*X(212)-JVS(1298)*X(213)&
             &-JVS(1299)*X(214))/(JVS(1292))
  X(170) = (X(170)-JVS(1281)*X(171)-JVS(1282)*X(205)-JVS(1283)*X(206)-JVS(1284)*X(208)-JVS(1285)*X(210)-JVS(1286)*X(212)&
             &-JVS(1287)*X(213)-JVS(1288)*X(214))/(JVS(1280))
  X(169) = (X(169)-JVS(1269)*X(196)-JVS(1270)*X(198)-JVS(1271)*X(203)-JVS(1272)*X(204)-JVS(1273)*X(205)-JVS(1274)*X(206)&
             &-JVS(1275)*X(210)-JVS(1276)*X(213)-JVS(1277)*X(214))/(JVS(1268))
  X(168) = (X(168)-JVS(1231)*X(169)-JVS(1232)*X(170)-JVS(1233)*X(171)-JVS(1234)*X(172)-JVS(1235)*X(174)-JVS(1236)*X(176)&
             &-JVS(1237)*X(177)-JVS(1238)*X(178)-JVS(1239)*X(179)-JVS(1240)*X(180)-JVS(1241)*X(182)-JVS(1242)*X(183)&
             &-JVS(1243)*X(184)-JVS(1244)*X(185)-JVS(1245)*X(188)-JVS(1246)*X(189)-JVS(1247)*X(195)-JVS(1248)*X(196)&
             &-JVS(1249)*X(197)-JVS(1250)*X(198)-JVS(1251)*X(200)-JVS(1252)*X(201)-JVS(1253)*X(202)-JVS(1254)*X(203)&
             &-JVS(1255)*X(204)-JVS(1256)*X(205)-JVS(1257)*X(206)-JVS(1258)*X(208)-JVS(1259)*X(209)-JVS(1260)*X(210)&
             &-JVS(1261)*X(212)-JVS(1262)*X(213)-JVS(1263)*X(214)-JVS(1264)*X(215))/(JVS(1230))
  X(167) = (X(167)-JVS(1196)*X(169)-JVS(1197)*X(198)-JVS(1198)*X(204)-JVS(1199)*X(205)-JVS(1200)*X(206)-JVS(1201)*X(210)&
             &-JVS(1202)*X(213)-JVS(1203)*X(214))/(JVS(1195))
  X(166) = (X(166)-JVS(1180)*X(176)-JVS(1181)*X(178)-JVS(1182)*X(188)-JVS(1183)*X(189)-JVS(1184)*X(205)-JVS(1185)*X(206)&
             &-JVS(1186)*X(213)-JVS(1187)*X(214))/(JVS(1179))
  X(165) = (X(165)-JVS(1167)*X(169)-JVS(1168)*X(180)-JVS(1169)*X(196)-JVS(1170)*X(198)-JVS(1171)*X(203)-JVS(1172)*X(204)&
             &-JVS(1173)*X(205)-JVS(1174)*X(213)-JVS(1175)*X(214)-JVS(1176)*X(215))/(JVS(1166))
  X(164) = (X(164)-JVS(1154)*X(167)-JVS(1155)*X(169)-JVS(1156)*X(198)-JVS(1157)*X(204)-JVS(1158)*X(205)-JVS(1159)*X(206)&
             &-JVS(1160)*X(210)-JVS(1161)*X(213)-JVS(1162)*X(214))/(JVS(1153))
  X(163) = (X(163)-JVS(1131)*X(183)-JVS(1132)*X(206)-JVS(1133)*X(208)-JVS(1134)*X(209)-JVS(1135)*X(210)-JVS(1136)*X(212)&
             &-JVS(1137)*X(213)-JVS(1138)*X(214))/(JVS(1130))
  X(162) = (X(162)-JVS(1120)*X(176)-JVS(1121)*X(178)-JVS(1122)*X(195)-JVS(1123)*X(206)-JVS(1124)*X(208)-JVS(1125)*X(212)&
             &-JVS(1126)*X(213)-JVS(1127)*X(214))/(JVS(1119))
  X(161) = (X(161)-JVS(1112)*X(176)-JVS(1113)*X(178)-JVS(1114)*X(206)-JVS(1115)*X(213)-JVS(1116)*X(214))/(JVS(1111))
  X(160) = (X(160)-JVS(1101)*X(193)-JVS(1102)*X(195)-JVS(1103)*X(203)-JVS(1104)*X(206)-JVS(1105)*X(208)-JVS(1106)*X(212)&
             &-JVS(1107)*X(213)-JVS(1108)*X(214)-JVS(1109)*X(215))/(JVS(1100))
  X(159) = (X(159)-JVS(1089)*X(181)-JVS(1090)*X(187)-JVS(1091)*X(203)-JVS(1092)*X(206)-JVS(1093)*X(208)-JVS(1094)*X(212)&
             &-JVS(1095)*X(213)-JVS(1096)*X(214)-JVS(1097)*X(215))/(JVS(1088))
  X(158) = (X(158)-JVS(1079)*X(194)-JVS(1080)*X(203)-JVS(1081)*X(206)-JVS(1082)*X(208)-JVS(1083)*X(212)-JVS(1084)*X(213)&
             &-JVS(1085)*X(214)-JVS(1086)*X(215))/(JVS(1078))
  X(157) = (X(157)-JVS(1073)*X(205)-JVS(1074)*X(210)-JVS(1075)*X(213)-JVS(1076)*X(215))/(JVS(1072))
  X(156) = (X(156)-JVS(1051)*X(157)-JVS(1052)*X(161)-JVS(1053)*X(166)-JVS(1054)*X(174)-JVS(1055)*X(176)-JVS(1056)*X(177)&
             &-JVS(1057)*X(178)-JVS(1058)*X(182)-JVS(1059)*X(188)-JVS(1060)*X(192)-JVS(1061)*X(194)-JVS(1062)*X(199)&
             &-JVS(1063)*X(204)-JVS(1064)*X(205)-JVS(1065)*X(206)-JVS(1066)*X(207)-JVS(1067)*X(209)-JVS(1068)*X(210)&
             &-JVS(1069)*X(213)-JVS(1070)*X(214)-JVS(1071)*X(215))/(JVS(1050))
  X(155) = (X(155)-JVS(1038)*X(185)-JVS(1039)*X(204)-JVS(1040)*X(206)-JVS(1041)*X(210)-JVS(1042)*X(213)-JVS(1043)&
             &*X(214))/(JVS(1037))
  X(154) = (X(154)-JVS(1031)*X(206)-JVS(1032)*X(208)-JVS(1033)*X(209)-JVS(1034)*X(210)-JVS(1035)*X(212)-JVS(1036)&
             &*X(214))/(JVS(1030))
  X(153) = (X(153)-JVS(1016)*X(154)-JVS(1017)*X(155)-JVS(1018)*X(161)-JVS(1019)*X(178)-JVS(1020)*X(185)-JVS(1021)*X(188)&
             &-JVS(1022)*X(194)-JVS(1023)*X(205)-JVS(1024)*X(206)-JVS(1025)*X(208)-JVS(1026)*X(210)-JVS(1027)*X(212)&
             &-JVS(1028)*X(213)-JVS(1029)*X(214))/(JVS(1015))
  X(152) = (X(152)-JVS(1001)*X(193)-JVS(1002)*X(195)-JVS(1003)*X(203)-JVS(1004)*X(206)-JVS(1005)*X(208)-JVS(1006)*X(212)&
             &-JVS(1007)*X(213)-JVS(1008)*X(214)-JVS(1009)*X(215))/(JVS(1000))
  X(151) = (X(151)-JVS(992)*X(157)-JVS(993)*X(204)-JVS(994)*X(205)-JVS(995)*X(206)-JVS(996)*X(207)-JVS(997)*X(211))&
             &/(JVS(991))
  X(150) = (X(150)-JVS(980)*X(170)-JVS(981)*X(171)-JVS(982)*X(172)-JVS(983)*X(174)-JVS(984)*X(205)-JVS(985)*X(206)&
             &-JVS(986)*X(208)-JVS(987)*X(210)-JVS(988)*X(212)-JVS(989)*X(213)-JVS(990)*X(214))/(JVS(979))
  X(149) = (X(149)-JVS(972)*X(194)-JVS(973)*X(206)-JVS(974)*X(208)-JVS(975)*X(210)-JVS(976)*X(212)-JVS(977)*X(213)&
             &-JVS(978)*X(214))/(JVS(971))
  X(148) = (X(148)-JVS(958)*X(177)-JVS(959)*X(178)-JVS(960)*X(179)-JVS(961)*X(185)-JVS(962)*X(188)-JVS(963)*X(205)&
             &-JVS(964)*X(206)-JVS(965)*X(208)-JVS(966)*X(210)-JVS(967)*X(212)-JVS(968)*X(213)-JVS(969)*X(214))/(JVS(957))
  X(147) = (X(147)-JVS(937)*X(165)-JVS(938)*X(169)-JVS(939)*X(180)-JVS(940)*X(196)-JVS(941)*X(203)-JVS(942)*X(204)&
             &-JVS(943)*X(205)-JVS(944)*X(213)-JVS(945)*X(214))/(JVS(936))
  X(146) = (X(146)-JVS(924)*X(161)-JVS(925)*X(176)-JVS(926)*X(182)-JVS(927)*X(188)-JVS(928)*X(205)-JVS(929)*X(206)&
             &-JVS(930)*X(213)-JVS(931)*X(214))/(JVS(923))
  X(145) = (X(145)-JVS(910)*X(165)-JVS(911)*X(167)-JVS(912)*X(169)-JVS(913)*X(180)-JVS(914)*X(196)-JVS(915)*X(198)&
             &-JVS(916)*X(204)-JVS(917)*X(210)-JVS(918)*X(212)-JVS(919)*X(213)-JVS(920)*X(214)-JVS(921)*X(215))/(JVS(909))
  X(144) = (X(144)-JVS(898)*X(178)-JVS(899)*X(188)-JVS(900)*X(205)-JVS(901)*X(206)-JVS(902)*X(213)-JVS(903)*X(214))&
             &/(JVS(897))
  X(143) = (X(143)-JVS(875)*X(151)-JVS(876)*X(157)-JVS(877)*X(186)-JVS(878)*X(194)-JVS(879)*X(199)-JVS(880)*X(204)&
             &-JVS(881)*X(205)-JVS(882)*X(206)-JVS(883)*X(207)-JVS(884)*X(209)-JVS(885)*X(210)-JVS(886)*X(211)-JVS(887)&
             &*X(213)-JVS(888)*X(214)-JVS(889)*X(215))/(JVS(874))
  X(142) = (X(142)-JVS(858)*X(157)-JVS(859)*X(194)-JVS(860)*X(199)-JVS(861)*X(204)-JVS(862)*X(205)-JVS(863)*X(206)&
             &-JVS(864)*X(207)-JVS(865)*X(209))/(JVS(857))
  X(141) = (X(141)-JVS(853)*X(188)-JVS(854)*X(205)-JVS(855)*X(206)-JVS(856)*X(213))/(JVS(852))
  X(140) = (X(140)-JVS(843)*X(170)-JVS(844)*X(171)-JVS(845)*X(174)-JVS(846)*X(206)-JVS(847)*X(208)-JVS(848)*X(210)&
             &-JVS(849)*X(212)-JVS(850)*X(213)-JVS(851)*X(214))/(JVS(842))
  X(139) = (X(139)-JVS(836)*X(199)-JVS(837)*X(204)-JVS(838)*X(205)-JVS(839)*X(206)-JVS(840)*X(207)-JVS(841)*X(211))&
             &/(JVS(835))
  X(138) = (X(138)-JVS(818)*X(149)-JVS(819)*X(152)-JVS(820)*X(158)-JVS(821)*X(160)-JVS(822)*X(162)-JVS(823)*X(163)&
             &-JVS(824)*X(171)-JVS(825)*X(172)-JVS(826)*X(174)-JVS(827)*X(179)-JVS(828)*X(181)-JVS(829)*X(182)-JVS(830)&
             &*X(188)-JVS(831)*X(189)-JVS(832)*X(193)-JVS(833)*X(212)-JVS(834)*X(213))/(JVS(817))
  X(137) = (X(137)-JVS(812)*X(166)-JVS(813)*X(204)-JVS(814)*X(206)-JVS(815)*X(213)-JVS(816)*X(214))/(JVS(811))
  X(136) = (X(136)-JVS(803)*X(185)-JVS(804)*X(191)-JVS(805)*X(206)-JVS(806)*X(210)-JVS(807)*X(212)-JVS(808)*X(213)&
             &-JVS(809)*X(214))/(JVS(802))
  X(135) = (X(135)-JVS(793)*X(186)-JVS(794)*X(204)-JVS(795)*X(205)-JVS(796)*X(206)-JVS(797)*X(207)-JVS(798)*X(209)&
             &-JVS(799)*X(211))/(JVS(792))
  X(134) = (X(134)-JVS(786)*X(164)-JVS(787)*X(167)-JVS(788)*X(204)-JVS(789)*X(206)-JVS(790)*X(210)-JVS(791)*X(213))&
             &/(JVS(785))
  X(133) = (X(133)-JVS(776)*X(194)-JVS(777)*X(204)-JVS(778)*X(205)-JVS(779)*X(206)-JVS(780)*X(207)-JVS(781)*X(211))&
             &/(JVS(775))
  X(132) = (X(132)-JVS(769)*X(186)-JVS(770)*X(204)-JVS(771)*X(205)-JVS(772)*X(206)-JVS(773)*X(207)-JVS(774)*X(211))&
             &/(JVS(768))
  X(131) = (X(131)-JVS(765)*X(205)-JVS(766)*X(210)-JVS(767)*X(213))/(JVS(764))
  X(130) = (X(130)-JVS(759)*X(155)-JVS(760)*X(204)-JVS(761)*X(209)-JVS(762)*X(210)-JVS(763)*X(213))/(JVS(758))
  X(129) = (X(129)-JVS(752)*X(185)-JVS(753)*X(206)-JVS(754)*X(210)-JVS(755)*X(212)-JVS(756)*X(214))/(JVS(751))
  X(128) = (X(128)-JVS(747)*X(188)-JVS(748)*X(206)-JVS(749)*X(208)-JVS(750)*X(214))/(JVS(746))
  X(127) = (X(127)-JVS(740)*X(179)-JVS(741)*X(205)-JVS(742)*X(206)-JVS(743)*X(208)-JVS(744)*X(213)-JVS(745)*X(214))&
             &/(JVS(739))
  X(126) = (X(126)-JVS(732)*X(157)-JVS(733)*X(204)-JVS(734)*X(205)-JVS(735)*X(206)-JVS(736)*X(207)-JVS(737)*X(211))&
             &/(JVS(731))
  X(125) = (X(125)-JVS(726)*X(134)-JVS(727)*X(164)-JVS(728)*X(167)-JVS(729)*X(204)-JVS(730)*X(210))/(JVS(725))
  X(124) = (X(124)-JVS(721)*X(169)-JVS(722)*X(196)-JVS(723)*X(203)-JVS(724)*X(204))/(JVS(720))
  X(123) = (X(123)-JVS(716)*X(183)-JVS(717)*X(204)-JVS(718)*X(205)-JVS(719)*X(213))/(JVS(715))
  X(122) = (X(122)-JVS(712)*X(205)-JVS(713)*X(210)-JVS(714)*X(213))/(JVS(711))
  X(121) = (X(121)-JVS(706)*X(185)-JVS(707)*X(206)-JVS(708)*X(212)-JVS(709)*X(213)-JVS(710)*X(214))/(JVS(705))
  X(120) = (X(120)-JVS(701)*X(203)-JVS(702)*X(210)-JVS(703)*X(213)-JVS(704)*X(215))/(JVS(700))
  X(119) = (X(119)-JVS(694)*X(161)-JVS(695)*X(178)-JVS(696)*X(205)-JVS(697)*X(206)-JVS(698)*X(213)-JVS(699)*X(214))&
             &/(JVS(693))
  X(118) = (X(118)-JVS(687)*X(178)-JVS(688)*X(190)-JVS(689)*X(205)-JVS(690)*X(212)-JVS(691)*X(213)-JVS(692)*X(215))&
             &/(JVS(686))
  X(117) = (X(117)-JVS(680)*X(154)-JVS(681)*X(183)-JVS(682)*X(209)-JVS(683)*X(210)-JVS(684)*X(213)-JVS(685)*X(214))&
             &/(JVS(679))
  X(116) = (X(116)-JVS(675)*X(147)-JVS(676)*X(165)-JVS(677)*X(180)-JVS(678)*X(205))/(JVS(674))
  X(115) = (X(115)-JVS(670)*X(147)-JVS(671)*X(165)-JVS(672)*X(180)-JVS(673)*X(205))/(JVS(669))
  X(114) = (X(114)-JVS(665)*X(161)-JVS(666)*X(176)-JVS(667)*X(213)-JVS(668)*X(214))/(JVS(664))
  X(113) = (X(113)-JVS(661)*X(188)-JVS(662)*X(213)-JVS(663)*X(214))/(JVS(660))
  X(112) = (X(112)-JVS(657)*X(188)-JVS(658)*X(213)-JVS(659)*X(214))/(JVS(656))
  X(111) = (X(111)-JVS(651)*X(140)-JVS(652)*X(150)-JVS(653)*X(205)-JVS(654)*X(210)-JVS(655)*X(213))/(JVS(650))
  X(110) = (X(110)-JVS(645)*X(179)-JVS(646)*X(206)-JVS(647)*X(208)-JVS(648)*X(213)-JVS(649)*X(214))/(JVS(644))
  X(109) = (X(109)-JVS(638)*X(179)-JVS(639)*X(205)-JVS(640)*X(206)-JVS(641)*X(208)-JVS(642)*X(213))/(JVS(637))
  X(108) = (X(108)-JVS(633)*X(144)-JVS(634)*X(206)-JVS(635)*X(213)-JVS(636)*X(214))/(JVS(632))
  X(107) = (X(107)-JVS(624)*X(145)-JVS(625)*X(165)-JVS(626)*X(169)-JVS(627)*X(196)-JVS(628)*X(198)-JVS(629)*X(212)&
             &-JVS(630)*X(213)-JVS(631)*X(215))/(JVS(623))
  X(106) = (X(106)-JVS(619)*X(182)-JVS(620)*X(213)-JVS(621)*X(214))/(JVS(618))
  X(105) = (X(105)-JVS(615)*X(188)-JVS(616)*X(213)-JVS(617)*X(214))/(JVS(614))
  X(104) = (X(104)-JVS(611)*X(179)-JVS(612)*X(213)-JVS(613)*X(214))/(JVS(610))
  X(103) = (X(103)-JVS(606)*X(188)-JVS(607)*X(206)-JVS(608)*X(213)-JVS(609)*X(214))/(JVS(605))
  X(102) = (X(102)-JVS(600)*X(151)-JVS(601)*X(189)-JVS(602)*X(213)-JVS(603)*X(214))/(JVS(599))
  X(101) = (X(101)-JVS(595)*X(212)-JVS(596)*X(213)-JVS(597)*X(214)-JVS(598)*X(215))/(JVS(594))
  X(100) = (X(100)-JVS(586)*X(115)-JVS(587)*X(116)-JVS(588)*X(124)-JVS(589)*X(147)-JVS(590)*X(169)-JVS(591)*X(180)&
             &-JVS(592)*X(203)-JVS(593)*X(213))/(JVS(585))
  X(99) = (X(99)-JVS(582)*X(203)-JVS(583)*X(213)-JVS(584)*X(215))/(JVS(581))
  X(98) = (X(98)-JVS(578)*X(196)-JVS(579)*X(204)-JVS(580)*X(210))/(JVS(577))
  X(97) = (X(97)-JVS(574)*X(188)-JVS(575)*X(206)-JVS(576)*X(214))/(JVS(573))
  X(96) = (X(96)-JVS(571)*X(188)-JVS(572)*X(213))/(JVS(570))
  X(95) = (X(95)-JVS(566)*X(134)-JVS(567)*X(167)-JVS(568)*X(213)-JVS(569)*X(214))/(JVS(565))
  X(94) = (X(94)-JVS(555)*X(115)-JVS(556)*X(116)-JVS(557)*X(124)-JVS(558)*X(145)-JVS(559)*X(147)-JVS(560)*X(165)&
            &-JVS(561)*X(169)-JVS(562)*X(180)-JVS(563)*X(196)-JVS(564)*X(198))/(JVS(554))
  X(93) = (X(93)-JVS(550)*X(159)-JVS(551)*X(181)-JVS(552)*X(213)-JVS(553)*X(214))/(JVS(549))
  X(92) = (X(92)-JVS(544)*X(127)-JVS(545)*X(128)-JVS(546)*X(193)-JVS(547)*X(213)-JVS(548)*X(214))/(JVS(543))
  X(91) = (X(91)-JVS(539)*X(172)-JVS(540)*X(174)-JVS(541)*X(213)-JVS(542)*X(214))/(JVS(538))
  X(90) = (X(90)-JVS(535)*X(210)-JVS(536)*X(213)-JVS(537)*X(215))/(JVS(534))
  X(89) = (X(89)-JVS(531)*X(149)-JVS(532)*X(213)-JVS(533)*X(214))/(JVS(530))
  X(88) = (X(88)-JVS(527)*X(158)-JVS(528)*X(213)-JVS(529)*X(214))/(JVS(526))
  X(87) = (X(87)-JVS(522)*X(155)-JVS(523)*X(173)-JVS(524)*X(213)-JVS(525)*X(214))/(JVS(521))
  X(86) = (X(86)-JVS(517)*X(130)-JVS(518)*X(204)-JVS(519)*X(208)-JVS(520)*X(213))/(JVS(516))
  X(85) = (X(85)-JVS(512)*X(167)-JVS(513)*X(169)-JVS(514)*X(198)-JVS(515)*X(213))/(JVS(511))
  X(84) = (X(84)-JVS(506)*X(169)-JVS(507)*X(198)-JVS(508)*X(212)-JVS(509)*X(213)-JVS(510)*X(215))/(JVS(505))
  X(83) = (X(83)-JVS(501)*X(98)-JVS(502)*X(196)-JVS(503)*X(213))/(JVS(500))
  X(82) = (X(82)-JVS(498)*X(213)-JVS(499)*X(215))/(JVS(497))
  X(81) = (X(81)-JVS(495)*X(210)-JVS(496)*X(213))/(JVS(494))
  X(80) = (X(80)-JVS(492)*X(210)-JVS(493)*X(213))/(JVS(491))
  X(79) = (X(79)-JVS(488)*X(160)-JVS(489)*X(213)-JVS(490)*X(214))/(JVS(487))
  X(78) = (X(78)-JVS(484)*X(152)-JVS(485)*X(213)-JVS(486)*X(214))/(JVS(483))
  X(77) = (X(77)-JVS(480)*X(190)-JVS(481)*X(213)-JVS(482)*X(214))/(JVS(479))
  X(76) = (X(76)-JVS(476)*X(167)-JVS(477)*X(169)-JVS(478)*X(206))/(JVS(475))
  X(75) = (X(75)-JVS(469)*X(204)-JVS(470)*X(213)-JVS(471)*X(214))/(JVS(468))
  X(74) = (X(74)-JVS(464)*X(164)-JVS(465)*X(204)-JVS(466)*X(206)-JVS(467)*X(213))/(JVS(463))
  X(73) = (X(73)-JVS(460)*X(164)-JVS(461)*X(204))/(JVS(459))
  X(72) = (X(72)-JVS(457)*X(198)-JVS(458)*X(213))/(JVS(456))
  X(71) = (X(71)-JVS(454)*X(213)-JVS(455)*X(215))/(JVS(453))
  X(70) = (X(70)-JVS(451)*X(213)-JVS(452)*X(215))/(JVS(450))
  X(69) = (X(69)-JVS(448)*X(204)-JVS(449)*X(212))/(JVS(447))
  X(68) = (X(68)-JVS(442)*X(130)-JVS(443)*X(204)-JVS(444)*X(209)-JVS(445)*X(210)-JVS(446)*X(213))/(JVS(441))
  X(67) = (X(67)-JVS(436)*X(73)-JVS(437)*X(95)-JVS(438)*X(125)-JVS(439)*X(167)-JVS(440)*X(198))/(JVS(435))
  X(66) = (X(66)-JVS(432)*X(208)-JVS(433)*X(213)-JVS(434)*X(214))/(JVS(431))
  X(65) = (X(65)-JVS(427)*X(80)-JVS(428)*X(206)-JVS(429)*X(213)-JVS(430)*X(214))/(JVS(426))
  X(64) = (X(64)-JVS(418)*X(141)-JVS(419)*X(146)-JVS(420)*X(161)-JVS(421)*X(166)-JVS(422)*X(176)-JVS(423)*X(178)&
            &-JVS(424)*X(195)-JVS(425)*X(206))/(JVS(417))
  X(63) = (X(63)-JVS(412)*X(105)-JVS(413)*X(112)-JVS(414)*X(141)-JVS(415)*X(213))/(JVS(411))
  X(62) = (X(62)-JVS(407)*X(105)-JVS(408)*X(112)-JVS(409)*X(141)-JVS(410)*X(213))/(JVS(406))
  X(61) = (X(61)-JVS(403)*X(206)-JVS(404)*X(213)-JVS(405)*X(214))/(JVS(402))
  X(60) = (X(60)-JVS(398)*X(206)-JVS(399)*X(213)-JVS(400)*X(214))/(JVS(397))
  X(59) = (X(59)-JVS(394)*X(164)-JVS(395)*X(206))/(JVS(393))
  X(58) = (X(58)-JVS(390)*X(113)-JVS(391)*X(178)-JVS(392)*X(213))/(JVS(389))
  X(57) = (X(57)-JVS(386)*X(73)-JVS(387)*X(95)-JVS(388)*X(125))/(JVS(385))
  X(56) = (X(56)-JVS(382)*X(164)-JVS(383)*X(213)-JVS(384)*X(214))/(JVS(381))
  X(55) = (X(55)-JVS(380)*X(213))/(JVS(379))
  X(54) = (X(54)-JVS(377)*X(203)-JVS(378)*X(204))/(JVS(376))
  X(53) = (X(53)-JVS(375)*X(213))/(JVS(374))
  X(52) = (X(52)-JVS(372)*X(173)-JVS(373)*X(204))/(JVS(371))
  X(51) = (X(51)-JVS(369)*X(137)-JVS(370)*X(204))/(JVS(368))
  X(50) = (X(50)-JVS(366)*X(76)-JVS(367)*X(167))/(JVS(365))
  X(49) = (X(49)-JVS(364)*X(97))/(JVS(363))
  X(48) = (X(48)-JVS(362)*X(213))/(JVS(361))
  X(47) = (X(47)-JVS(358)*X(161)-JVS(359)*X(176)-JVS(360)*X(206))/(JVS(357))
  X(46) = (X(46)-JVS(356)*X(213))/(JVS(355))
  X(45) = (X(45)-JVS(352)*X(111)-JVS(353)*X(140)-JVS(354)*X(150))/(JVS(351))
  X(44) = (X(44)-JVS(350)*X(167))/(JVS(349))
  X(43) = (X(43)-JVS(348)*X(213))/(JVS(347))
  X(42) = (X(42)-JVS(346)*X(213))/(JVS(345))
  X(41) = (X(41)-JVS(344)*X(76))/(JVS(343))
  X(40) = (X(40)-JVS(334)*X(126)-JVS(335)*X(132)-JVS(336)*X(133)-JVS(337)*X(135)-JVS(338)*X(139)-JVS(339)*X(142)&
            &-JVS(340)*X(151)-JVS(341)*X(207)-JVS(342)*X(213))/(JVS(333))
  X(39) = (X(39)-JVS(325)*X(126)-JVS(326)*X(132)-JVS(327)*X(133)-JVS(328)*X(135)-JVS(329)*X(139)-JVS(330)*X(151)&
            &-JVS(331)*X(211)-JVS(332)*X(213))/(JVS(324))
  X(38) = (X(38)-JVS(278)*X(70)-JVS(279)*X(71)-JVS(280)*X(82)-JVS(281)*X(96)-JVS(282)*X(97)-JVS(283)*X(102)-JVS(284)&
            &*X(104)-JVS(285)*X(108)-JVS(286)*X(110)-JVS(287)*X(119)-JVS(288)*X(122)-JVS(289)*X(123)-JVS(290)*X(130)&
            &-JVS(291)*X(131)-JVS(292)*X(141)-JVS(293)*X(144)-JVS(294)*X(148)-JVS(295)*X(153)-JVS(296)*X(154)-JVS(297)&
            &*X(155)-JVS(298)*X(157)-JVS(299)*X(166)-JVS(300)*X(177)-JVS(301)*X(179)-JVS(302)*X(183)-JVS(303)*X(184)&
            &-JVS(304)*X(186)-JVS(305)*X(187)-JVS(306)*X(188)-JVS(307)*X(189)-JVS(308)*X(192)-JVS(309)*X(194)-JVS(310)&
            &*X(197)-JVS(311)*X(199)-JVS(312)*X(201)-JVS(313)*X(202)-JVS(314)*X(203)-JVS(315)*X(205)-JVS(316)*X(206)&
            &-JVS(317)*X(208)-JVS(318)*X(209)-JVS(319)*X(210)-JVS(320)*X(212)-JVS(321)*X(213)-JVS(322)*X(214)-JVS(323)&
            &*X(215))/(JVS(277))
  X(37) = (X(37)-JVS(213)*X(41)-JVS(214)*X(44)-JVS(215)*X(50)-JVS(216)*X(68)-JVS(217)*X(72)-JVS(218)*X(73)-JVS(219)&
            &*X(76)-JVS(220)*X(80)-JVS(221)*X(81)-JVS(222)*X(85)-JVS(223)*X(90)-JVS(224)*X(95)-JVS(225)*X(98)-JVS(226)&
            &*X(109)-JVS(227)*X(114)-JVS(228)*X(115)-JVS(229)*X(116)-JVS(230)*X(120)-JVS(231)*X(121)-JVS(232)*X(122)&
            &-JVS(233)*X(124)-JVS(234)*X(125)-JVS(235)*X(129)-JVS(236)*X(131)-JVS(237)*X(137)-JVS(238)*X(140)-JVS(239)&
            &*X(141)-JVS(240)*X(145)-JVS(241)*X(146)-JVS(242)*X(147)-JVS(243)*X(148)-JVS(244)*X(150)-JVS(245)*X(155)&
            &-JVS(246)*X(157)-JVS(247)*X(165)-JVS(248)*X(166)-JVS(249)*X(167)-JVS(250)*X(169)-JVS(251)*X(170)-JVS(252)&
            &*X(172)-JVS(253)*X(174)-JVS(254)*X(178)-JVS(255)*X(180)-JVS(256)*X(184)-JVS(257)*X(185)-JVS(258)*X(186)&
            &-JVS(259)*X(191)-JVS(260)*X(194)-JVS(261)*X(195)-JVS(262)*X(196)-JVS(263)*X(197)-JVS(264)*X(198)-JVS(265)&
            &*X(199)-JVS(266)*X(200)-JVS(267)*X(201)-JVS(268)*X(202)-JVS(269)*X(204)-JVS(270)*X(205)-JVS(271)*X(206)&
            &-JVS(272)*X(209)-JVS(273)*X(210)-JVS(274)*X(212)-JVS(275)*X(213)-JVS(276)*X(214))/(JVS(212))
  X(36) = (X(36)-JVS(147)*X(45)-JVS(148)*X(51)-JVS(149)*X(64)-JVS(150)*X(69)-JVS(151)*X(74)-JVS(152)*X(75)-JVS(153)&
            &*X(83)-JVS(154)*X(84)-JVS(155)*X(86)-JVS(156)*X(97)-JVS(157)*X(100)-JVS(158)*X(103)-JVS(159)*X(107)-JVS(160)&
            &*X(111)-JVS(161)*X(126)-JVS(162)*X(127)-JVS(163)*X(128)-JVS(164)*X(129)-JVS(165)*X(130)-JVS(166)*X(132)&
            &-JVS(167)*X(133)-JVS(168)*X(134)-JVS(169)*X(135)-JVS(170)*X(137)-JVS(171)*X(139)-JVS(172)*X(140)-JVS(173)&
            &*X(142)-JVS(174)*X(144)-JVS(175)*X(146)-JVS(176)*X(149)-JVS(177)*X(150)-JVS(178)*X(151)-JVS(179)*X(152)&
            &-JVS(180)*X(154)-JVS(181)*X(155)-JVS(182)*X(158)-JVS(183)*X(159)-JVS(184)*X(160)-JVS(185)*X(161)-JVS(186)&
            &*X(162)-JVS(187)*X(163)-JVS(188)*X(165)-JVS(189)*X(168)-JVS(190)*X(170)-JVS(191)*X(171)-JVS(192)*X(172)&
            &-JVS(193)*X(173)-JVS(194)*X(174)-JVS(195)*X(176)-JVS(196)*X(179)-JVS(197)*X(181)-JVS(198)*X(182)-JVS(199)&
            &*X(183)-JVS(200)*X(188)-JVS(201)*X(189)-JVS(202)*X(190)-JVS(203)*X(191)-JVS(204)*X(193)-JVS(205)*X(204)&
            &-JVS(206)*X(206)-JVS(207)*X(208)-JVS(208)*X(212)-JVS(209)*X(213)-JVS(210)*X(214)-JVS(211)*X(215))/(JVS(146))
  X(35) = (X(35)-JVS(145)*X(184))/(JVS(144))
  X(34) = (X(34)-JVS(142)*X(130)-JVS(143)*X(213))/(JVS(141))
  X(33) = (X(33)-JVS(140)*X(34))/(JVS(139))
  X(32) = (X(32)-JVS(136)*X(58)-JVS(137)*X(62)-JVS(138)*X(63))/(JVS(135))
  X(31) = (X(31)-JVS(134)*X(148))/(JVS(133))
  X(30) = (X(30)-JVS(132)*X(147))/(JVS(131))
  X(29) = (X(29)-JVS(130)*X(147))/(JVS(129))
  X(28) = (X(28)-JVS(120)*X(126)-JVS(121)*X(132)-JVS(122)*X(133)-JVS(123)*X(135)-JVS(124)*X(139)-JVS(125)*X(142)&
            &-JVS(126)*X(151)-JVS(127)*X(207)-JVS(128)*X(213))/(JVS(119))
  X(27) = (X(27)-JVS(117)*X(146)-JVS(118)*X(213))/(JVS(116))
  X(26) = (X(26)-JVS(114)*X(81)-JVS(115)*X(213))/(JVS(113))
  X(25) = (X(25)-JVS(111)*X(65)-JVS(112)*X(206))/(JVS(110))
  X(24) = (X(24)-JVS(108)*X(65)-JVS(109)*X(214))/(JVS(107))
  X(23) = (X(23)-JVS(103)*X(105)-JVS(104)*X(112)-JVS(105)*X(113)-JVS(106)*X(213))/(JVS(102))
  X(22) = (X(22)-JVS(101)*X(23))/(JVS(100))
  X(21) = (X(21)-JVS(98)*X(60)-JVS(99)*X(206))/(JVS(97))
  X(20) = (X(20)-JVS(95)*X(60)-JVS(96)*X(214))/(JVS(94))
  X(19) = (X(19)-JVS(93)*X(213))/(JVS(92))
  X(18) = (X(18)-JVS(88)*X(19)-JVS(89)*X(206)-JVS(90)*X(213)-JVS(91)*X(214))/(JVS(87))
  X(17) = (X(17)-JVS(85)*X(18)-JVS(86)*X(206))/(JVS(84))
  X(16) = (X(16)-JVS(82)*X(18)-JVS(83)*X(214))/(JVS(81))
  X(15) = (X(15)-JVS(79)*X(157)-JVS(80)*X(210))/(JVS(78))
  X(14) = (X(14)-JVS(76)*X(157)-JVS(77)*X(213))/(JVS(75))
  X(13) = (X(13)-JVS(73)*X(61)-JVS(74)*X(206))/(JVS(72))
  X(12) = (X(12)-JVS(70)*X(61)-JVS(71)*X(214))/(JVS(69))
  X(11) = (X(11)-JVS(61)*X(121)-JVS(62)*X(129)-JVS(63)*X(155)-JVS(64)*X(204)-JVS(65)*X(206)-JVS(66)*X(210)-JVS(67)&
            &*X(212)-JVS(68)*X(214))/(JVS(60))
  X(10) = (X(10)-JVS(59)*X(11))/(JVS(58))
  X(9) = (X(9)-JVS(51)*X(41)-JVS(52)*X(44)-JVS(53)*X(50)-JVS(54)*X(56)-JVS(55)*X(73)-JVS(56)*X(95)-JVS(57)*X(125))&
           &/(JVS(50))
  X(8) = (X(8)-JVS(43)*X(41)-JVS(44)*X(44)-JVS(45)*X(50)-JVS(46)*X(56)-JVS(47)*X(73)-JVS(48)*X(95)-JVS(49)*X(125))&
           &/(JVS(42))
  X(7) = (X(7)-JVS(40)*X(45)-JVS(41)*X(64))/(JVS(39))
  X(6) = (X(6)-JVS(11)*X(80)-JVS(12)*X(96)-JVS(13)*X(102)-JVS(14)*X(109)-JVS(15)*X(119)-JVS(16)*X(127)-JVS(17)*X(130)&
           &-JVS(18)*X(137)-JVS(19)*X(141)-JVS(20)*X(144)-JVS(21)*X(154)-JVS(22)*X(156)-JVS(23)*X(163)-JVS(24)*X(175)&
           &-JVS(25)*X(177)-JVS(26)*X(178)-JVS(27)*X(183)-JVS(28)*X(188)-JVS(29)*X(192)-JVS(30)*X(205)-JVS(31)*X(206)&
           &-JVS(32)*X(208)-JVS(33)*X(210)-JVS(34)*X(211)-JVS(35)*X(212)-JVS(36)*X(213)-JVS(37)*X(214)-JVS(38)*X(215))&
           &/(JVS(10))
  X(5) = (X(5)-JVS(6)*X(41)-JVS(7)*X(44)-JVS(8)*X(50)-JVS(9)*X(56))/(JVS(5))
  X(4) = X(4)/JVS(4)
  X(3) = X(3)/JVS(3)
  X(2) = X(2)/JVS(2)
  X(1) = X(1)/JVS(1)
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(2)
  XX(3) = X(3)/JVS(3)
  XX(4) = X(4)/JVS(4)
  XX(5) = X(5)/JVS(5)
  XX(6) = X(6)/JVS(10)
  XX(7) = X(7)/JVS(39)
  XX(8) = X(8)/JVS(42)
  XX(9) = X(9)/JVS(50)
  XX(10) = X(10)/JVS(58)
  XX(11) = (X(11)-JVS(59)*XX(10))/(JVS(60))
  XX(12) = X(12)/JVS(69)
  XX(13) = X(13)/JVS(72)
  XX(14) = X(14)/JVS(75)
  XX(15) = X(15)/JVS(78)
  XX(16) = X(16)/JVS(81)
  XX(17) = X(17)/JVS(84)
  XX(18) = (X(18)-JVS(82)*XX(16)-JVS(85)*XX(17))/(JVS(87))
  XX(19) = (X(19)-JVS(88)*XX(18))/(JVS(92))
  XX(20) = X(20)/JVS(94)
  XX(21) = X(21)/JVS(97)
  XX(22) = X(22)/JVS(100)
  XX(23) = (X(23)-JVS(101)*XX(22))/(JVS(102))
  XX(24) = X(24)/JVS(107)
  XX(25) = X(25)/JVS(110)
  XX(26) = X(26)/JVS(113)
  XX(27) = X(27)/JVS(116)
  XX(28) = X(28)/JVS(119)
  XX(29) = X(29)/JVS(129)
  XX(30) = X(30)/JVS(131)
  XX(31) = X(31)/JVS(133)
  XX(32) = X(32)/JVS(135)
  XX(33) = X(33)/JVS(139)
  XX(34) = (X(34)-JVS(140)*XX(33))/(JVS(141))
  XX(35) = X(35)/JVS(144)
  XX(36) = X(36)/JVS(146)
  XX(37) = X(37)/JVS(212)
  XX(38) = X(38)/JVS(277)
  XX(39) = X(39)/JVS(324)
  XX(40) = X(40)/JVS(333)
  XX(41) = (X(41)-JVS(6)*XX(5)-JVS(43)*XX(8)-JVS(51)*XX(9)-JVS(213)*XX(37))/(JVS(343))
  XX(42) = X(42)/JVS(345)
  XX(43) = X(43)/JVS(347)
  XX(44) = (X(44)-JVS(7)*XX(5)-JVS(44)*XX(8)-JVS(52)*XX(9)-JVS(214)*XX(37))/(JVS(349))
  XX(45) = (X(45)-JVS(40)*XX(7)-JVS(147)*XX(36))/(JVS(351))
  XX(46) = X(46)/JVS(355)
  XX(47) = X(47)/JVS(357)
  XX(48) = X(48)/JVS(361)
  XX(49) = X(49)/JVS(363)
  XX(50) = (X(50)-JVS(8)*XX(5)-JVS(45)*XX(8)-JVS(53)*XX(9)-JVS(215)*XX(37))/(JVS(365))
  XX(51) = (X(51)-JVS(148)*XX(36))/(JVS(368))
  XX(52) = X(52)/JVS(371)
  XX(53) = X(53)/JVS(374)
  XX(54) = X(54)/JVS(376)
  XX(55) = X(55)/JVS(379)
  XX(56) = (X(56)-JVS(9)*XX(5)-JVS(46)*XX(8)-JVS(54)*XX(9))/(JVS(381))
  XX(57) = X(57)/JVS(385)
  XX(58) = (X(58)-JVS(136)*XX(32))/(JVS(389))
  XX(59) = X(59)/JVS(393)
  XX(60) = (X(60)-JVS(95)*XX(20)-JVS(98)*XX(21))/(JVS(397))
  XX(61) = (X(61)-JVS(70)*XX(12)-JVS(73)*XX(13))/(JVS(402))
  XX(62) = (X(62)-JVS(137)*XX(32))/(JVS(406))
  XX(63) = (X(63)-JVS(138)*XX(32))/(JVS(411))
  XX(64) = (X(64)-JVS(41)*XX(7)-JVS(149)*XX(36))/(JVS(417))
  XX(65) = (X(65)-JVS(108)*XX(24)-JVS(111)*XX(25))/(JVS(426))
  XX(66) = X(66)/JVS(431)
  XX(67) = X(67)/JVS(435)
  XX(68) = (X(68)-JVS(216)*XX(37))/(JVS(441))
  XX(69) = (X(69)-JVS(150)*XX(36))/(JVS(447))
  XX(70) = (X(70)-JVS(278)*XX(38))/(JVS(450))
  XX(71) = (X(71)-JVS(279)*XX(38))/(JVS(453))
  XX(72) = (X(72)-JVS(217)*XX(37))/(JVS(456))
  XX(73) = (X(73)-JVS(47)*XX(8)-JVS(55)*XX(9)-JVS(218)*XX(37)-JVS(386)*XX(57)-JVS(436)*XX(67))/(JVS(459))
  XX(74) = (X(74)-JVS(151)*XX(36))/(JVS(463))
  XX(75) = (X(75)-JVS(152)*XX(36))/(JVS(468))
  XX(76) = (X(76)-JVS(219)*XX(37)-JVS(344)*XX(41)-JVS(366)*XX(50))/(JVS(475))
  XX(77) = X(77)/JVS(479)
  XX(78) = X(78)/JVS(483)
  XX(79) = X(79)/JVS(487)
  XX(80) = (X(80)-JVS(11)*XX(6)-JVS(220)*XX(37)-JVS(427)*XX(65))/(JVS(491))
  XX(81) = (X(81)-JVS(114)*XX(26)-JVS(221)*XX(37))/(JVS(494))
  XX(82) = (X(82)-JVS(280)*XX(38))/(JVS(497))
  XX(83) = (X(83)-JVS(153)*XX(36))/(JVS(500))
  XX(84) = (X(84)-JVS(154)*XX(36))/(JVS(505))
  XX(85) = (X(85)-JVS(222)*XX(37))/(JVS(511))
  XX(86) = (X(86)-JVS(155)*XX(36))/(JVS(516))
  XX(87) = X(87)/JVS(521)
  XX(88) = X(88)/JVS(526)
  XX(89) = X(89)/JVS(530)
  XX(90) = (X(90)-JVS(223)*XX(37))/(JVS(534))
  XX(91) = X(91)/JVS(538)
  XX(92) = X(92)/JVS(543)
  XX(93) = X(93)/JVS(549)
  XX(94) = X(94)/JVS(554)
  XX(95) = (X(95)-JVS(48)*XX(8)-JVS(56)*XX(9)-JVS(224)*XX(37)-JVS(387)*XX(57)-JVS(437)*XX(67))/(JVS(565))
  XX(96) = (X(96)-JVS(12)*XX(6)-JVS(281)*XX(38))/(JVS(570))
  XX(97) = (X(97)-JVS(156)*XX(36)-JVS(282)*XX(38)-JVS(364)*XX(49))/(JVS(573))
  XX(98) = (X(98)-JVS(225)*XX(37)-JVS(501)*XX(83))/(JVS(577))
  XX(99) = X(99)/JVS(581)
  XX(100) = (X(100)-JVS(157)*XX(36))/(JVS(585))
  XX(101) = X(101)/JVS(594)
  XX(102) = (X(102)-JVS(13)*XX(6)-JVS(283)*XX(38))/(JVS(599))
  XX(103) = (X(103)-JVS(158)*XX(36))/(JVS(605))
  XX(104) = (X(104)-JVS(284)*XX(38))/(JVS(610))
  XX(105) = (X(105)-JVS(103)*XX(23)-JVS(407)*XX(62)-JVS(412)*XX(63))/(JVS(614))
  XX(106) = X(106)/JVS(618)
  XX(107) = (X(107)-JVS(159)*XX(36))/(JVS(623))
  XX(108) = (X(108)-JVS(285)*XX(38))/(JVS(632))
  XX(109) = (X(109)-JVS(14)*XX(6)-JVS(226)*XX(37))/(JVS(637))
  XX(110) = (X(110)-JVS(286)*XX(38))/(JVS(644))
  XX(111) = (X(111)-JVS(160)*XX(36)-JVS(352)*XX(45))/(JVS(650))
  XX(112) = (X(112)-JVS(104)*XX(23)-JVS(408)*XX(62)-JVS(413)*XX(63))/(JVS(656))
  XX(113) = (X(113)-JVS(105)*XX(23)-JVS(390)*XX(58))/(JVS(660))
  XX(114) = (X(114)-JVS(227)*XX(37))/(JVS(664))
  XX(115) = (X(115)-JVS(228)*XX(37)-JVS(555)*XX(94)-JVS(586)*XX(100))/(JVS(669))
  XX(116) = (X(116)-JVS(229)*XX(37)-JVS(556)*XX(94)-JVS(587)*XX(100))/(JVS(674))
  XX(117) = X(117)/JVS(679)
  XX(118) = X(118)/JVS(686)
  XX(119) = (X(119)-JVS(15)*XX(6)-JVS(287)*XX(38))/(JVS(693))
  XX(120) = (X(120)-JVS(230)*XX(37))/(JVS(700))
  XX(121) = (X(121)-JVS(61)*XX(11)-JVS(231)*XX(37))/(JVS(705))
  XX(122) = (X(122)-JVS(232)*XX(37)-JVS(288)*XX(38))/(JVS(711))
  XX(123) = (X(123)-JVS(289)*XX(38))/(JVS(715))
  XX(124) = (X(124)-JVS(233)*XX(37)-JVS(557)*XX(94)-JVS(588)*XX(100))/(JVS(720))
  XX(125) = (X(125)-JVS(49)*XX(8)-JVS(57)*XX(9)-JVS(234)*XX(37)-JVS(388)*XX(57)-JVS(438)*XX(67))/(JVS(725))
  XX(126) = (X(126)-JVS(120)*XX(28)-JVS(161)*XX(36)-JVS(325)*XX(39)-JVS(334)*XX(40))/(JVS(731))
  XX(127) = (X(127)-JVS(16)*XX(6)-JVS(162)*XX(36)-JVS(544)*XX(92))/(JVS(739))
  XX(128) = (X(128)-JVS(163)*XX(36)-JVS(545)*XX(92))/(JVS(746))
  XX(129) = (X(129)-JVS(62)*XX(11)-JVS(164)*XX(36)-JVS(235)*XX(37))/(JVS(751))
  XX(130) = (X(130)-JVS(17)*XX(6)-JVS(142)*XX(34)-JVS(165)*XX(36)-JVS(290)*XX(38)-JVS(442)*XX(68)-JVS(517)*XX(86))&
              &/(JVS(758))
  XX(131) = (X(131)-JVS(236)*XX(37)-JVS(291)*XX(38))/(JVS(764))
  XX(132) = (X(132)-JVS(121)*XX(28)-JVS(166)*XX(36)-JVS(326)*XX(39)-JVS(335)*XX(40))/(JVS(768))
  XX(133) = (X(133)-JVS(122)*XX(28)-JVS(167)*XX(36)-JVS(327)*XX(39)-JVS(336)*XX(40))/(JVS(775))
  XX(134) = (X(134)-JVS(168)*XX(36)-JVS(566)*XX(95)-JVS(726)*XX(125))/(JVS(785))
  XX(135) = (X(135)-JVS(123)*XX(28)-JVS(169)*XX(36)-JVS(328)*XX(39)-JVS(337)*XX(40))/(JVS(792))
  XX(136) = X(136)/JVS(802)
  XX(137) = (X(137)-JVS(18)*XX(6)-JVS(170)*XX(36)-JVS(237)*XX(37)-JVS(369)*XX(51))/(JVS(811))
  XX(138) = X(138)/JVS(817)
  XX(139) = (X(139)-JVS(124)*XX(28)-JVS(171)*XX(36)-JVS(329)*XX(39)-JVS(338)*XX(40))/(JVS(835))
  XX(140) = (X(140)-JVS(172)*XX(36)-JVS(238)*XX(37)-JVS(353)*XX(45)-JVS(651)*XX(111))/(JVS(842))
  XX(141) = (X(141)-JVS(19)*XX(6)-JVS(239)*XX(37)-JVS(292)*XX(38)-JVS(409)*XX(62)-JVS(414)*XX(63)-JVS(418)*XX(64))&
              &/(JVS(852))
  XX(142) = (X(142)-JVS(125)*XX(28)-JVS(173)*XX(36)-JVS(339)*XX(40))/(JVS(857))
  XX(143) = X(143)/JVS(874)
  XX(144) = (X(144)-JVS(20)*XX(6)-JVS(174)*XX(36)-JVS(293)*XX(38)-JVS(633)*XX(108))/(JVS(897))
  XX(145) = (X(145)-JVS(240)*XX(37)-JVS(558)*XX(94)-JVS(624)*XX(107))/(JVS(909))
  XX(146) = (X(146)-JVS(117)*XX(27)-JVS(175)*XX(36)-JVS(241)*XX(37)-JVS(419)*XX(64))/(JVS(923))
  XX(147) = (X(147)-JVS(130)*XX(29)-JVS(132)*XX(30)-JVS(242)*XX(37)-JVS(559)*XX(94)-JVS(589)*XX(100)-JVS(670)*XX(115)&
              &-JVS(675)*XX(116))/(JVS(936))
  XX(148) = (X(148)-JVS(134)*XX(31)-JVS(243)*XX(37)-JVS(294)*XX(38))/(JVS(957))
  XX(149) = (X(149)-JVS(176)*XX(36)-JVS(531)*XX(89)-JVS(818)*XX(138))/(JVS(971))
  XX(150) = (X(150)-JVS(177)*XX(36)-JVS(244)*XX(37)-JVS(354)*XX(45)-JVS(652)*XX(111))/(JVS(979))
  XX(151) = (X(151)-JVS(126)*XX(28)-JVS(178)*XX(36)-JVS(330)*XX(39)-JVS(340)*XX(40)-JVS(600)*XX(102)-JVS(875)*XX(143))&
              &/(JVS(991))
  XX(152) = (X(152)-JVS(179)*XX(36)-JVS(484)*XX(78)-JVS(819)*XX(138))/(JVS(1000))
  XX(153) = (X(153)-JVS(295)*XX(38))/(JVS(1015))
  XX(154) = (X(154)-JVS(21)*XX(6)-JVS(180)*XX(36)-JVS(296)*XX(38)-JVS(680)*XX(117)-JVS(1016)*XX(153))/(JVS(1030))
  XX(155) = (X(155)-JVS(63)*XX(11)-JVS(181)*XX(36)-JVS(245)*XX(37)-JVS(297)*XX(38)-JVS(522)*XX(87)-JVS(759)*XX(130)&
              &-JVS(1017)*XX(153))/(JVS(1037))
  XX(156) = (X(156)-JVS(22)*XX(6))/(JVS(1050))
  XX(157) = (X(157)-JVS(76)*XX(14)-JVS(79)*XX(15)-JVS(246)*XX(37)-JVS(298)*XX(38)-JVS(732)*XX(126)-JVS(858)*XX(142)&
              &-JVS(876)*XX(143)-JVS(992)*XX(151)-JVS(1051)*XX(156))/(JVS(1072))
  XX(158) = (X(158)-JVS(182)*XX(36)-JVS(527)*XX(88)-JVS(820)*XX(138))/(JVS(1078))
  XX(159) = (X(159)-JVS(183)*XX(36)-JVS(550)*XX(93))/(JVS(1088))
  XX(160) = (X(160)-JVS(184)*XX(36)-JVS(488)*XX(79)-JVS(821)*XX(138))/(JVS(1100))
  XX(161) = (X(161)-JVS(185)*XX(36)-JVS(358)*XX(47)-JVS(420)*XX(64)-JVS(665)*XX(114)-JVS(694)*XX(119)-JVS(924)*XX(146)&
              &-JVS(1018)*XX(153)-JVS(1052)*XX(156))/(JVS(1111))
  XX(162) = (X(162)-JVS(186)*XX(36)-JVS(822)*XX(138))/(JVS(1119))
  XX(163) = (X(163)-JVS(23)*XX(6)-JVS(187)*XX(36)-JVS(823)*XX(138))/(JVS(1130))
  XX(164) = (X(164)-JVS(382)*XX(56)-JVS(394)*XX(59)-JVS(460)*XX(73)-JVS(464)*XX(74)-JVS(727)*XX(125)-JVS(786)*XX(134))&
              &/(JVS(1153))
  XX(165) = (X(165)-JVS(188)*XX(36)-JVS(247)*XX(37)-JVS(560)*XX(94)-JVS(625)*XX(107)-JVS(671)*XX(115)-JVS(676)*XX(116)&
              &-JVS(910)*XX(145)-JVS(937)*XX(147))/(JVS(1166))
  XX(166) = (X(166)-JVS(248)*XX(37)-JVS(299)*XX(38)-JVS(421)*XX(64)-JVS(812)*XX(137)-JVS(1053)*XX(156))/(JVS(1179))
  XX(167) = (X(167)-JVS(249)*XX(37)-JVS(350)*XX(44)-JVS(367)*XX(50)-JVS(439)*XX(67)-JVS(476)*XX(76)-JVS(512)*XX(85)&
              &-JVS(567)*XX(95)-JVS(728)*XX(125)-JVS(787)*XX(134)-JVS(911)*XX(145)-JVS(1154)*XX(164))/(JVS(1195))
  XX(168) = (X(168)-JVS(189)*XX(36))/(JVS(1230))
  XX(169) = (X(169)-JVS(250)*XX(37)-JVS(477)*XX(76)-JVS(506)*XX(84)-JVS(513)*XX(85)-JVS(561)*XX(94)-JVS(590)*XX(100)&
              &-JVS(626)*XX(107)-JVS(721)*XX(124)-JVS(912)*XX(145)-JVS(938)*XX(147)-JVS(1155)*XX(164)-JVS(1167)*XX(165)&
              &-JVS(1196)*XX(167)-JVS(1231)*XX(168))/(JVS(1268))
  XX(170) = (X(170)-JVS(190)*XX(36)-JVS(251)*XX(37)-JVS(843)*XX(140)-JVS(980)*XX(150)-JVS(1232)*XX(168))/(JVS(1280))
  XX(171) = (X(171)-JVS(191)*XX(36)-JVS(824)*XX(138)-JVS(844)*XX(140)-JVS(981)*XX(150)-JVS(1233)*XX(168)-JVS(1281)&
              &*XX(170))/(JVS(1292))
  XX(172) = (X(172)-JVS(192)*XX(36)-JVS(252)*XX(37)-JVS(539)*XX(91)-JVS(825)*XX(138)-JVS(982)*XX(150)-JVS(1234)*XX(168))&
              &/(JVS(1301))
  XX(173) = (X(173)-JVS(193)*XX(36)-JVS(372)*XX(52)-JVS(523)*XX(87))/(JVS(1312))
  XX(174) = (X(174)-JVS(194)*XX(36)-JVS(253)*XX(37)-JVS(540)*XX(91)-JVS(826)*XX(138)-JVS(845)*XX(140)-JVS(983)*XX(150)&
              &-JVS(1054)*XX(156)-JVS(1235)*XX(168))/(JVS(1325))
  XX(175) = (X(175)-JVS(24)*XX(6))/(JVS(1344))
  XX(176) = (X(176)-JVS(195)*XX(36)-JVS(359)*XX(47)-JVS(422)*XX(64)-JVS(666)*XX(114)-JVS(925)*XX(146)-JVS(1055)*XX(156)&
              &-JVS(1112)*XX(161)-JVS(1120)*XX(162)-JVS(1180)*XX(166)-JVS(1236)*XX(168)-JVS(1345)*XX(175))/(JVS(1376))
  XX(177) = (X(177)-JVS(25)*XX(6)-JVS(300)*XX(38)-JVS(958)*XX(148)-JVS(1056)*XX(156)-JVS(1237)*XX(168))/(JVS(1392))
  XX(178) = (X(178)-JVS(26)*XX(6)-JVS(254)*XX(37)-JVS(391)*XX(58)-JVS(423)*XX(64)-JVS(687)*XX(118)-JVS(695)*XX(119)&
              &-JVS(898)*XX(144)-JVS(959)*XX(148)-JVS(1019)*XX(153)-JVS(1057)*XX(156)-JVS(1113)*XX(161)-JVS(1121)*XX(162)&
              &-JVS(1181)*XX(166)-JVS(1238)*XX(168)-JVS(1346)*XX(175)-JVS(1377)*XX(176)-JVS(1393)*XX(177))/(JVS(1408))
  XX(179) = (X(179)-JVS(196)*XX(36)-JVS(301)*XX(38)-JVS(611)*XX(104)-JVS(638)*XX(109)-JVS(645)*XX(110)-JVS(740)*XX(127)&
              &-JVS(827)*XX(138)-JVS(960)*XX(148)-JVS(1239)*XX(168)-JVS(1347)*XX(175)-JVS(1394)*XX(177))/(JVS(1418))
  XX(180) = (X(180)-JVS(255)*XX(37)-JVS(562)*XX(94)-JVS(591)*XX(100)-JVS(672)*XX(115)-JVS(677)*XX(116)-JVS(913)*XX(145)&
              &-JVS(939)*XX(147)-JVS(1168)*XX(165)-JVS(1240)*XX(168))/(JVS(1433))
  XX(181) = (X(181)-JVS(197)*XX(36)-JVS(551)*XX(93)-JVS(828)*XX(138)-JVS(1089)*XX(159)-JVS(1348)*XX(175))/(JVS(1451))
  XX(182) = (X(182)-JVS(198)*XX(36)-JVS(619)*XX(106)-JVS(829)*XX(138)-JVS(926)*XX(146)-JVS(1058)*XX(156)-JVS(1241)&
              &*XX(168)-JVS(1349)*XX(175)-JVS(1395)*XX(177))/(JVS(1462))
  XX(183) = (X(183)-JVS(27)*XX(6)-JVS(199)*XX(36)-JVS(302)*XX(38)-JVS(681)*XX(117)-JVS(716)*XX(123)-JVS(1131)*XX(163)&
              &-JVS(1242)*XX(168)-JVS(1350)*XX(175))/(JVS(1475))
  XX(184) = (X(184)-JVS(145)*XX(35)-JVS(256)*XX(37)-JVS(303)*XX(38)-JVS(1243)*XX(168))/(JVS(1512))
  XX(185) = (X(185)-JVS(257)*XX(37)-JVS(706)*XX(121)-JVS(752)*XX(129)-JVS(803)*XX(136)-JVS(961)*XX(148)-JVS(1020)&
              &*XX(153)-JVS(1038)*XX(155)-JVS(1244)*XX(168)-JVS(1313)*XX(173)-JVS(1396)*XX(177)-JVS(1513)*XX(184))&
              &/(JVS(1536))
  XX(186) = (X(186)-JVS(258)*XX(37)-JVS(304)*XX(38)-JVS(769)*XX(132)-JVS(793)*XX(135)-JVS(877)*XX(143)-JVS(1397)*XX(177)&
              &-JVS(1419)*XX(179)-JVS(1514)*XX(184))/(JVS(1549))
  XX(187) = (X(187)-JVS(305)*XX(38)-JVS(1090)*XX(159)-JVS(1351)*XX(175)-JVS(1434)*XX(180)-JVS(1515)*XX(184))/(JVS(1562))
  XX(188) = (X(188)-JVS(28)*XX(6)-JVS(200)*XX(36)-JVS(306)*XX(38)-JVS(571)*XX(96)-JVS(574)*XX(97)-JVS(606)*XX(103)&
              &-JVS(615)*XX(105)-JVS(657)*XX(112)-JVS(661)*XX(113)-JVS(747)*XX(128)-JVS(830)*XX(138)-JVS(853)*XX(141)&
              &-JVS(899)*XX(144)-JVS(927)*XX(146)-JVS(962)*XX(148)-JVS(1021)*XX(153)-JVS(1059)*XX(156)-JVS(1182)*XX(166)&
              &-JVS(1245)*XX(168)-JVS(1352)*XX(175)-JVS(1378)*XX(176)-JVS(1398)*XX(177)-JVS(1409)*XX(178)-JVS(1420)*XX(179)&
              &-JVS(1516)*XX(184)-JVS(1550)*XX(186))/(JVS(1578))
  XX(189) = (X(189)-JVS(201)*XX(36)-JVS(307)*XX(38)-JVS(601)*XX(102)-JVS(831)*XX(138)-JVS(1183)*XX(166)-JVS(1246)&
              &*XX(168)-JVS(1353)*XX(175)-JVS(1517)*XX(184))/(JVS(1590))
  XX(190) = (X(190)-JVS(202)*XX(36)-JVS(480)*XX(77)-JVS(688)*XX(118)-JVS(1354)*XX(175))/(JVS(1608))
  XX(191) = (X(191)-JVS(203)*XX(36)-JVS(259)*XX(37)-JVS(804)*XX(136)-JVS(1355)*XX(175)-JVS(1410)*XX(178)-JVS(1518)&
              &*XX(184)-JVS(1537)*XX(185)-JVS(1551)*XX(186)-JVS(1609)*XX(190))/(JVS(1628))
  XX(192) = (X(192)-JVS(29)*XX(6)-JVS(308)*XX(38)-JVS(1060)*XX(156)-JVS(1356)*XX(175)-JVS(1519)*XX(184))/(JVS(1674))
  XX(193) = (X(193)-JVS(204)*XX(36)-JVS(546)*XX(92)-JVS(832)*XX(138)-JVS(1001)*XX(152)-JVS(1101)*XX(160)-JVS(1357)&
              &*XX(175)-JVS(1563)*XX(187)-JVS(1610)*XX(190)-JVS(1675)*XX(192))/(JVS(1706))
  XX(194) = (X(194)-JVS(260)*XX(37)-JVS(309)*XX(38)-JVS(776)*XX(133)-JVS(859)*XX(142)-JVS(878)*XX(143)-JVS(972)*XX(149)&
              &-JVS(1022)*XX(153)-JVS(1061)*XX(156)-JVS(1079)*XX(158)-JVS(1358)*XX(175)-JVS(1435)*XX(180)-JVS(1520)*XX(184)&
              &-JVS(1676)*XX(192))/(JVS(1719))
  XX(195) = (X(195)-JVS(261)*XX(37)-JVS(424)*XX(64)-JVS(1002)*XX(152)-JVS(1102)*XX(160)-JVS(1122)*XX(162)-JVS(1247)&
              &*XX(168)-JVS(1359)*XX(175)-JVS(1564)*XX(187)-JVS(1611)*XX(190)-JVS(1677)*XX(192)-JVS(1707)*XX(193))&
              &/(JVS(1740))
  XX(196) = (X(196)-JVS(262)*XX(37)-JVS(502)*XX(83)-JVS(563)*XX(94)-JVS(578)*XX(98)-JVS(627)*XX(107)-JVS(722)*XX(124)&
              &-JVS(914)*XX(145)-JVS(940)*XX(147)-JVS(1169)*XX(165)-JVS(1248)*XX(168)-JVS(1269)*XX(169)-JVS(1436)*XX(180))&
              &/(JVS(1793))
  XX(197) = (X(197)-JVS(263)*XX(37)-JVS(310)*XX(38)-JVS(1249)*XX(168)-JVS(1437)*XX(180)-JVS(1794)*XX(196))/(JVS(1879))
  XX(198) = (X(198)-JVS(264)*XX(37)-JVS(440)*XX(67)-JVS(457)*XX(72)-JVS(507)*XX(84)-JVS(514)*XX(85)-JVS(564)*XX(94)&
              &-JVS(628)*XX(107)-JVS(915)*XX(145)-JVS(1156)*XX(164)-JVS(1170)*XX(165)-JVS(1197)*XX(167)-JVS(1250)*XX(168)&
              &-JVS(1270)*XX(169)-JVS(1438)*XX(180)-JVS(1795)*XX(196)-JVS(1880)*XX(197))/(JVS(1914))
  XX(199) = (X(199)-JVS(265)*XX(37)-JVS(311)*XX(38)-JVS(836)*XX(139)-JVS(860)*XX(142)-JVS(879)*XX(143)-JVS(1062)*XX(156)&
              &-JVS(1314)*XX(173)-JVS(1463)*XX(182)-JVS(1521)*XX(184)-JVS(1612)*XX(190)-JVS(1720)*XX(194)-JVS(1796)*XX(196)&
              &-JVS(1881)*XX(197)-JVS(1915)*XX(198))/(JVS(1939))
  XX(200) = (X(200)-JVS(266)*XX(37)-JVS(1251)*XX(168)-JVS(1315)*XX(173)-JVS(1452)*XX(181)-JVS(1522)*XX(184)-JVS(1613)&
              &*XX(190)-JVS(1678)*XX(192)-JVS(1741)*XX(195)-JVS(1797)*XX(196)-JVS(1882)*XX(197)-JVS(1916)*XX(198))&
              &/(JVS(1975))
  XX(201) = (X(201)-JVS(267)*XX(37)-JVS(312)*XX(38)-JVS(1252)*XX(168)-JVS(1439)*XX(180)-JVS(1798)*XX(196)-JVS(1883)&
              &*XX(197)-JVS(1917)*XX(198))/(JVS(2010))
  XX(202) = (X(202)-JVS(268)*XX(37)-JVS(313)*XX(38)-JVS(1253)*XX(168)-JVS(1316)*XX(173)-JVS(1614)*XX(190)-JVS(1799)&
              &*XX(196)-JVS(1884)*XX(197)-JVS(1918)*XX(198)-JVS(2011)*XX(201))/(JVS(2064))
  XX(203) = (X(203)-JVS(314)*XX(38)-JVS(377)*XX(54)-JVS(582)*XX(99)-JVS(592)*XX(100)-JVS(701)*XX(120)-JVS(723)*XX(124)&
              &-JVS(941)*XX(147)-JVS(1003)*XX(152)-JVS(1080)*XX(158)-JVS(1091)*XX(159)-JVS(1103)*XX(160)-JVS(1171)*XX(165)&
              &-JVS(1254)*XX(168)-JVS(1271)*XX(169)-JVS(1360)*XX(175)-JVS(1440)*XX(180)-JVS(1523)*XX(184)-JVS(1565)*XX(187)&
              &-JVS(1615)*XX(190)-JVS(1679)*XX(192)-JVS(1721)*XX(194)-JVS(1800)*XX(196)-JVS(1885)*XX(197)-JVS(1919)*XX(198)&
              &-JVS(2012)*XX(201)-JVS(2065)*XX(202))/(JVS(2113))
  XX(204) = (X(204)-JVS(64)*XX(11)-JVS(205)*XX(36)-JVS(269)*XX(37)-JVS(370)*XX(51)-JVS(373)*XX(52)-JVS(378)*XX(54)&
              &-JVS(443)*XX(68)-JVS(448)*XX(69)-JVS(461)*XX(73)-JVS(465)*XX(74)-JVS(469)*XX(75)-JVS(518)*XX(86)-JVS(579)&
              &*XX(98)-JVS(717)*XX(123)-JVS(724)*XX(124)-JVS(729)*XX(125)-JVS(733)*XX(126)-JVS(760)*XX(130)-JVS(770)*XX(132)&
              &-JVS(777)*XX(133)-JVS(788)*XX(134)-JVS(794)*XX(135)-JVS(813)*XX(137)-JVS(837)*XX(139)-JVS(861)*XX(142)&
              &-JVS(880)*XX(143)-JVS(916)*XX(145)-JVS(942)*XX(147)-JVS(993)*XX(151)-JVS(1039)*XX(155)-JVS(1063)*XX(156)&
              &-JVS(1157)*XX(164)-JVS(1172)*XX(165)-JVS(1198)*XX(167)-JVS(1255)*XX(168)-JVS(1272)*XX(169)-JVS(1317)*XX(173)&
              &-JVS(1361)*XX(175)-JVS(1399)*XX(177)-JVS(1441)*XX(180)-JVS(1476)*XX(183)-JVS(1524)*XX(184)-JVS(1591)*XX(189)&
              &-JVS(1616)*XX(190)-JVS(1680)*XX(192)-JVS(1801)*XX(196)-JVS(1886)*XX(197)-JVS(1920)*XX(198)-JVS(1940)*XX(199)&
              &-JVS(1976)*XX(200)-JVS(2013)*XX(201)-JVS(2066)*XX(202)-JVS(2114)*XX(203))/(JVS(2217))
  XX(205) = (X(205)-JVS(30)*XX(6)-JVS(270)*XX(37)-JVS(315)*XX(38)-JVS(639)*XX(109)-JVS(653)*XX(111)-JVS(673)*XX(115)&
              &-JVS(678)*XX(116)-JVS(689)*XX(118)-JVS(696)*XX(119)-JVS(712)*XX(122)-JVS(718)*XX(123)-JVS(734)*XX(126)&
              &-JVS(741)*XX(127)-JVS(765)*XX(131)-JVS(771)*XX(132)-JVS(778)*XX(133)-JVS(795)*XX(135)-JVS(838)*XX(139)&
              &-JVS(854)*XX(141)-JVS(862)*XX(142)-JVS(881)*XX(143)-JVS(900)*XX(144)-JVS(928)*XX(146)-JVS(943)*XX(147)&
              &-JVS(963)*XX(148)-JVS(984)*XX(150)-JVS(994)*XX(151)-JVS(1023)*XX(153)-JVS(1064)*XX(156)-JVS(1073)*XX(157)&
              &-JVS(1158)*XX(164)-JVS(1173)*XX(165)-JVS(1184)*XX(166)-JVS(1199)*XX(167)-JVS(1256)*XX(168)-JVS(1273)*XX(169)&
              &-JVS(1282)*XX(170)-JVS(1293)*XX(171)-JVS(1302)*XX(172)-JVS(1326)*XX(174)-JVS(1362)*XX(175)-JVS(1379)*XX(176)&
              &-JVS(1400)*XX(177)-JVS(1411)*XX(178)-JVS(1442)*XX(180)-JVS(1453)*XX(181)-JVS(1464)*XX(182)-JVS(1477)*XX(183)&
              &-JVS(1525)*XX(184)-JVS(1538)*XX(185)-JVS(1552)*XX(186)-JVS(1566)*XX(187)-JVS(1579)*XX(188)-JVS(1592)*XX(189)&
              &-JVS(1617)*XX(190)-JVS(1629)*XX(191)-JVS(1681)*XX(192)-JVS(1708)*XX(193)-JVS(1722)*XX(194)-JVS(1742)*XX(195)&
              &-JVS(1802)*XX(196)-JVS(1887)*XX(197)-JVS(1921)*XX(198)-JVS(1941)*XX(199)-JVS(1977)*XX(200)-JVS(2014)*XX(201)&
              &-JVS(2067)*XX(202)-JVS(2115)*XX(203)-JVS(2218)*XX(204))/(JVS(2271))
  XX(206) = (X(206)-JVS(31)*XX(6)-JVS(65)*XX(11)-JVS(74)*XX(13)-JVS(86)*XX(17)-JVS(89)*XX(18)-JVS(99)*XX(21)-JVS(112)&
              &*XX(25)-JVS(206)*XX(36)-JVS(271)*XX(37)-JVS(316)*XX(38)-JVS(360)*XX(47)-JVS(395)*XX(59)-JVS(398)*XX(60)&
              &-JVS(403)*XX(61)-JVS(425)*XX(64)-JVS(428)*XX(65)-JVS(466)*XX(74)-JVS(478)*XX(76)-JVS(575)*XX(97)-JVS(607)&
              &*XX(103)-JVS(634)*XX(108)-JVS(640)*XX(109)-JVS(646)*XX(110)-JVS(697)*XX(119)-JVS(707)*XX(121)-JVS(735)&
              &*XX(126)-JVS(742)*XX(127)-JVS(748)*XX(128)-JVS(753)*XX(129)-JVS(772)*XX(132)-JVS(779)*XX(133)-JVS(789)&
              &*XX(134)-JVS(796)*XX(135)-JVS(805)*XX(136)-JVS(814)*XX(137)-JVS(839)*XX(139)-JVS(846)*XX(140)-JVS(855)&
              &*XX(141)-JVS(863)*XX(142)-JVS(882)*XX(143)-JVS(901)*XX(144)-JVS(929)*XX(146)-JVS(964)*XX(148)-JVS(973)&
              &*XX(149)-JVS(985)*XX(150)-JVS(995)*XX(151)-JVS(1004)*XX(152)-JVS(1024)*XX(153)-JVS(1031)*XX(154)-JVS(1040)&
              &*XX(155)-JVS(1065)*XX(156)-JVS(1081)*XX(158)-JVS(1092)*XX(159)-JVS(1104)*XX(160)-JVS(1114)*XX(161)-JVS(1123)&
              &*XX(162)-JVS(1132)*XX(163)-JVS(1159)*XX(164)-JVS(1185)*XX(166)-JVS(1200)*XX(167)-JVS(1257)*XX(168)-JVS(1274)&
              &*XX(169)-JVS(1283)*XX(170)-JVS(1294)*XX(171)-JVS(1303)*XX(172)-JVS(1318)*XX(173)-JVS(1327)*XX(174)-JVS(1363)&
              &*XX(175)-JVS(1380)*XX(176)-JVS(1401)*XX(177)-JVS(1412)*XX(178)-JVS(1421)*XX(179)-JVS(1443)*XX(180)-JVS(1454)&
              &*XX(181)-JVS(1465)*XX(182)-JVS(1478)*XX(183)-JVS(1526)*XX(184)-JVS(1539)*XX(185)-JVS(1553)*XX(186)-JVS(1567)&
              &*XX(187)-JVS(1580)*XX(188)-JVS(1593)*XX(189)-JVS(1618)*XX(190)-JVS(1630)*XX(191)-JVS(1682)*XX(192)-JVS(1709)&
              &*XX(193)-JVS(1723)*XX(194)-JVS(1743)*XX(195)-JVS(1803)*XX(196)-JVS(1888)*XX(197)-JVS(1922)*XX(198)-JVS(1942)&
              &*XX(199)-JVS(1978)*XX(200)-JVS(2015)*XX(201)-JVS(2068)*XX(202)-JVS(2116)*XX(203)-JVS(2219)*XX(204)-JVS(2272)&
              &*XX(205))/(JVS(2350))
  XX(207) = (X(207)-JVS(127)*XX(28)-JVS(341)*XX(40)-JVS(736)*XX(126)-JVS(773)*XX(132)-JVS(780)*XX(133)-JVS(797)*XX(135)&
              &-JVS(840)*XX(139)-JVS(864)*XX(142)-JVS(883)*XX(143)-JVS(996)*XX(151)-JVS(1066)*XX(156)-JVS(1364)*XX(175)&
              &-JVS(1402)*XX(177)-JVS(1527)*XX(184)-JVS(1594)*XX(189)-JVS(1683)*XX(192)-JVS(1804)*XX(196)-JVS(1889)*XX(197)&
              &-JVS(1923)*XX(198)-JVS(1943)*XX(199)-JVS(1979)*XX(200)-JVS(2016)*XX(201)-JVS(2069)*XX(202)-JVS(2117)*XX(203)&
              &-JVS(2220)*XX(204)-JVS(2273)*XX(205)-JVS(2351)*XX(206))/(JVS(2378))
  XX(208) = (X(208)-JVS(32)*XX(6)-JVS(207)*XX(36)-JVS(317)*XX(38)-JVS(432)*XX(66)-JVS(519)*XX(86)-JVS(641)*XX(109)&
              &-JVS(647)*XX(110)-JVS(743)*XX(127)-JVS(749)*XX(128)-JVS(847)*XX(140)-JVS(965)*XX(148)-JVS(974)*XX(149)&
              &-JVS(986)*XX(150)-JVS(1005)*XX(152)-JVS(1025)*XX(153)-JVS(1032)*XX(154)-JVS(1082)*XX(158)-JVS(1093)*XX(159)&
              &-JVS(1105)*XX(160)-JVS(1124)*XX(162)-JVS(1133)*XX(163)-JVS(1258)*XX(168)-JVS(1284)*XX(170)-JVS(1295)*XX(171)&
              &-JVS(1304)*XX(172)-JVS(1319)*XX(173)-JVS(1328)*XX(174)-JVS(1365)*XX(175)-JVS(1403)*XX(177)-JVS(1422)*XX(179)&
              &-JVS(1455)*XX(181)-JVS(1466)*XX(182)-JVS(1479)*XX(183)-JVS(1528)*XX(184)-JVS(1540)*XX(185)-JVS(1554)*XX(186)&
              &-JVS(1568)*XX(187)-JVS(1581)*XX(188)-JVS(1595)*XX(189)-JVS(1619)*XX(190)-JVS(1631)*XX(191)-JVS(1684)*XX(192)&
              &-JVS(1710)*XX(193)-JVS(1724)*XX(194)-JVS(1744)*XX(195)-JVS(1805)*XX(196)-JVS(1890)*XX(197)-JVS(1924)*XX(198)&
              &-JVS(1944)*XX(199)-JVS(1980)*XX(200)-JVS(2017)*XX(201)-JVS(2070)*XX(202)-JVS(2118)*XX(203)-JVS(2221)*XX(204)&
              &-JVS(2274)*XX(205)-JVS(2352)*XX(206)-JVS(2379)*XX(207))/(JVS(2442))
  XX(209) = (X(209)-JVS(272)*XX(37)-JVS(318)*XX(38)-JVS(444)*XX(68)-JVS(682)*XX(117)-JVS(761)*XX(130)-JVS(798)*XX(135)&
              &-JVS(865)*XX(142)-JVS(884)*XX(143)-JVS(1033)*XX(154)-JVS(1067)*XX(156)-JVS(1134)*XX(163)-JVS(1259)*XX(168)&
              &-JVS(1366)*XX(175)-JVS(1480)*XX(183)-JVS(1529)*XX(184)-JVS(1596)*XX(189)-JVS(1685)*XX(192)-JVS(1745)*XX(195)&
              &-JVS(1806)*XX(196)-JVS(1891)*XX(197)-JVS(1925)*XX(198)-JVS(1981)*XX(200)-JVS(2018)*XX(201)-JVS(2071)*XX(202)&
              &-JVS(2119)*XX(203)-JVS(2222)*XX(204)-JVS(2275)*XX(205)-JVS(2353)*XX(206)-JVS(2380)*XX(207)-JVS(2443)*XX(208))&
              &/(JVS(2464))
  XX(210) = (X(210)-JVS(33)*XX(6)-JVS(66)*XX(11)-JVS(80)*XX(15)-JVS(273)*XX(37)-JVS(319)*XX(38)-JVS(445)*XX(68)-JVS(492)&
              &*XX(80)-JVS(495)*XX(81)-JVS(535)*XX(90)-JVS(580)*XX(98)-JVS(654)*XX(111)-JVS(683)*XX(117)-JVS(702)*XX(120)&
              &-JVS(713)*XX(122)-JVS(730)*XX(125)-JVS(754)*XX(129)-JVS(762)*XX(130)-JVS(766)*XX(131)-JVS(790)*XX(134)&
              &-JVS(806)*XX(136)-JVS(848)*XX(140)-JVS(885)*XX(143)-JVS(917)*XX(145)-JVS(966)*XX(148)-JVS(975)*XX(149)&
              &-JVS(987)*XX(150)-JVS(1026)*XX(153)-JVS(1034)*XX(154)-JVS(1041)*XX(155)-JVS(1068)*XX(156)-JVS(1074)*XX(157)&
              &-JVS(1135)*XX(163)-JVS(1160)*XX(164)-JVS(1201)*XX(167)-JVS(1260)*XX(168)-JVS(1275)*XX(169)-JVS(1285)*XX(170)&
              &-JVS(1296)*XX(171)-JVS(1305)*XX(172)-JVS(1320)*XX(173)-JVS(1329)*XX(174)-JVS(1367)*XX(175)-JVS(1444)*XX(180)&
              &-JVS(1456)*XX(181)-JVS(1467)*XX(182)-JVS(1481)*XX(183)-JVS(1530)*XX(184)-JVS(1541)*XX(185)-JVS(1555)*XX(186)&
              &-JVS(1569)*XX(187)-JVS(1582)*XX(188)-JVS(1597)*XX(189)-JVS(1620)*XX(190)-JVS(1632)*XX(191)-JVS(1686)*XX(192)&
              &-JVS(1711)*XX(193)-JVS(1725)*XX(194)-JVS(1746)*XX(195)-JVS(1807)*XX(196)-JVS(1892)*XX(197)-JVS(1926)*XX(198)&
              &-JVS(1945)*XX(199)-JVS(1982)*XX(200)-JVS(2019)*XX(201)-JVS(2072)*XX(202)-JVS(2120)*XX(203)-JVS(2223)*XX(204)&
              &-JVS(2276)*XX(205)-JVS(2354)*XX(206)-JVS(2381)*XX(207)-JVS(2444)*XX(208)-JVS(2465)*XX(209))/(JVS(2545))
  XX(211) = (X(211)-JVS(34)*XX(6)-JVS(331)*XX(39)-JVS(737)*XX(126)-JVS(774)*XX(132)-JVS(781)*XX(133)-JVS(799)*XX(135)&
              &-JVS(841)*XX(139)-JVS(886)*XX(143)-JVS(997)*XX(151)-JVS(1368)*XX(175)-JVS(1404)*XX(177)-JVS(1531)*XX(184)&
              &-JVS(1598)*XX(189)-JVS(1687)*XX(192)-JVS(1808)*XX(196)-JVS(1893)*XX(197)-JVS(1927)*XX(198)-JVS(1946)*XX(199)&
              &-JVS(1983)*XX(200)-JVS(2020)*XX(201)-JVS(2073)*XX(202)-JVS(2121)*XX(203)-JVS(2224)*XX(204)-JVS(2277)*XX(205)&
              &-JVS(2355)*XX(206)-JVS(2382)*XX(207)-JVS(2445)*XX(208)-JVS(2466)*XX(209)-JVS(2546)*XX(210))/(JVS(2611))
  XX(212) = (X(212)-JVS(35)*XX(6)-JVS(67)*XX(11)-JVS(208)*XX(36)-JVS(274)*XX(37)-JVS(320)*XX(38)-JVS(449)*XX(69)&
              &-JVS(508)*XX(84)-JVS(595)*XX(101)-JVS(629)*XX(107)-JVS(690)*XX(118)-JVS(708)*XX(121)-JVS(755)*XX(129)&
              &-JVS(807)*XX(136)-JVS(833)*XX(138)-JVS(849)*XX(140)-JVS(918)*XX(145)-JVS(967)*XX(148)-JVS(976)*XX(149)&
              &-JVS(988)*XX(150)-JVS(1006)*XX(152)-JVS(1027)*XX(153)-JVS(1035)*XX(154)-JVS(1083)*XX(158)-JVS(1094)*XX(159)&
              &-JVS(1106)*XX(160)-JVS(1125)*XX(162)-JVS(1136)*XX(163)-JVS(1261)*XX(168)-JVS(1286)*XX(170)-JVS(1297)*XX(171)&
              &-JVS(1306)*XX(172)-JVS(1321)*XX(173)-JVS(1330)*XX(174)-JVS(1369)*XX(175)-JVS(1405)*XX(177)-JVS(1413)*XX(178)&
              &-JVS(1423)*XX(179)-JVS(1445)*XX(180)-JVS(1457)*XX(181)-JVS(1468)*XX(182)-JVS(1482)*XX(183)-JVS(1532)*XX(184)&
              &-JVS(1542)*XX(185)-JVS(1556)*XX(186)-JVS(1570)*XX(187)-JVS(1583)*XX(188)-JVS(1599)*XX(189)-JVS(1621)*XX(190)&
              &-JVS(1633)*XX(191)-JVS(1688)*XX(192)-JVS(1712)*XX(193)-JVS(1726)*XX(194)-JVS(1747)*XX(195)-JVS(1809)*XX(196)&
              &-JVS(1894)*XX(197)-JVS(1928)*XX(198)-JVS(1947)*XX(199)-JVS(1984)*XX(200)-JVS(2021)*XX(201)-JVS(2074)*XX(202)&
              &-JVS(2122)*XX(203)-JVS(2225)*XX(204)-JVS(2278)*XX(205)-JVS(2356)*XX(206)-JVS(2383)*XX(207)-JVS(2446)*XX(208)&
              &-JVS(2467)*XX(209)-JVS(2547)*XX(210)-JVS(2612)*XX(211))/(JVS(2677))
  XX(213) = (X(213)-JVS(36)*XX(6)-JVS(77)*XX(14)-JVS(90)*XX(18)-JVS(93)*XX(19)-JVS(106)*XX(23)-JVS(115)*XX(26)-JVS(118)&
              &*XX(27)-JVS(128)*XX(28)-JVS(143)*XX(34)-JVS(209)*XX(36)-JVS(275)*XX(37)-JVS(321)*XX(38)-JVS(332)*XX(39)&
              &-JVS(342)*XX(40)-JVS(346)*XX(42)-JVS(348)*XX(43)-JVS(356)*XX(46)-JVS(362)*XX(48)-JVS(375)*XX(53)-JVS(380)&
              &*XX(55)-JVS(383)*XX(56)-JVS(392)*XX(58)-JVS(399)*XX(60)-JVS(404)*XX(61)-JVS(410)*XX(62)-JVS(415)*XX(63)&
              &-JVS(429)*XX(65)-JVS(433)*XX(66)-JVS(446)*XX(68)-JVS(451)*XX(70)-JVS(454)*XX(71)-JVS(458)*XX(72)-JVS(467)&
              &*XX(74)-JVS(470)*XX(75)-JVS(481)*XX(77)-JVS(485)*XX(78)-JVS(489)*XX(79)-JVS(493)*XX(80)-JVS(496)*XX(81)&
              &-JVS(498)*XX(82)-JVS(503)*XX(83)-JVS(509)*XX(84)-JVS(515)*XX(85)-JVS(520)*XX(86)-JVS(524)*XX(87)-JVS(528)&
              &*XX(88)-JVS(532)*XX(89)-JVS(536)*XX(90)-JVS(541)*XX(91)-JVS(547)*XX(92)-JVS(552)*XX(93)-JVS(568)*XX(95)&
              &-JVS(572)*XX(96)-JVS(583)*XX(99)-JVS(593)*XX(100)-JVS(596)*XX(101)-JVS(602)*XX(102)-JVS(608)*XX(103)-JVS(612)&
              &*XX(104)-JVS(616)*XX(105)-JVS(620)*XX(106)-JVS(630)*XX(107)-JVS(635)*XX(108)-JVS(642)*XX(109)-JVS(648)&
              &*XX(110)-JVS(655)*XX(111)-JVS(658)*XX(112)-JVS(662)*XX(113)-JVS(667)*XX(114)-JVS(684)*XX(117)-JVS(691)&
              &*XX(118)-JVS(698)*XX(119)-JVS(703)*XX(120)-JVS(709)*XX(121)-JVS(714)*XX(122)-JVS(719)*XX(123)-JVS(744)&
              &*XX(127)-JVS(763)*XX(130)-JVS(767)*XX(131)-JVS(791)*XX(134)-JVS(808)*XX(136)-JVS(815)*XX(137)-JVS(834)&
              &*XX(138)-JVS(850)*XX(140)-JVS(856)*XX(141)-JVS(887)*XX(143)-JVS(902)*XX(144)-JVS(919)*XX(145)-JVS(930)&
              &*XX(146)-JVS(944)*XX(147)-JVS(968)*XX(148)-JVS(977)*XX(149)-JVS(989)*XX(150)-JVS(1007)*XX(152)-JVS(1028)&
              &*XX(153)-JVS(1042)*XX(155)-JVS(1069)*XX(156)-JVS(1075)*XX(157)-JVS(1084)*XX(158)-JVS(1095)*XX(159)-JVS(1107)&
              &*XX(160)-JVS(1115)*XX(161)-JVS(1126)*XX(162)-JVS(1137)*XX(163)-JVS(1161)*XX(164)-JVS(1174)*XX(165)-JVS(1186)&
              &*XX(166)-JVS(1202)*XX(167)-JVS(1262)*XX(168)-JVS(1276)*XX(169)-JVS(1287)*XX(170)-JVS(1298)*XX(171)-JVS(1307)&
              &*XX(172)-JVS(1322)*XX(173)-JVS(1331)*XX(174)-JVS(1370)*XX(175)-JVS(1381)*XX(176)-JVS(1406)*XX(177)-JVS(1414)&
              &*XX(178)-JVS(1424)*XX(179)-JVS(1446)*XX(180)-JVS(1458)*XX(181)-JVS(1469)*XX(182)-JVS(1483)*XX(183)-JVS(1533)&
              &*XX(184)-JVS(1543)*XX(185)-JVS(1557)*XX(186)-JVS(1571)*XX(187)-JVS(1584)*XX(188)-JVS(1600)*XX(189)-JVS(1622)&
              &*XX(190)-JVS(1634)*XX(191)-JVS(1689)*XX(192)-JVS(1713)*XX(193)-JVS(1727)*XX(194)-JVS(1748)*XX(195)-JVS(1810)&
              &*XX(196)-JVS(1895)*XX(197)-JVS(1929)*XX(198)-JVS(1948)*XX(199)-JVS(1985)*XX(200)-JVS(2022)*XX(201)-JVS(2075)&
              &*XX(202)-JVS(2123)*XX(203)-JVS(2226)*XX(204)-JVS(2279)*XX(205)-JVS(2357)*XX(206)-JVS(2384)*XX(207)-JVS(2447)&
              &*XX(208)-JVS(2468)*XX(209)-JVS(2548)*XX(210)-JVS(2613)*XX(211)-JVS(2678)*XX(212))/(JVS(2819))
  XX(214) = (X(214)-JVS(37)*XX(6)-JVS(68)*XX(11)-JVS(71)*XX(12)-JVS(83)*XX(16)-JVS(91)*XX(18)-JVS(96)*XX(20)-JVS(109)&
              &*XX(24)-JVS(210)*XX(36)-JVS(276)*XX(37)-JVS(322)*XX(38)-JVS(384)*XX(56)-JVS(400)*XX(60)-JVS(405)*XX(61)&
              &-JVS(430)*XX(65)-JVS(434)*XX(66)-JVS(471)*XX(75)-JVS(482)*XX(77)-JVS(486)*XX(78)-JVS(490)*XX(79)-JVS(525)&
              &*XX(87)-JVS(529)*XX(88)-JVS(533)*XX(89)-JVS(542)*XX(91)-JVS(548)*XX(92)-JVS(553)*XX(93)-JVS(569)*XX(95)&
              &-JVS(576)*XX(97)-JVS(597)*XX(101)-JVS(603)*XX(102)-JVS(609)*XX(103)-JVS(613)*XX(104)-JVS(617)*XX(105)&
              &-JVS(621)*XX(106)-JVS(636)*XX(108)-JVS(649)*XX(110)-JVS(659)*XX(112)-JVS(663)*XX(113)-JVS(668)*XX(114)&
              &-JVS(685)*XX(117)-JVS(699)*XX(119)-JVS(710)*XX(121)-JVS(745)*XX(127)-JVS(750)*XX(128)-JVS(756)*XX(129)&
              &-JVS(809)*XX(136)-JVS(816)*XX(137)-JVS(851)*XX(140)-JVS(888)*XX(143)-JVS(903)*XX(144)-JVS(920)*XX(145)&
              &-JVS(931)*XX(146)-JVS(945)*XX(147)-JVS(969)*XX(148)-JVS(978)*XX(149)-JVS(990)*XX(150)-JVS(1008)*XX(152)&
              &-JVS(1029)*XX(153)-JVS(1036)*XX(154)-JVS(1043)*XX(155)-JVS(1070)*XX(156)-JVS(1085)*XX(158)-JVS(1096)*XX(159)&
              &-JVS(1108)*XX(160)-JVS(1116)*XX(161)-JVS(1127)*XX(162)-JVS(1138)*XX(163)-JVS(1162)*XX(164)-JVS(1175)*XX(165)&
              &-JVS(1187)*XX(166)-JVS(1203)*XX(167)-JVS(1263)*XX(168)-JVS(1277)*XX(169)-JVS(1288)*XX(170)-JVS(1299)*XX(171)&
              &-JVS(1308)*XX(172)-JVS(1323)*XX(173)-JVS(1332)*XX(174)-JVS(1371)*XX(175)-JVS(1382)*XX(176)-JVS(1407)*XX(177)&
              &-JVS(1425)*XX(179)-JVS(1447)*XX(180)-JVS(1459)*XX(181)-JVS(1470)*XX(182)-JVS(1484)*XX(183)-JVS(1534)*XX(184)&
              &-JVS(1558)*XX(186)-JVS(1572)*XX(187)-JVS(1585)*XX(188)-JVS(1601)*XX(189)-JVS(1623)*XX(190)-JVS(1635)*XX(191)&
              &-JVS(1690)*XX(192)-JVS(1714)*XX(193)-JVS(1728)*XX(194)-JVS(1749)*XX(195)-JVS(1811)*XX(196)-JVS(1896)*XX(197)&
              &-JVS(1930)*XX(198)-JVS(1949)*XX(199)-JVS(1986)*XX(200)-JVS(2023)*XX(201)-JVS(2076)*XX(202)-JVS(2124)*XX(203)&
              &-JVS(2227)*XX(204)-JVS(2280)*XX(205)-JVS(2358)*XX(206)-JVS(2385)*XX(207)-JVS(2448)*XX(208)-JVS(2469)*XX(209)&
              &-JVS(2549)*XX(210)-JVS(2614)*XX(211)-JVS(2679)*XX(212)-JVS(2820)*XX(213))/(JVS(2929))
  XX(215) = (X(215)-JVS(38)*XX(6)-JVS(211)*XX(36)-JVS(323)*XX(38)-JVS(452)*XX(70)-JVS(455)*XX(71)-JVS(499)*XX(82)&
              &-JVS(510)*XX(84)-JVS(537)*XX(90)-JVS(584)*XX(99)-JVS(598)*XX(101)-JVS(631)*XX(107)-JVS(692)*XX(118)-JVS(704)&
              &*XX(120)-JVS(889)*XX(143)-JVS(921)*XX(145)-JVS(1009)*XX(152)-JVS(1071)*XX(156)-JVS(1076)*XX(157)-JVS(1086)&
              &*XX(158)-JVS(1097)*XX(159)-JVS(1109)*XX(160)-JVS(1176)*XX(165)-JVS(1264)*XX(168)-JVS(1372)*XX(175)-JVS(1448)&
              &*XX(180)-JVS(1471)*XX(182)-JVS(1535)*XX(184)-JVS(1573)*XX(187)-JVS(1586)*XX(188)-JVS(1602)*XX(189)-JVS(1624)&
              &*XX(190)-JVS(1636)*XX(191)-JVS(1691)*XX(192)-JVS(1715)*XX(193)-JVS(1729)*XX(194)-JVS(1750)*XX(195)-JVS(1812)&
              &*XX(196)-JVS(1897)*XX(197)-JVS(1931)*XX(198)-JVS(1950)*XX(199)-JVS(1987)*XX(200)-JVS(2024)*XX(201)-JVS(2077)&
              &*XX(202)-JVS(2125)*XX(203)-JVS(2228)*XX(204)-JVS(2281)*XX(205)-JVS(2359)*XX(206)-JVS(2386)*XX(207)-JVS(2449)&
              &*XX(208)-JVS(2470)*XX(209)-JVS(2550)*XX(210)-JVS(2615)*XX(211)-JVS(2680)*XX(212)-JVS(2821)*XX(213)-JVS(2930)&
              &*XX(214))/(JVS(3006))
  XX(215) = XX(215)
  XX(214) = XX(214)-JVS(3005)*XX(215)
  XX(213) = XX(213)-JVS(2928)*XX(214)-JVS(3004)*XX(215)
  XX(212) = XX(212)-JVS(2818)*XX(213)-JVS(2927)*XX(214)-JVS(3003)*XX(215)
  XX(211) = XX(211)-JVS(2676)*XX(212)-JVS(2817)*XX(213)-JVS(2926)*XX(214)-JVS(3002)*XX(215)
  XX(210) = XX(210)-JVS(2610)*XX(211)-JVS(2675)*XX(212)-JVS(2816)*XX(213)-JVS(2925)*XX(214)-JVS(3001)*XX(215)
  XX(209) = XX(209)-JVS(2544)*XX(210)-JVS(2609)*XX(211)-JVS(2674)*XX(212)-JVS(2815)*XX(213)-JVS(2924)*XX(214)-JVS(3000)&
              &*XX(215)
  XX(208) = XX(208)-JVS(2463)*XX(209)-JVS(2543)*XX(210)-JVS(2608)*XX(211)-JVS(2673)*XX(212)-JVS(2814)*XX(213)-JVS(2923)&
              &*XX(214)-JVS(2999)*XX(215)
  XX(207) = XX(207)-JVS(2441)*XX(208)-JVS(2462)*XX(209)-JVS(2542)*XX(210)-JVS(2607)*XX(211)-JVS(2672)*XX(212)-JVS(2813)&
              &*XX(213)-JVS(2922)*XX(214)-JVS(2998)*XX(215)
  XX(206) = XX(206)-JVS(2377)*XX(207)-JVS(2440)*XX(208)-JVS(2461)*XX(209)-JVS(2541)*XX(210)-JVS(2606)*XX(211)-JVS(2671)&
              &*XX(212)-JVS(2812)*XX(213)-JVS(2921)*XX(214)-JVS(2997)*XX(215)
  XX(205) = XX(205)-JVS(2349)*XX(206)-JVS(2376)*XX(207)-JVS(2439)*XX(208)-JVS(2460)*XX(209)-JVS(2540)*XX(210)-JVS(2605)&
              &*XX(211)-JVS(2670)*XX(212)-JVS(2811)*XX(213)-JVS(2920)*XX(214)-JVS(2996)*XX(215)
  XX(204) = XX(204)-JVS(2270)*XX(205)-JVS(2348)*XX(206)-JVS(2375)*XX(207)-JVS(2438)*XX(208)-JVS(2459)*XX(209)-JVS(2539)&
              &*XX(210)-JVS(2604)*XX(211)-JVS(2669)*XX(212)-JVS(2810)*XX(213)-JVS(2919)*XX(214)-JVS(2995)*XX(215)
  XX(203) = XX(203)-JVS(2216)*XX(204)-JVS(2269)*XX(205)-JVS(2347)*XX(206)-JVS(2374)*XX(207)-JVS(2437)*XX(208)-JVS(2538)&
              &*XX(210)-JVS(2603)*XX(211)-JVS(2668)*XX(212)-JVS(2809)*XX(213)-JVS(2918)*XX(214)-JVS(2994)*XX(215)
  XX(202) = XX(202)-JVS(2112)*XX(203)-JVS(2215)*XX(204)-JVS(2268)*XX(205)-JVS(2346)*XX(206)-JVS(2436)*XX(208)-JVS(2537)&
              &*XX(210)-JVS(2602)*XX(211)-JVS(2667)*XX(212)-JVS(2808)*XX(213)-JVS(2917)*XX(214)-JVS(2993)*XX(215)
  XX(201) = XX(201)-JVS(2111)*XX(203)-JVS(2214)*XX(204)-JVS(2267)*XX(205)-JVS(2345)*XX(206)-JVS(2435)*XX(208)-JVS(2536)&
              &*XX(210)-JVS(2601)*XX(211)-JVS(2666)*XX(212)-JVS(2807)*XX(213)-JVS(2916)*XX(214)-JVS(2992)*XX(215)
  XX(200) = XX(200)-JVS(2009)*XX(201)-JVS(2063)*XX(202)-JVS(2110)*XX(203)-JVS(2213)*XX(204)-JVS(2266)*XX(205)-JVS(2344)&
              &*XX(206)-JVS(2434)*XX(208)-JVS(2535)*XX(210)-JVS(2600)*XX(211)-JVS(2665)*XX(212)-JVS(2806)*XX(213)-JVS(2915)&
              &*XX(214)-JVS(2991)*XX(215)
  XX(199) = XX(199)-JVS(1974)*XX(200)-JVS(2008)*XX(201)-JVS(2062)*XX(202)-JVS(2109)*XX(203)-JVS(2212)*XX(204)-JVS(2265)&
              &*XX(205)-JVS(2343)*XX(206)-JVS(2373)*XX(207)-JVS(2433)*XX(208)-JVS(2534)*XX(210)-JVS(2599)*XX(211)-JVS(2664)&
              &*XX(212)-JVS(2805)*XX(213)-JVS(2914)*XX(214)-JVS(2990)*XX(215)
  XX(198) = XX(198)-JVS(2108)*XX(203)-JVS(2211)*XX(204)-JVS(2264)*XX(205)-JVS(2342)*XX(206)-JVS(2533)*XX(210)-JVS(2598)&
              &*XX(211)-JVS(2663)*XX(212)-JVS(2804)*XX(213)-JVS(2913)*XX(214)-JVS(2989)*XX(215)
  XX(197) = XX(197)-JVS(1913)*XX(198)-JVS(2107)*XX(203)-JVS(2210)*XX(204)-JVS(2263)*XX(205)-JVS(2341)*XX(206)-JVS(2532)&
              &*XX(210)-JVS(2597)*XX(211)-JVS(2803)*XX(213)-JVS(2912)*XX(214)-JVS(2988)*XX(215)
  XX(196) = XX(196)-JVS(1912)*XX(198)-JVS(2106)*XX(203)-JVS(2209)*XX(204)-JVS(2262)*XX(205)-JVS(2340)*XX(206)-JVS(2531)&
              &*XX(210)-JVS(2802)*XX(213)-JVS(2911)*XX(214)-JVS(2987)*XX(215)
  XX(195) = XX(195)-JVS(1792)*XX(196)-JVS(1878)*XX(197)-JVS(1911)*XX(198)-JVS(1973)*XX(200)-JVS(2007)*XX(201)-JVS(2061)&
              &*XX(202)-JVS(2105)*XX(203)-JVS(2208)*XX(204)-JVS(2261)*XX(205)-JVS(2339)*XX(206)-JVS(2432)*XX(208)-JVS(2530)&
              &*XX(210)-JVS(2596)*XX(211)-JVS(2662)*XX(212)-JVS(2801)*XX(213)-JVS(2910)*XX(214)-JVS(2986)*XX(215)
  XX(194) = XX(194)-JVS(1791)*XX(196)-JVS(1877)*XX(197)-JVS(1910)*XX(198)-JVS(2006)*XX(201)-JVS(2060)*XX(202)-JVS(2104)&
              &*XX(203)-JVS(2207)*XX(204)-JVS(2260)*XX(205)-JVS(2338)*XX(206)-JVS(2372)*XX(207)-JVS(2431)*XX(208)-JVS(2529)&
              &*XX(210)-JVS(2595)*XX(211)-JVS(2661)*XX(212)-JVS(2800)*XX(213)-JVS(2909)*XX(214)-JVS(2985)*XX(215)
  XX(193) = XX(193)-JVS(1739)*XX(195)-JVS(1790)*XX(196)-JVS(1876)*XX(197)-JVS(1909)*XX(198)-JVS(1972)*XX(200)-JVS(2005)&
              &*XX(201)-JVS(2059)*XX(202)-JVS(2103)*XX(203)-JVS(2206)*XX(204)-JVS(2259)*XX(205)-JVS(2337)*XX(206)-JVS(2430)&
              &*XX(208)-JVS(2528)*XX(210)-JVS(2594)*XX(211)-JVS(2660)*XX(212)-JVS(2799)*XX(213)-JVS(2908)*XX(214)-JVS(2984)&
              &*XX(215)
  XX(192) = XX(192)-JVS(1789)*XX(196)-JVS(1875)*XX(197)-JVS(2205)*XX(204)-JVS(2429)*XX(208)-JVS(2527)*XX(210)-JVS(2593)&
              &*XX(211)-JVS(2659)*XX(212)-JVS(2798)*XX(213)-JVS(2907)*XX(214)-JVS(2983)*XX(215)
  XX(191) = XX(191)-JVS(1673)*XX(192)-JVS(1705)*XX(193)-JVS(1738)*XX(195)-JVS(1788)*XX(196)-JVS(1874)*XX(197)-JVS(1908)&
              &*XX(198)-JVS(1938)*XX(199)-JVS(1971)*XX(200)-JVS(2004)*XX(201)-JVS(2058)*XX(202)-JVS(2204)*XX(204)-JVS(2258)&
              &*XX(205)-JVS(2336)*XX(206)-JVS(2371)*XX(207)-JVS(2428)*XX(208)-JVS(2458)*XX(209)-JVS(2526)*XX(210)-JVS(2592)&
              &*XX(211)-JVS(2658)*XX(212)-JVS(2797)*XX(213)-JVS(2906)*XX(214)-JVS(2982)*XX(215)
  XX(190) = XX(190)-JVS(1787)*XX(196)-JVS(1873)*XX(197)-JVS(1907)*XX(198)-JVS(2003)*XX(201)-JVS(2203)*XX(204)-JVS(2335)&
              &*XX(206)-JVS(2427)*XX(208)-JVS(2657)*XX(212)-JVS(2796)*XX(213)-JVS(2905)*XX(214)-JVS(2981)*XX(215)
  XX(189) = XX(189)-JVS(1672)*XX(192)-JVS(1786)*XX(196)-JVS(1872)*XX(197)-JVS(1970)*XX(200)-JVS(2057)*XX(202)-JVS(2202)&
              &*XX(204)-JVS(2334)*XX(206)-JVS(2426)*XX(208)-JVS(2525)*XX(210)-JVS(2591)*XX(211)-JVS(2656)*XX(212)-JVS(2795)&
              &*XX(213)-JVS(2904)*XX(214)-JVS(2980)*XX(215)
  XX(188) = XX(188)-JVS(1671)*XX(192)-JVS(1704)*XX(193)-JVS(1737)*XX(195)-JVS(1785)*XX(196)-JVS(1871)*XX(197)-JVS(1937)&
              &*XX(199)-JVS(1969)*XX(200)-JVS(2002)*XX(201)-JVS(2056)*XX(202)-JVS(2201)*XX(204)-JVS(2257)*XX(205)-JVS(2333)&
              &*XX(206)-JVS(2370)*XX(207)-JVS(2425)*XX(208)-JVS(2457)*XX(209)-JVS(2524)*XX(210)-JVS(2590)*XX(211)-JVS(2655)&
              &*XX(212)-JVS(2794)*XX(213)-JVS(2903)*XX(214)-JVS(2979)*XX(215)
  XX(187) = XX(187)-JVS(1670)*XX(192)-JVS(1784)*XX(196)-JVS(1870)*XX(197)-JVS(1906)*XX(198)-JVS(2102)*XX(203)-JVS(2200)&
              &*XX(204)-JVS(2256)*XX(205)-JVS(2332)*XX(206)-JVS(2424)*XX(208)-JVS(2523)*XX(210)-JVS(2589)*XX(211)-JVS(2654)&
              &*XX(212)-JVS(2793)*XX(213)-JVS(2902)*XX(214)-JVS(2978)*XX(215)
  XX(186) = XX(186)-JVS(1669)*XX(192)-JVS(1703)*XX(193)-JVS(1783)*XX(196)-JVS(1869)*XX(197)-JVS(1968)*XX(200)-JVS(2055)&
              &*XX(202)-JVS(2199)*XX(204)-JVS(2255)*XX(205)-JVS(2331)*XX(206)-JVS(2369)*XX(207)-JVS(2423)*XX(208)-JVS(2522)&
              &*XX(210)-JVS(2588)*XX(211)-JVS(2653)*XX(212)-JVS(2792)*XX(213)-JVS(2901)*XX(214)-JVS(2977)*XX(215)
  XX(185) = XX(185)-JVS(1607)*XX(190)-JVS(1627)*XX(191)-JVS(1668)*XX(192)-JVS(1736)*XX(195)-JVS(1782)*XX(196)-JVS(1868)&
              &*XX(197)-JVS(1967)*XX(200)-JVS(2001)*XX(201)-JVS(2054)*XX(202)-JVS(2198)*XX(204)-JVS(2254)*XX(205)-JVS(2330)&
              &*XX(206)-JVS(2422)*XX(208)-JVS(2521)*XX(210)-JVS(2587)*XX(211)-JVS(2652)*XX(212)-JVS(2791)*XX(213)-JVS(2900)&
              &*XX(214)-JVS(2976)*XX(215)
  XX(184) = XX(184)-JVS(2197)*XX(204)-JVS(2421)*XX(208)-JVS(2520)*XX(210)-JVS(2586)*XX(211)-JVS(2790)*XX(213)-JVS(2899)&
              &*XX(214)
  XX(183) = XX(183)-JVS(1667)*XX(192)-JVS(1781)*XX(196)-JVS(1867)*XX(197)-JVS(1966)*XX(200)-JVS(2053)*XX(202)-JVS(2196)&
              &*XX(204)-JVS(2253)*XX(205)-JVS(2329)*XX(206)-JVS(2420)*XX(208)-JVS(2519)*XX(210)-JVS(2585)*XX(211)-JVS(2651)&
              &*XX(212)-JVS(2789)*XX(213)-JVS(2898)*XX(214)-JVS(2975)*XX(215)
  XX(182) = XX(182)-JVS(1511)*XX(184)-JVS(1780)*XX(196)-JVS(1866)*XX(197)-JVS(1965)*XX(200)-JVS(2052)*XX(202)-JVS(2195)&
              &*XX(204)-JVS(2328)*XX(206)-JVS(2419)*XX(208)-JVS(2518)*XX(210)-JVS(2584)*XX(211)-JVS(2650)*XX(212)-JVS(2788)&
              &*XX(213)-JVS(2897)*XX(214)-JVS(2974)*XX(215)
  XX(181) = XX(181)-JVS(1510)*XX(184)-JVS(1666)*XX(192)-JVS(1735)*XX(195)-JVS(1779)*XX(196)-JVS(1865)*XX(197)-JVS(1964)&
              &*XX(200)-JVS(2000)*XX(201)-JVS(2051)*XX(202)-JVS(2194)*XX(204)-JVS(2327)*XX(206)-JVS(2418)*XX(208)-JVS(2649)&
              &*XX(212)-JVS(2787)*XX(213)-JVS(2896)*XX(214)-JVS(2973)*XX(215)
  XX(180) = XX(180)-JVS(1778)*XX(196)-JVS(1905)*XX(198)-JVS(2101)*XX(203)-JVS(2193)*XX(204)-JVS(2252)*XX(205)-JVS(2517)&
              &*XX(210)-JVS(2786)*XX(213)-JVS(2972)*XX(215)
  XX(179) = XX(179)-JVS(1509)*XX(184)-JVS(1665)*XX(192)-JVS(1702)*XX(193)-JVS(1777)*XX(196)-JVS(1864)*XX(197)-JVS(1963)&
              &*XX(200)-JVS(2050)*XX(202)-JVS(2192)*XX(204)-JVS(2251)*XX(205)-JVS(2326)*XX(206)-JVS(2417)*XX(208)-JVS(2516)&
              &*XX(210)-JVS(2583)*XX(211)-JVS(2648)*XX(212)-JVS(2785)*XX(213)-JVS(2895)*XX(214)-JVS(2971)*XX(215)
  XX(178) = XX(178)-JVS(1508)*XX(184)-JVS(1548)*XX(186)-JVS(1664)*XX(192)-JVS(1701)*XX(193)-JVS(1734)*XX(195)-JVS(1776)&
              &*XX(196)-JVS(1863)*XX(197)-JVS(1999)*XX(201)-JVS(2049)*XX(202)-JVS(2191)*XX(204)-JVS(2250)*XX(205)-JVS(2325)&
              &*XX(206)-JVS(2416)*XX(208)-JVS(2515)*XX(210)-JVS(2582)*XX(211)-JVS(2647)*XX(212)-JVS(2784)*XX(213)-JVS(2894)&
              &*XX(214)-JVS(2970)*XX(215)
  XX(177) = XX(177)-JVS(1775)*XX(196)-JVS(1862)*XX(197)-JVS(2190)*XX(204)-JVS(2514)*XX(210)-JVS(2581)*XX(211)-JVS(2783)&
              &*XX(213)-JVS(2893)*XX(214)-JVS(2969)*XX(215)
  XX(176) = XX(176)-JVS(1391)*XX(177)-JVS(1507)*XX(184)-JVS(1663)*XX(192)-JVS(1700)*XX(193)-JVS(1733)*XX(195)-JVS(1774)&
              &*XX(196)-JVS(1861)*XX(197)-JVS(1998)*XX(201)-JVS(2048)*XX(202)-JVS(2189)*XX(204)-JVS(2324)*XX(206)-JVS(2415)&
              &*XX(208)-JVS(2513)*XX(210)-JVS(2580)*XX(211)-JVS(2646)*XX(212)-JVS(2782)*XX(213)-JVS(2892)*XX(214)-JVS(2968)&
              &*XX(215)
  XX(175) = XX(175)-JVS(1773)*XX(196)-JVS(2645)*XX(212)-JVS(2781)*XX(213)-JVS(2967)*XX(215)
  XX(174) = XX(174)-JVS(1561)*XX(187)-JVS(1662)*XX(192)-JVS(1699)*XX(193)-JVS(1772)*XX(196)-JVS(1860)*XX(197)-JVS(1962)&
              &*XX(200)-JVS(2047)*XX(202)-JVS(2188)*XX(204)-JVS(2249)*XX(205)-JVS(2323)*XX(206)-JVS(2414)*XX(208)-JVS(2512)&
              &*XX(210)-JVS(2644)*XX(212)-JVS(2780)*XX(213)-JVS(2891)*XX(214)-JVS(2966)*XX(215)
  XX(173) = XX(173)-JVS(1606)*XX(190)-JVS(1859)*XX(197)-JVS(1997)*XX(201)-JVS(2187)*XX(204)-JVS(2248)*XX(205)-JVS(2322)&
              &*XX(206)-JVS(2413)*XX(208)-JVS(2643)*XX(212)-JVS(2779)*XX(213)-JVS(2890)*XX(214)
  XX(172) = XX(172)-JVS(1661)*XX(192)-JVS(1698)*XX(193)-JVS(1718)*XX(194)-JVS(1858)*XX(197)-JVS(1961)*XX(200)-JVS(2046)&
              &*XX(202)-JVS(2186)*XX(204)-JVS(2247)*XX(205)-JVS(2321)*XX(206)-JVS(2412)*XX(208)-JVS(2456)*XX(209)-JVS(2511)&
              &*XX(210)-JVS(2642)*XX(212)-JVS(2778)*XX(213)-JVS(2889)*XX(214)
  XX(171) = XX(171)-JVS(1660)*XX(192)-JVS(1857)*XX(197)-JVS(1960)*XX(200)-JVS(2045)*XX(202)-JVS(2185)*XX(204)-JVS(2246)&
              &*XX(205)-JVS(2320)*XX(206)-JVS(2411)*XX(208)-JVS(2510)*XX(210)-JVS(2641)*XX(212)-JVS(2777)*XX(213)-JVS(2888)&
              &*XX(214)
  XX(170) = XX(170)-JVS(1291)*XX(171)-JVS(1659)*XX(192)-JVS(1856)*XX(197)-JVS(1959)*XX(200)-JVS(2044)*XX(202)-JVS(2184)&
              &*XX(204)-JVS(2245)*XX(205)-JVS(2319)*XX(206)-JVS(2410)*XX(208)-JVS(2509)*XX(210)-JVS(2640)*XX(212)-JVS(2776)&
              &*XX(213)-JVS(2887)*XX(214)
  XX(169) = XX(169)-JVS(1432)*XX(180)-JVS(1771)*XX(196)-JVS(1904)*XX(198)-JVS(2100)*XX(203)-JVS(2183)*XX(204)-JVS(2244)&
              &*XX(205)-JVS(2318)*XX(206)-JVS(2508)*XX(210)-JVS(2775)*XX(213)-JVS(2886)*XX(214)-JVS(2965)*XX(215)
  XX(168) = XX(168)-JVS(2182)*XX(204)-JVS(2507)*XX(210)-JVS(2774)*XX(213)
  XX(167) = XX(167)-JVS(1229)*XX(168)-JVS(1267)*XX(169)-JVS(1431)*XX(180)-JVS(1770)*XX(196)-JVS(1903)*XX(198)-JVS(2099)&
              &*XX(203)-JVS(2181)*XX(204)-JVS(2243)*XX(205)-JVS(2317)*XX(206)-JVS(2506)*XX(210)-JVS(2773)*XX(213)-JVS(2885)&
              &*XX(214)-JVS(2964)*XX(215)
  XX(166) = XX(166)-JVS(1228)*XX(168)-JVS(1343)*XX(175)-JVS(1506)*XX(184)-JVS(1658)*XX(192)-JVS(1769)*XX(196)-JVS(1855)&
              &*XX(197)-JVS(2180)*XX(204)-JVS(2316)*XX(206)-JVS(2505)*XX(210)-JVS(2579)*XX(211)-JVS(2772)*XX(213)-JVS(2884)&
              &*XX(214)-JVS(2963)*XX(215)
  XX(165) = XX(165)-JVS(1227)*XX(168)-JVS(1430)*XX(180)-JVS(1768)*XX(196)-JVS(1902)*XX(198)-JVS(2098)*XX(203)-JVS(2179)&
              &*XX(204)-JVS(2242)*XX(205)-JVS(2504)*XX(210)-JVS(2771)*XX(213)-JVS(2962)*XX(215)
  XX(164) = XX(164)-JVS(1194)*XX(167)-JVS(1226)*XX(168)-JVS(1266)*XX(169)-JVS(2097)*XX(203)-JVS(2178)*XX(204)-JVS(2241)&
              &*XX(205)-JVS(2315)*XX(206)-JVS(2503)*XX(210)-JVS(2770)*XX(213)-JVS(2883)*XX(214)-JVS(2961)*XX(215)
  XX(163) = XX(163)-JVS(1225)*XX(168)-JVS(1342)*XX(175)-JVS(1657)*XX(192)-JVS(1854)*XX(197)-JVS(1958)*XX(200)-JVS(2043)&
              &*XX(202)-JVS(2177)*XX(204)-JVS(2314)*XX(206)-JVS(2409)*XX(208)-JVS(2639)*XX(212)-JVS(2769)*XX(213)-JVS(2882)&
              &*XX(214)
  XX(162) = XX(162)-JVS(1341)*XX(175)-JVS(1697)*XX(193)-JVS(1732)*XX(195)-JVS(1853)*XX(197)-JVS(1996)*XX(201)-JVS(2042)&
              &*XX(202)-JVS(2176)*XX(204)-JVS(2313)*XX(206)-JVS(2408)*XX(208)-JVS(2638)*XX(212)-JVS(2768)*XX(213)-JVS(2881)&
              &*XX(214)
  XX(161) = XX(161)-JVS(1118)*XX(162)-JVS(1178)*XX(166)-JVS(1224)*XX(168)-JVS(1375)*XX(176)-JVS(1390)*XX(177)-JVS(1505)&
              &*XX(184)-JVS(1656)*XX(192)-JVS(1767)*XX(196)-JVS(1852)*XX(197)-JVS(2041)*XX(202)-JVS(2175)*XX(204)-JVS(2312)&
              &*XX(206)-JVS(2407)*XX(208)-JVS(2502)*XX(210)-JVS(2578)*XX(211)-JVS(2637)*XX(212)-JVS(2767)*XX(213)-JVS(2880)&
              &*XX(214)-JVS(2960)*XX(215)
  XX(160) = XX(160)-JVS(1340)*XX(175)-JVS(1560)*XX(187)-JVS(1851)*XX(197)-JVS(2040)*XX(202)-JVS(2174)*XX(204)-JVS(2311)&
              &*XX(206)-JVS(2406)*XX(208)-JVS(2636)*XX(212)-JVS(2766)*XX(213)-JVS(2879)*XX(214)
  XX(159) = XX(159)-JVS(1339)*XX(175)-JVS(1504)*XX(184)-JVS(1655)*XX(192)-JVS(1850)*XX(197)-JVS(2173)*XX(204)-JVS(2310)&
              &*XX(206)-JVS(2405)*XX(208)-JVS(2635)*XX(212)-JVS(2765)*XX(213)-JVS(2878)*XX(214)
  XX(158) = XX(158)-JVS(1338)*XX(175)-JVS(1654)*XX(192)-JVS(1849)*XX(197)-JVS(1995)*XX(201)-JVS(2039)*XX(202)-JVS(2172)&
              &*XX(204)-JVS(2309)*XX(206)-JVS(2404)*XX(208)-JVS(2634)*XX(212)-JVS(2764)*XX(213)-JVS(2877)*XX(214)
  XX(157) = XX(157)-JVS(1461)*XX(182)-JVS(1577)*XX(188)-JVS(1589)*XX(189)-JVS(1626)*XX(191)-JVS(1653)*XX(192)-JVS(1717)&
              &*XX(194)-JVS(1766)*XX(196)-JVS(1848)*XX(197)-JVS(1936)*XX(199)-JVS(2171)*XX(204)-JVS(2240)*XX(205)-JVS(2308)&
              &*XX(206)-JVS(2368)*XX(207)-JVS(2403)*XX(208)-JVS(2455)*XX(209)-JVS(2501)*XX(210)-JVS(2577)*XX(211)-JVS(2633)&
              &*XX(212)-JVS(2763)*XX(213)-JVS(2876)*XX(214)-JVS(2959)*XX(215)
  XX(156) = XX(156)-JVS(1765)*XX(196)-JVS(2762)*XX(213)-JVS(2875)*XX(214)-JVS(2958)*XX(215)
  XX(155) = XX(155)-JVS(1311)*XX(173)-JVS(1503)*XX(184)-JVS(1652)*XX(192)-JVS(1847)*XX(197)-JVS(1994)*XX(201)-JVS(2170)&
              &*XX(204)-JVS(2239)*XX(205)-JVS(2307)*XX(206)-JVS(2402)*XX(208)-JVS(2500)*XX(210)-JVS(2576)*XX(211)-JVS(2632)&
              &*XX(212)-JVS(2761)*XX(213)-JVS(2874)*XX(214)
  XX(154) = XX(154)-JVS(1129)*XX(163)-JVS(1337)*XX(175)-JVS(1474)*XX(183)-JVS(1502)*XX(184)-JVS(1731)*XX(195)-JVS(1846)&
              &*XX(197)-JVS(2038)*XX(202)-JVS(2169)*XX(204)-JVS(2306)*XX(206)-JVS(2401)*XX(208)-JVS(2575)*XX(211)-JVS(2631)&
              &*XX(212)-JVS(2760)*XX(213)-JVS(2873)*XX(214)
  XX(153) = XX(153)-JVS(1501)*XX(184)-JVS(1845)*XX(197)-JVS(2168)*XX(204)-JVS(2574)*XX(211)-JVS(2630)*XX(212)-JVS(2759)&
              &*XX(213)
  XX(152) = XX(152)-JVS(1336)*XX(175)-JVS(1844)*XX(197)-JVS(2037)*XX(202)-JVS(2167)*XX(204)-JVS(2305)*XX(206)-JVS(2400)&
              &*XX(208)-JVS(2629)*XX(212)-JVS(2758)*XX(213)-JVS(2872)*XX(214)
  XX(151) = XX(151)-JVS(1588)*XX(189)-JVS(1651)*XX(192)-JVS(1764)*XX(196)-JVS(1843)*XX(197)-JVS(2166)*XX(204)-JVS(2304)&
              &*XX(206)-JVS(2367)*XX(207)-JVS(2454)*XX(209)-JVS(2499)*XX(210)-JVS(2573)*XX(211)-JVS(2757)*XX(213)-JVS(2871)&
              &*XX(214)-JVS(2957)*XX(215)
  XX(150) = XX(150)-JVS(1223)*XX(168)-JVS(1650)*XX(192)-JVS(2036)*XX(202)-JVS(2165)*XX(204)-JVS(2238)*XX(205)-JVS(2498)&
              &*XX(210)-JVS(2756)*XX(213)
  XX(149) = XX(149)-JVS(1014)*XX(153)-JVS(1335)*XX(175)-JVS(1842)*XX(197)-JVS(1993)*XX(201)-JVS(2035)*XX(202)-JVS(2164)&
              &*XX(204)-JVS(2303)*XX(206)-JVS(2399)*XX(208)-JVS(2628)*XX(212)-JVS(2755)*XX(213)-JVS(2870)*XX(214)
  XX(148) = XX(148)-JVS(1222)*XX(168)-JVS(1841)*XX(197)-JVS(2497)*XX(210)-JVS(2572)*XX(211)-JVS(2754)*XX(213)-JVS(2869)&
              &*XX(214)
  XX(147) = XX(147)-JVS(1165)*XX(165)-JVS(1221)*XX(168)-JVS(1429)*XX(180)-JVS(1763)*XX(196)-JVS(2096)*XX(203)-JVS(2237)&
              &*XX(205)-JVS(2753)*XX(213)-JVS(2956)*XX(215)
  XX(146) = XX(146)-JVS(1049)*XX(156)-JVS(1220)*XX(168)-JVS(1389)*XX(177)-JVS(1500)*XX(184)-JVS(1840)*XX(197)-JVS(2163)&
              &*XX(204)-JVS(2398)*XX(208)-JVS(2496)*XX(210)-JVS(2752)*XX(213)
  XX(145) = XX(145)-JVS(1428)*XX(180)-JVS(1762)*XX(196)-JVS(1901)*XX(198)-JVS(2095)*XX(203)-JVS(2751)*XX(213)-JVS(2955)&
              &*XX(215)
  XX(144) = XX(144)-JVS(956)*XX(148)-JVS(1048)*XX(156)-JVS(1388)*XX(177)-JVS(1499)*XX(184)-JVS(1649)*XX(192)-JVS(1839)&
              &*XX(197)-JVS(2162)*XX(204)-JVS(2302)*XX(206)-JVS(2397)*XX(208)-JVS(2571)*XX(211)-JVS(2750)*XX(213)-JVS(2868)&
              &*XX(214)
  XX(143) = XX(143)-JVS(1761)*XX(196)-JVS(2749)*XX(213)-JVS(2867)*XX(214)-JVS(2954)*XX(215)
  XX(142) = XX(142)-JVS(873)*XX(143)-JVS(1047)*XX(156)-JVS(1838)*XX(197)-JVS(2161)*XX(204)-JVS(2301)*XX(206)-JVS(2366)&
              &*XX(207)-JVS(2495)*XX(210)
  XX(141) = XX(141)-JVS(896)*XX(144)-JVS(922)*XX(146)-JVS(1013)*XX(153)-JVS(1046)*XX(156)-JVS(1177)*XX(166)-JVS(1219)&
              &*XX(168)-JVS(1374)*XX(176)-JVS(1547)*XX(186)-JVS(1837)*XX(197)-JVS(2160)*XX(204)-JVS(2236)*XX(205)-JVS(2570)&
              &*XX(211)-JVS(2748)*XX(213)-JVS(2866)*XX(214)
  XX(140) = XX(140)-JVS(1218)*XX(168)-JVS(1648)*XX(192)-JVS(1957)*XX(200)-JVS(2159)*XX(204)-JVS(2494)*XX(210)-JVS(2747)&
              &*XX(213)
  XX(139) = XX(139)-JVS(872)*XX(143)-JVS(1498)*XX(184)-JVS(2158)*XX(204)-JVS(2300)*XX(206)-JVS(2365)*XX(207)-JVS(2396)&
              &*XX(208)-JVS(2493)*XX(210)-JVS(2569)*XX(211)-JVS(2627)*XX(212)
  XX(138) = XX(138)-JVS(2034)*XX(202)-JVS(2746)*XX(213)-JVS(2865)*XX(214)
  XX(137) = XX(137)-JVS(1045)*XX(156)-JVS(1334)*XX(175)-JVS(1497)*XX(184)-JVS(1647)*XX(192)-JVS(1836)*XX(197)-JVS(2157)&
              &*XX(204)-JVS(2299)*XX(206)-JVS(2492)*XX(210)-JVS(2745)*XX(213)-JVS(2864)*XX(214)
  XX(136) = XX(136)-JVS(1625)*XX(191)-JVS(1730)*XX(195)-JVS(1956)*XX(200)-JVS(2033)*XX(202)-JVS(2156)*XX(204)-JVS(2744)&
              &*XX(213)-JVS(2863)*XX(214)
  XX(135) = XX(135)-JVS(871)*XX(143)-JVS(1496)*XX(184)-JVS(2155)*XX(204)-JVS(2298)*XX(206)-JVS(2364)*XX(207)-JVS(2491)&
              &*XX(210)-JVS(2568)*XX(211)
  XX(134) = XX(134)-JVS(1152)*XX(164)-JVS(1193)*XX(167)-JVS(1217)*XX(168)-JVS(2094)*XX(203)-JVS(2154)*XX(204)-JVS(2490)&
              &*XX(210)-JVS(2743)*XX(213)-JVS(2953)*XX(215)
  XX(133) = XX(133)-JVS(870)*XX(143)-JVS(1333)*XX(175)-JVS(1992)*XX(201)-JVS(2153)*XX(204)-JVS(2297)*XX(206)-JVS(2363)&
              &*XX(207)-JVS(2489)*XX(210)-JVS(2567)*XX(211)
  XX(132) = XX(132)-JVS(869)*XX(143)-JVS(1387)*XX(177)-JVS(1646)*XX(192)-JVS(2152)*XX(204)-JVS(2296)*XX(206)-JVS(2362)&
              &*XX(207)-JVS(2488)*XX(210)-JVS(2566)*XX(211)
  XX(131) = XX(131)-JVS(868)*XX(143)-JVS(1044)*XX(156)-JVS(1279)*XX(170)-JVS(1290)*XX(171)-JVS(1300)*XX(172)-JVS(1450)&
              &*XX(181)-JVS(1605)*XX(190)-JVS(1716)*XX(194)-JVS(1835)*XX(197)-JVS(2235)*XX(205)-JVS(2453)*XX(209)-JVS(2487)&
              &*XX(210)-JVS(2565)*XX(211)-JVS(2742)*XX(213)-JVS(2862)*XX(214)
  XX(130) = XX(130)-JVS(1645)*XX(192)-JVS(1834)*XX(197)-JVS(2151)*XX(204)-JVS(2395)*XX(208)-JVS(2486)*XX(210)-JVS(2564)&
              &*XX(211)-JVS(2626)*XX(212)-JVS(2741)*XX(213)-JVS(2861)*XX(214)
  XX(129) = XX(129)-JVS(801)*XX(136)-JVS(955)*XX(148)-JVS(1012)*XX(153)-JVS(1833)*XX(197)-JVS(2150)*XX(204)-JVS(2295)&
              &*XX(206)-JVS(2485)*XX(210)-JVS(2625)*XX(212)-JVS(2860)*XX(214)
  XX(128) = XX(128)-JVS(954)*XX(148)-JVS(1216)*XX(168)-JVS(1386)*XX(177)-JVS(1495)*XX(184)-JVS(1644)*XX(192)-JVS(1696)&
              &*XX(193)-JVS(2032)*XX(202)-JVS(2149)*XX(204)-JVS(2294)*XX(206)-JVS(2740)*XX(213)-JVS(2859)*XX(214)
  XX(127) = XX(127)-JVS(1215)*XX(168)-JVS(1695)*XX(193)-JVS(2031)*XX(202)-JVS(2148)*XX(204)-JVS(2293)*XX(206)-JVS(2739)&
              &*XX(213)-JVS(2858)*XX(214)
  XX(126) = XX(126)-JVS(867)*XX(143)-JVS(1935)*XX(199)-JVS(2147)*XX(204)-JVS(2292)*XX(206)-JVS(2361)*XX(207)-JVS(2484)&
              &*XX(210)-JVS(2563)*XX(211)
  XX(125) = XX(125)-JVS(784)*XX(134)-JVS(1151)*XX(164)-JVS(1192)*XX(167)-JVS(1214)*XX(168)-JVS(2093)*XX(203)-JVS(2146)&
              &*XX(204)-JVS(2483)*XX(210)-JVS(2952)*XX(215)
  XX(124) = XX(124)-JVS(935)*XX(147)-JVS(1213)*XX(168)-JVS(1265)*XX(169)-JVS(1760)*XX(196)-JVS(2092)*XX(203)-JVS(2145)&
              &*XX(204)-JVS(2482)*XX(210)-JVS(2738)*XX(213)-JVS(2951)*XX(215)
  XX(123) = XX(123)-JVS(1473)*XX(183)-JVS(1643)*XX(192)-JVS(1832)*XX(197)-JVS(2144)*XX(204)-JVS(2234)*XX(205)-JVS(2394)&
              &*XX(208)-JVS(2481)*XX(210)-JVS(2562)*XX(211)-JVS(2737)*XX(213)
  XX(122) = XX(122)-JVS(866)*XX(143)-JVS(1278)*XX(170)-JVS(1289)*XX(171)-JVS(1324)*XX(174)-JVS(1449)*XX(181)-JVS(1955)&
              &*XX(200)-JVS(2030)*XX(202)-JVS(2233)*XX(205)-JVS(2480)*XX(210)-JVS(2561)*XX(211)-JVS(2736)*XX(213)-JVS(2857)&
              &*XX(214)
  XX(121) = XX(121)-JVS(800)*XX(136)-JVS(953)*XX(148)-JVS(1011)*XX(153)-JVS(1831)*XX(197)-JVS(2291)*XX(206)-JVS(2624)&
              &*XX(212)-JVS(2856)*XX(214)
  XX(120) = XX(120)-JVS(1212)*XX(168)-JVS(1427)*XX(180)-JVS(1604)*XX(190)-JVS(1759)*XX(196)-JVS(2091)*XX(203)-JVS(2479)&
              &*XX(210)-JVS(2735)*XX(213)-JVS(2950)*XX(215)
  XX(119) = XX(119)-JVS(1830)*XX(197)-JVS(2143)*XX(204)-JVS(2560)*XX(211)-JVS(2734)*XX(213)-JVS(2855)*XX(214)
  XX(118) = XX(118)-JVS(1758)*XX(196)-JVS(1991)*XX(201)-JVS(2733)*XX(213)-JVS(2854)*XX(214)-JVS(2949)*XX(215)
  XX(117) = XX(117)-JVS(1128)*XX(163)-JVS(1472)*XX(183)-JVS(1829)*XX(197)-JVS(2393)*XX(208)-JVS(2732)*XX(213)
  XX(116) = XX(116)-JVS(934)*XX(147)-JVS(1164)*XX(165)-JVS(1211)*XX(168)-JVS(2090)*XX(203)-JVS(2232)*XX(205)-JVS(2731)&
              &*XX(213)-JVS(2948)*XX(215)
  XX(115) = XX(115)-JVS(933)*XX(147)-JVS(1163)*XX(165)-JVS(1210)*XX(168)-JVS(2089)*XX(203)-JVS(2231)*XX(205)-JVS(2730)&
              &*XX(213)-JVS(2947)*XX(215)
  XX(114) = XX(114)-JVS(1110)*XX(161)-JVS(1117)*XX(162)-JVS(1373)*XX(176)-JVS(2029)*XX(202)-JVS(2142)*XX(204)-JVS(2729)&
              &*XX(213)-JVS(2853)*XX(214)
  XX(113) = XX(113)-JVS(895)*XX(144)-JVS(1417)*XX(179)-JVS(1546)*XX(186)-JVS(1576)*XX(188)-JVS(1828)*XX(197)-JVS(1934)&
              &*XX(199)-JVS(2452)*XX(209)-JVS(2728)*XX(213)-JVS(2852)*XX(214)
  XX(112) = XX(112)-JVS(894)*XX(144)-JVS(1416)*XX(179)-JVS(1545)*XX(186)-JVS(1575)*XX(188)-JVS(1827)*XX(197)-JVS(1933)&
              &*XX(199)-JVS(2451)*XX(209)-JVS(2727)*XX(213)-JVS(2851)*XX(214)
  XX(111) = XX(111)-JVS(1209)*XX(168)-JVS(1642)*XX(192)-JVS(2141)*XX(204)-JVS(2478)*XX(210)-JVS(2726)*XX(213)
  XX(110) = XX(110)-JVS(1641)*XX(192)-JVS(1954)*XX(200)-JVS(2559)*XX(211)-JVS(2725)*XX(213)-JVS(2850)*XX(214)
  XX(109) = XX(109)-JVS(738)*XX(127)-JVS(1953)*XX(200)-JVS(2230)*XX(205)-JVS(2724)*XX(213)-JVS(2849)*XX(214)
  XX(108) = XX(108)-JVS(1494)*XX(184)-JVS(1826)*XX(197)-JVS(2392)*XX(208)-JVS(2558)*XX(211)-JVS(2723)*XX(213)-JVS(2848)&
              &*XX(214)
  XX(107) = XX(107)-JVS(908)*XX(145)-JVS(2722)*XX(213)-JVS(2946)*XX(215)
  XX(106) = XX(106)-JVS(1385)*XX(177)-JVS(1460)*XX(182)-JVS(1493)*XX(184)-JVS(1825)*XX(197)-JVS(1952)*XX(200)-JVS(2391)&
              &*XX(208)-JVS(2721)*XX(213)-JVS(2847)*XX(214)
  XX(105) = XX(105)-JVS(893)*XX(144)-JVS(1544)*XX(186)-JVS(1574)*XX(188)-JVS(1824)*XX(197)-JVS(1932)*XX(199)-JVS(2450)&
              &*XX(209)-JVS(2720)*XX(213)-JVS(2846)*XX(214)
  XX(104) = XX(104)-JVS(643)*XX(110)-JVS(1384)*XX(177)-JVS(1415)*XX(179)-JVS(1492)*XX(184)-JVS(1640)*XX(192)-JVS(2557)&
              &*XX(211)-JVS(2719)*XX(213)-JVS(2845)*XX(214)
  XX(103) = XX(103)-JVS(952)*XX(148)-JVS(1491)*XX(184)-JVS(2140)*XX(204)-JVS(2290)*XX(206)-JVS(2718)*XX(213)-JVS(2844)&
              &*XX(214)
  XX(102) = XX(102)-JVS(1587)*XX(189)-JVS(1639)*XX(192)-JVS(1823)*XX(197)-JVS(2556)*XX(211)-JVS(2717)*XX(213)-JVS(2843)&
              &*XX(214)
  XX(101) = XX(101)-JVS(1757)*XX(196)-JVS(1822)*XX(197)-JVS(2623)*XX(212)-JVS(2716)*XX(213)-JVS(2842)*XX(214)-JVS(2945)&
              &*XX(215)
  XX(100) = XX(100)-JVS(932)*XX(147)-JVS(2088)*XX(203)-JVS(2715)*XX(213)
  XX(99) = XX(99)-JVS(999)*XX(152)-JVS(1099)*XX(160)-JVS(1426)*XX(180)-JVS(1756)*XX(196)-JVS(2087)*XX(203)-JVS(2714)&
             &*XX(213)-JVS(2944)*XX(215)
  XX(98) = XX(98)-JVS(907)*XX(145)-JVS(1208)*XX(168)-JVS(1755)*XX(196)-JVS(2139)*XX(204)-JVS(2477)*XX(210)-JVS(2713)&
             &*XX(213)-JVS(2943)*XX(215)
  XX(97) = XX(97)-JVS(951)*XX(148)-JVS(1490)*XX(184)-JVS(2138)*XX(204)-JVS(2289)*XX(206)-JVS(2555)*XX(211)-JVS(2712)&
             &*XX(213)-JVS(2841)*XX(214)
  XX(96) = XX(96)-JVS(604)*XX(103)-JVS(950)*XX(148)-JVS(1383)*XX(177)-JVS(1489)*XX(184)-JVS(1638)*XX(192)-JVS(1821)&
             &*XX(197)-JVS(2390)*XX(208)-JVS(2554)*XX(211)-JVS(2711)*XX(213)-JVS(2840)*XX(214)
  XX(95) = XX(95)-JVS(1150)*XX(164)-JVS(1191)*XX(167)-JVS(2086)*XX(203)-JVS(2710)*XX(213)-JVS(2942)*XX(215)
  XX(94) = XX(94)-JVS(2085)*XX(203)-JVS(2941)*XX(215)
  XX(93) = XX(93)-JVS(1087)*XX(159)-JVS(1488)*XX(184)-JVS(1820)*XX(197)-JVS(2389)*XX(208)-JVS(2709)*XX(213)
  XX(92) = XX(92)-JVS(1694)*XX(193)-JVS(2028)*XX(202)-JVS(2708)*XX(213)-JVS(2839)*XX(214)
  XX(91) = XX(91)-JVS(1693)*XX(193)-JVS(1951)*XX(200)-JVS(2027)*XX(202)-JVS(2707)*XX(213)-JVS(2838)*XX(214)
  XX(90) = XX(90)-JVS(1207)*XX(168)-JVS(1692)*XX(193)-JVS(1754)*XX(196)-JVS(2476)*XX(210)-JVS(2706)*XX(213)-JVS(2940)&
             &*XX(215)
  XX(89) = XX(89)-JVS(970)*XX(149)-JVS(1010)*XX(153)-JVS(2026)*XX(202)-JVS(2137)*XX(204)-JVS(2705)*XX(213)-JVS(2837)&
             &*XX(214)
  XX(88) = XX(88)-JVS(1077)*XX(158)-JVS(1637)*XX(192)-JVS(1819)*XX(197)-JVS(1990)*XX(201)-JVS(2704)*XX(213)-JVS(2836)&
             &*XX(214)
  XX(87) = XX(87)-JVS(1310)*XX(173)-JVS(1989)*XX(201)-JVS(2703)*XX(213)-JVS(2835)*XX(214)
  XX(86) = XX(86)-JVS(2136)*XX(204)-JVS(2388)*XX(208)-JVS(2475)*XX(210)-JVS(2622)*XX(212)
  XX(85) = XX(85)-JVS(906)*XX(145)-JVS(1900)*XX(198)-JVS(2229)*XX(205)-JVS(2702)*XX(213)
  XX(84) = XX(84)-JVS(622)*XX(107)-JVS(1899)*XX(198)-JVS(2939)*XX(215)
  XX(83) = XX(83)-JVS(905)*XX(145)-JVS(2135)*XX(204)-JVS(2701)*XX(213)-JVS(2938)*XX(215)
  XX(82) = XX(82)-JVS(1753)*XX(196)-JVS(2553)*XX(211)-JVS(2621)*XX(212)-JVS(2700)*XX(213)-JVS(2834)*XX(214)-JVS(2937)&
             &*XX(215)
  XX(81) = XX(81)-JVS(1206)*XX(168)-JVS(1818)*XX(197)-JVS(2360)*XX(207)-JVS(2474)*XX(210)-JVS(2620)*XX(212)-JVS(2699)&
             &*XX(213)
  XX(80) = XX(80)-JVS(949)*XX(148)-JVS(1487)*XX(184)-JVS(1817)*XX(197)-JVS(2288)*XX(206)-JVS(2473)*XX(210)-JVS(2833)&
             &*XX(214)
  XX(79) = XX(79)-JVS(1098)*XX(160)-JVS(1559)*XX(187)-JVS(2698)*XX(213)-JVS(2832)*XX(214)
  XX(78) = XX(78)-JVS(998)*XX(152)-JVS(2025)*XX(202)-JVS(2697)*XX(213)-JVS(2831)*XX(214)
  XX(77) = XX(77)-JVS(1603)*XX(190)-JVS(1988)*XX(201)-JVS(2696)*XX(213)-JVS(2830)*XX(214)
  XX(76) = XX(76)-JVS(1149)*XX(164)-JVS(1190)*XX(167)-JVS(2134)*XX(204)-JVS(2287)*XX(206)
  XX(75) = XX(75)-JVS(2133)*XX(204)-JVS(2472)*XX(210)-JVS(2695)*XX(213)-JVS(2829)*XX(214)
  XX(74) = XX(74)-JVS(2132)*XX(204)-JVS(2286)*XX(206)-JVS(2694)*XX(213)
  XX(73) = XX(73)-JVS(462)*XX(74)-JVS(783)*XX(134)-JVS(1148)*XX(164)-JVS(2084)*XX(203)-JVS(2131)*XX(204)-JVS(2936)&
             &*XX(215)
  XX(72) = XX(72)-JVS(504)*XX(84)-JVS(904)*XX(145)-JVS(1898)*XX(198)-JVS(2693)*XX(213)-JVS(2935)*XX(215)
  XX(71) = XX(71)-JVS(1752)*XX(196)-JVS(2552)*XX(211)-JVS(2692)*XX(213)-JVS(2828)*XX(214)-JVS(2934)*XX(215)
  XX(70) = XX(70)-JVS(1751)*XX(196)-JVS(2551)*XX(211)-JVS(2691)*XX(213)-JVS(2827)*XX(214)-JVS(2933)*XX(215)
  XX(69) = XX(69)-JVS(1816)*XX(197)-JVS(2130)*XX(204)-JVS(2471)*XX(210)-JVS(2619)*XX(212)-JVS(2826)*XX(214)
  XX(68) = XX(68)-JVS(757)*XX(130)-JVS(2129)*XX(204)
  XX(67) = XX(67)-JVS(1147)*XX(164)-JVS(2932)*XX(215)
  XX(66) = XX(66)-JVS(2387)*XX(208)-JVS(2618)*XX(212)-JVS(2690)*XX(213)
  XX(65) = XX(65)-JVS(2285)*XX(206)-JVS(2825)*XX(214)
  XX(64) = XX(64)-JVS(1205)*XX(168)
  XX(63) = XX(63)-JVS(892)*XX(144)-JVS(2689)*XX(213)
  XX(62) = XX(62)-JVS(891)*XX(144)-JVS(2688)*XX(213)
  XX(61) = XX(61)-JVS(2284)*XX(206)-JVS(2824)*XX(214)
  XX(60) = XX(60)-JVS(2283)*XX(206)-JVS(2823)*XX(214)
  XX(59) = XX(59)-JVS(782)*XX(134)-JVS(1146)*XX(164)-JVS(2282)*XX(206)
  XX(58) = XX(58)-JVS(890)*XX(144)-JVS(2687)*XX(213)
  XX(57) = XX(57)-JVS(1145)*XX(164)-JVS(2083)*XX(203)
  XX(56) = XX(56)-JVS(1144)*XX(164)-JVS(2686)*XX(213)
  XX(55) = XX(55)-JVS(2082)*XX(203)-JVS(2617)*XX(212)-JVS(2685)*XX(213)-JVS(2822)*XX(214)
  XX(54) = XX(54)-JVS(2081)*XX(203)-JVS(2128)*XX(204)
  XX(53) = XX(53)-JVS(396)*XX(60)-JVS(948)*XX(148)-JVS(1486)*XX(184)-JVS(1815)*XX(197)
  XX(52) = XX(52)-JVS(1309)*XX(173)-JVS(2127)*XX(204)
  XX(51) = XX(51)-JVS(810)*XX(137)-JVS(2126)*XX(204)
  XX(50) = XX(50)-JVS(474)*XX(76)-JVS(1189)*XX(167)
  XX(49) = XX(49)-JVS(947)*XX(148)-JVS(1485)*XX(184)-JVS(2684)*XX(213)
  XX(48) = XX(48)-JVS(1143)*XX(164)-JVS(2616)*XX(212)-JVS(2683)*XX(213)
  XX(47) = XX(47)-JVS(416)*XX(64)
  XX(46) = XX(46)-JVS(401)*XX(61)-JVS(946)*XX(148)-JVS(1814)*XX(197)
  XX(45) = XX(45)-JVS(1204)*XX(168)
  XX(44) = XX(44)-JVS(473)*XX(76)-JVS(1142)*XX(164)-JVS(1188)*XX(167)
  XX(43) = XX(43)-JVS(2080)*XX(203)-JVS(2682)*XX(213)
  XX(42) = XX(42)-JVS(2079)*XX(203)-JVS(2681)*XX(213)
  XX(41) = XX(41)-JVS(472)*XX(76)
  XX(40) = XX(40)
  XX(39) = XX(39)
  XX(38) = XX(38)
  XX(37) = XX(37)
  XX(36) = XX(36)
  XX(35) = XX(35)
  XX(34) = XX(34)
  XX(33) = XX(33)
  XX(32) = XX(32)
  XX(31) = XX(31)
  XX(30) = XX(30)
  XX(29) = XX(29)
  XX(28) = XX(28)
  XX(27) = XX(27)
  XX(26) = XX(26)
  XX(25) = XX(25)
  XX(24) = XX(24)
  XX(23) = XX(23)
  XX(22) = XX(22)
  XX(21) = XX(21)
  XX(20) = XX(20)
  XX(19) = XX(19)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)
  XX(4) = XX(4)-JVS(1813)*XX(197)
  XX(3) = XX(3)-JVS(1141)*XX(164)-JVS(2078)*XX(203)
  XX(2) = XX(2)-JVS(1140)*XX(164)-JVS(2931)*XX(215)
  XX(1) = XX(1)-JVS(1139)*XX(164)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.

!$OMP THREADPRIVATE( Eps, First )      

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

